@@ -170,12 +170,19 @@ bool dai_is_ferry(struct unit *pferry, struct ai_type *ait)
 void dai_ferry_init_ferry(struct ai_type *ait, struct unit *ferry)
 {
   if (dai_is_ferry(ferry, ait)) {
+    bool caller_closes;
+    struct player *pplayer = unit_owner(ferry);
     struct unit_ai *unit_data = def_ai_unit_data(ferry, ait);
-    struct ai_plr *ai = dai_plr_data_get(ait, unit_owner(ferry), NULL);
+    struct ai_plr *ai = dai_plr_data_get(ait, pplayer,
+                                         &caller_closes);
 
     unit_data->passenger = FERRY_AVAILABLE;
     ai->stats.boats++;
     ai->stats.available_boats++;
+
+    if (caller_closes) {
+      dai_data_phase_finished(ait, pplayer);
+    }
   }
 }
 
@@ -442,7 +449,7 @@ bool is_boat_free(struct ai_type *ait, struct unit *boat,
    *   are eligible.
    * - Only boats with enough remaining capacity are eligible.
    * - Only units that can travel at sea are eligible.
-   * - Units that require fuel are lose hitpoints are not eligible.
+   * - Units that require fuel or lose hitpoints are not eligible.
    */
   struct unit_class *ferry_class = unit_class_get(boat);
   struct unit_ai *boat_data = def_ai_unit_data(boat, ait);
