@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,17 +32,23 @@
 #include "srv_log.h"
 #include "techtools.h"
 
-/* ai */
-#include "advmilitary.h"
+/* server/advisors */
+#include "advdata.h"
+
+/* ai/default */
+#include "aidata.h"
+#include "ailog.h"
+#include "aiplayer.h"
 #include "aitools.h"
+#include "daieffects.h"
 
 #include "aitech.h"
 
 struct ai_tech_choice {
-  Tech_type_id choice;   /* The id of the most needed tech */
-  int want;              /* Want of the most needed tech */
-  int current_want;      /* Want of the tech which is currently researched 
-			  * or is our current goal */
+  Tech_type_id choice;        /* The id of the most needed tech */
+  adv_want want;              /* Want of the most needed tech */
+  adv_want current_want;      /* Want of the tech which is currently researched 
+                               * or is our current goal */
 };
 
 /**************************************************************************
@@ -51,7 +57,7 @@ struct ai_tech_choice {
 
   TODO: Write a transparent formula.
 
-  Notes: 1. num_unknown_techs_for_goal returns 0 for known techs, 1 if tech 
+  Notes: 1. research_goal_unknown_techs returns 0 for known techs, 1 if tech
   is immediately available etc.
   2. A tech is reachable means we can research it now; tech is available 
   means it's on our tech tree (different nations can have different techs).
@@ -59,17 +65,19 @@ struct ai_tech_choice {
   of cities here.
   4. A tech isn't a requirement of itself.
 **************************************************************************/
-static void dai_select_tech(struct player *pplayer, 
+static void dai_select_tech(struct ai_type *ait,
+                            struct player *pplayer, 
                             struct ai_tech_choice *choice,
                             struct ai_tech_choice *goal)
 {
+  struct research *presearch = research_get(pplayer);
   Tech_type_id newtech, newgoal;
   int num_cities_nonzero = MAX(1, city_list_size(pplayer->cities));
-  int values[A_LAST];
-  int goal_values[A_LAST];
+  int values[MAX(A_LAST, A_UNSET + 1)];
+  int goal_values[MAX(A_LAST, A_UNSET + 1)];
+  struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
 
   memset(values, 0, sizeof(values));
-  memset(goal_values, 0, sizeof(goal_values));
   values[A_UNSET] = -1;
   values[A_NONE] = -1;
   goal_values[A_UNSET] = -1;
@@ -77,32 +85,32 @@ static void dai_select_tech(struct player *pplayer,
 
   /* if we are researching future techs, then simply continue with that. 
    * we don't need to do anything below. */
-  if (is_future_tech(player_research_get(pplayer)->researching)) {
+  if (is_future_tech(presearch->researching)) {
     if (choice) {
-      choice->choice = player_research_get(pplayer)->researching;
+      choice->choice = presearch->researching;
       choice->want = 1;
       choice->current_want = 1;
     }
     if (goal) {
-      goal->choice = player_research_get(pplayer)->tech_goal;
+      goal->choice = A_UNSET;
       goal->want = 1;
       goal->current_want = 1;
     }
     return;
-  }  
+  }
 
   /* Fill in values for the techs: want of the tech 
    * + average want of those we will discover en route */
   advance_index_iterate(A_FIRST, i) {
     if (valid_advance_by_number(i)) {
-      int steps = num_unknown_techs_for_goal(pplayer, i);
+      int steps = research_goal_unknown_techs(presearch, i);
 
       /* We only want it if we haven't got it (so AI is human after all) */
       if (steps > 0) { 
-        values[i] += pplayer->ai_common.tech_want[i];
+        values[i] += plr_data->tech_want[i];
 	advance_index_iterate(A_FIRST, k) {
-	  if (is_tech_a_req_for_goal(pplayer, k, i)) {
-            values[k] += pplayer->ai_common.tech_want[i] / steps;
+          if (research_goal_tech_req(presearch, i, k)) {
+            values[k] += plr_data->tech_want[i] / steps;
 	  }
 	} advance_index_iterate_end;
       }
@@ -112,15 +120,17 @@ static void dai_select_tech(struct player *pplayer,
   /* Fill in the values for the tech goals */
   advance_index_iterate(A_FIRST, i) {
     if (valid_advance_by_number(i)) {
-      int steps = num_unknown_techs_for_goal(pplayer, i);
+      int steps = research_goal_unknown_techs(presearch, i);
 
       if (steps == 0) {
+        /* Can't be set as a goal any more */
+        goal_values[i] = -1;
 	continue;
       }
 
       goal_values[i] = values[i];      
       advance_index_iterate(A_FIRST, k) {
-	if (is_tech_a_req_for_goal(pplayer, k, i)) {
+        if (research_goal_tech_req(presearch, i, k)) {
 	  goal_values[i] += values[k];
 	}
       } advance_index_iterate_end;
@@ -130,9 +140,9 @@ static void dai_select_tech(struct player *pplayer,
        * it's supposed to be doing; it just looks strange. -- Syela */
       goal_values[i] /= steps;
       if (steps < 6) {
-        log_debug("%s: want = %d, value = %d, goal_value = %d",
-                  advance_name_by_player(pplayer, i),
-                  pplayer->ai_common.tech_want[i],
+        log_debug("%s: want = " ADV_WANT_PRINTF ", value = %d, goal_value = %d",
+                  advance_rule_name(advance_by_number(i)),
+                  plr_data->tech_want[i],
                   values[i], goal_values[i]);
       }
     }
@@ -143,12 +153,11 @@ static void dai_select_tech(struct player *pplayer,
   advance_index_iterate(A_FIRST, i) {
     if (valid_advance_by_number(i)) {
       if (values[i] > values[newtech]
-          && player_invention_reachable(pplayer, i, FALSE)
-          && player_invention_state(pplayer, i) == TECH_PREREQS_KNOWN) {
+          && research_invention_gettable(presearch, i, TRUE)) {
         newtech = i;
       }
       if (goal_values[i] > goal_values[newgoal]
-	  && player_invention_reachable(pplayer, i, TRUE)) {
+          && research_invention_reachable(presearch, i)) {
 	newgoal = i;
       }
     }
@@ -156,8 +165,8 @@ static void dai_select_tech(struct player *pplayer,
 #ifdef REALLY_DEBUG_THIS
   advance_index_iterate(A_FIRST, id) {
     if (values[id] > 0
-        && player_invention_state(pplayer, id) == TECH_PREREQS_KNOWN) {
-      TECH_LOG(LOG_DEBUG, pplayer, advance_by_number(id),
+        && research_invention_state(presearch, id) == TECH_PREREQS_KNOWN) {
+      TECH_LOG(ait, LOG_DEBUG, pplayer, advance_by_number(id),
               "turn end want: %d", values[id]);
     }
   } advance_index_iterate_end;
@@ -165,19 +174,19 @@ static void dai_select_tech(struct player *pplayer,
   if (choice) {
     choice->choice = newtech;
     choice->want = values[newtech] / num_cities_nonzero;
-    choice->current_want = 
-      values[player_research_get(pplayer)->researching] / num_cities_nonzero;
+    choice->current_want = (values[presearch->researching]
+                            / num_cities_nonzero);
   }
 
   if (goal) {
     goal->choice = newgoal;
     goal->want = goal_values[newgoal] / num_cities_nonzero;
-    goal->current_want
-      = (goal_values[player_research_get(pplayer)->tech_goal]
-         / num_cities_nonzero);
-    log_debug("Goal->choice = %s, goal->want = %d, goal_value = %d, "
+    goal->current_want = (goal_values[presearch->tech_goal]
+                          / num_cities_nonzero);
+    log_debug("Goal->choice = %s, goal->want = " ADV_WANT_PRINTF ", goal_value = %d, "
               "num_cities_nonzero = %d",
-              advance_name_by_player(pplayer, goal->choice), goal->want,
+              research_advance_rule_name(presearch, goal->choice),
+              goal->want,
               goal_values[newgoal],
               num_cities_nonzero);
   }
@@ -185,23 +194,133 @@ static void dai_select_tech(struct player *pplayer,
   /* we can't have this, which will happen in the circumstance 
    * where all ai.tech_wants are negative */
   if (choice && choice->choice == A_UNSET) {
-    choice->choice = player_research_get(pplayer)->researching;
+    choice->choice = presearch->researching;
   }
 
   return;
 }
 
+/**************************************************************************
+  Calculates want for some techs by actually adding the tech and
+  measuring the effect.
+**************************************************************************/
+static adv_want dai_tech_base_want(struct ai_type *ait, struct player *pplayer,
+                                   struct city *pcity, struct advance *padv)
+{
+  struct research *pres = research_get(pplayer);
+  Tech_type_id tech = advance_number(padv);
+  enum tech_state old_state = research_invention_state(pres, tech);
+  struct adv_data *adv = adv_data_get(pplayer, NULL);
+  adv_want orig_want = dai_city_want(pplayer, pcity, adv, NULL);
+  adv_want final_want;
+  bool world_knew = game.info.global_advances[tech];
+
+  research_invention_set(pres, tech, TECH_KNOWN);
+
+  final_want = dai_city_want(pplayer, pcity, adv, NULL);
+
+  research_invention_set(pres, tech, old_state);
+  game.info.global_advances[tech] = world_knew;
+
+  return final_want - orig_want;
+}
+
+/**************************************************************************
+  Add effect values in to tech wants.
+**************************************************************************/
+static void dai_tech_effect_values(struct ai_type *ait, struct player *pplayer)
+{
+  /* TODO: Currently this duplicates code from aicity.c improvement effect
+   *       evaluating almost verbose - refactor so that they can share code. */
+  struct government *gov = government_of_player(pplayer);
+  struct adv_data *adv = adv_data_get(pplayer, NULL);
+  struct ai_plr *aip = def_ai_player_data(pplayer, ait);
+  int turns = 9999; /* TODO: Set to correct value */
+  int nplayers = normal_player_count();
+
+  /* Remove team members from the equation */
+  players_iterate(aplayer) {
+    if (aplayer->team
+        && aplayer->team == pplayer->team
+        && aplayer != pplayer) {
+      nplayers--;
+    }
+  } players_iterate_end;
+
+  advance_iterate(A_FIRST, padv) {
+    if (research_invention_state(research_get(pplayer), advance_number(padv))
+        != TECH_KNOWN) {
+      struct universal source = { .kind = VUT_ADVANCE, .value.advance = padv };
+
+      city_list_iterate(pplayer->cities, pcity) {
+        adv_want v;
+        adv_want tech_want;
+        bool capital;
+
+        v = dai_tech_base_want(ait, pplayer, pcity, padv);
+        capital = is_capital(pcity);
+
+        effect_list_iterate(get_req_source_effects(&source), peffect) {
+          bool present = TRUE;
+          bool active = TRUE;
+
+          requirement_vector_iterate(&peffect->reqs, preq) {
+            /* Check if all the requirements for the currently evaluated effect
+             * are met, except for having the tech that we are evaluating.
+             * TODO: Consider requirements that could be met later. */
+            if (VUT_ADVANCE == preq->source.kind
+                && preq->source.value.advance == padv) {
+              present = preq->present;
+              continue;
+            }
+            if (!is_req_active(pplayer, NULL, pcity, NULL, NULL, NULL, NULL,
+                               NULL, NULL, preq, RPT_POSSIBLE)) {
+              active = FALSE;
+              break; /* presence doesn't matter for inactive effects. */
+
+            }
+          } requirement_vector_iterate_end;
+
+          if (active) {
+            adv_want v1;
+
+            v1 = dai_effect_value(pplayer, gov, adv, pcity, capital,
+                                  turns, peffect, 1,
+                                  nplayers);
+
+            if (!present) {
+              /* Tech removes the effect */
+              v -= v1;
+            } else {
+              v += v1;
+            }
+          }
+        } effect_list_iterate_end;
+
+        /* Same conversion factor as in want_tech_for_improvement_effect() */
+        tech_want = v * 14 / 8;
+
+        aip->tech_want[advance_index(padv)] += tech_want;
+      } city_list_iterate_end;
+    }
+  } advance_iterate_end;
+}
+
 /**************************************************************************
   Key AI research function. Disable if we are in a team with human team
   mates in a research pool.
 **************************************************************************/
-void dai_manage_tech(struct player *pplayer)
+void dai_manage_tech(struct ai_type *ait, struct player *pplayer)
 {
   struct ai_tech_choice choice, goal;
-  struct player_research *research = player_research_get(pplayer);
+  struct research *research = research_get(pplayer);
   /* Penalty for switching research */
   int penalty = (research->got_tech ? 0 : research->bulbs_researched);
 
+  /* Even when we let human to do the final decision, we keep our
+   * wants correctly calculated. Add effect values in */
+  dai_tech_effect_values(ait, pplayer);
+
   /* If there are humans in our team, they will choose the techs */
   players_iterate(aplayer) {
     const struct player_diplstate *ds = player_diplstate_get(pplayer, aplayer);
@@ -211,17 +330,18 @@ void dai_manage_tech(struct player *pplayer)
     }
   } players_iterate_end;
 
-  dai_select_tech(pplayer, &choice, &goal);
+  dai_select_tech(ait, pplayer, &choice, &goal);
   if (choice.choice != research->researching) {
     /* changing */
-    if ((choice.want - choice.current_want) > penalty &&
-	penalty + research->bulbs_researched <=
-	total_bulbs_required(pplayer)) {
-      TECH_LOG(LOG_DEBUG, pplayer, advance_by_number(choice.choice), 
+    if (choice.want - choice.current_want > penalty
+        && (penalty + research->bulbs_researched
+            <= research_total_bulbs_required(research, research->researching,
+                                             FALSE))) {
+      TECH_LOG(ait, LOG_DEBUG, pplayer, advance_by_number(choice.choice), 
                "new research, was %s, penalty was %d", 
-               advance_name_by_player(pplayer, research->researching),
+               research_advance_rule_name(research, research->researching),
                penalty);
-      choose_tech(pplayer, choice.choice);
+      choose_tech(research, choice.choice);
     }
   }
 
@@ -229,24 +349,28 @@ void dai_manage_tech(struct player *pplayer)
   /* It worked, in particular, because the value it sets (research->tech_goal)
    * is practically never used, see the comment for ai_next_tech_goal */
   if (goal.choice != research->tech_goal) {
-    log_debug("%s change goal from %s (want=%d) to %s (want=%d)",
+    log_debug("%s change goal from %s (want=" ADV_WANT_PRINTF
+              ") to %s (want=" ADV_WANT_PRINTF ")",
               player_name(pplayer),
-              advance_name_by_player(pplayer, research->tech_goal), 
+              research_advance_rule_name(research, research->tech_goal),
               goal.current_want,
-              advance_name_by_player(pplayer, goal.choice),
+              research_advance_rule_name(research, goal.choice),
               goal.want);
-    choose_tech_goal(pplayer, goal.choice);
+    choose_tech_goal(research, goal.choice);
   }
 }
+
 /**************************************************************************
   Returns the best defense multiplier unit we can build, or NULL if none.
   Assigns tech wants for techs to get better units, but only for the
   cheapest to research.
 **************************************************************************/
-struct unit_type *dai_wants_defender_against(struct player *pplayer,
+struct unit_type *dai_wants_defender_against(struct ai_type *ait,
+                                             struct player *pplayer,
                                              struct city *pcity,
                                              struct unit_type *att, int want)
 {
+  struct research *presearch = research_get(pplayer);
   int best_avl_def = 0;
   struct unit_type *best_avl = NULL;
   int best_cost = FC_INFINITY;
@@ -257,8 +381,8 @@ struct unit_type *dai_wants_defender_against(struct player *pplayer,
 
   unit_type_iterate(deftype) {
     int mp = deftype->cache.defense_mp_bonuses[att_idx] + 1;
-    int div = combat_bonus_against(att->bonuses, deftype, CBONUS_DEFENSE_DIVIDER) + 1;
-    int def = deftype->defense_strength * mp / div;
+    int div_bonus = combat_bonus_against(att->bonuses, deftype, CBONUS_DEFENSE_DIVIDER) + 1;
+    int def = deftype->defense_strength * mp / div_bonus;
 
     def_values[utype_index(deftype)] = def;
 
@@ -280,43 +404,43 @@ struct unit_type *dai_wants_defender_against(struct player *pplayer,
       bool impossible_to_get = FALSE;
 
       if (A_NEVER != itech
-          && player_invention_state(pplayer, advance_number(itech)) != TECH_KNOWN) {
+          && research_invention_state(presearch,
+                                      advance_number(itech)) != TECH_KNOWN) {
         /* See if we want to invent this. */
-        cost = total_bulbs_required_for_goal(pplayer, advance_number(itech));
+        cost = research_goal_bulbs_required(presearch,
+                                            advance_number(itech));
       }
       if (deftype->need_improvement 
           && !can_player_build_improvement_direct(pplayer, deftype->need_improvement)) {
         struct impr_type *building = deftype->need_improvement;
 
         requirement_vector_iterate(&building->reqs, preq) {
-          if (VUT_ADVANCE == preq->source.kind) {
-            int iimprtech = advance_number(preq->source.value.advance);
+          if (!is_req_active(pplayer, NULL, pcity, building, city_tile(pcity),
+                             NULL, deftype, NULL, NULL, preq, RPT_CERTAIN)) {
 
-            if (!preq->negated) {
-              if (TECH_KNOWN != player_invention_state(pplayer, iimprtech)) {
-                int imprcost = total_bulbs_required_for_goal(pplayer, iimprtech);
+            if (VUT_ADVANCE == preq->source.kind && preq->present) {
+              int iimprtech = advance_number(preq->source.value.advance);
+              int imprcost = research_goal_bulbs_required(presearch,
+                                                          iimprtech);
 
-                if (imprcost < cost || cost == 0) {
-                  /* If we already have the primary tech (cost == 0),
-                   * or the building's tech is cheaper,
-                   * go for the building's required tech. */
-                  itech = preq->source.value.advance;
-                  cost = 0;
-                }
-                cost += imprcost;
-              }
-            } else {
-              if (TECH_KNOWN == player_invention_state(pplayer, iimprtech)) {
-                /* We're not going to lose tech */
-                impossible_to_get = TRUE;
+              if (imprcost < cost || cost == 0) {
+                /* If we already have the primary tech (cost == 0),
+                 * or the building's tech is cheaper,
+                 * go for the building's required tech. */
+                itech = preq->source.value.advance;
+                cost = 0;
               }
+              cost += imprcost;
+            } else if (!dai_can_requirement_be_met_in_city(preq, pplayer,
+                                                           pcity)) {
+              impossible_to_get = TRUE;
             }
           }
         } requirement_vector_iterate_end;
       }
 
       if (cost < best_cost && !impossible_to_get
-          && player_invention_reachable(pplayer, advance_number(itech), TRUE)) {
+          && research_invention_reachable(presearch, advance_number(itech))) {
         best_tech = itech;
         best_cost = cost;
         best_unit = deftype;
@@ -325,14 +449,17 @@ struct unit_type *dai_wants_defender_against(struct player *pplayer,
   } unit_type_iterate_end;
 
   if (A_NEVER != best_tech) {
+    struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
+
     /* Crank up chosen tech want */
     if (best_avl != NULL
         && def_values[utype_index(best_unit)] <= 1.5 * best_avl_def) {
       /* We already have almost as good unit suitable for defending against this attacker */
       want /= 2;
     }
-    pplayer->ai_common.tech_want[advance_index(best_tech)] += want;
-    TECH_LOG(LOG_DEBUG, pplayer, best_tech,
+
+    plr_data->tech_want[advance_index(best_tech)] += want;
+    TECH_LOG(ait, LOG_DEBUG, pplayer, best_tech,
              "+ %d for %s by role",
              want,
              utype_rule_name(best_unit));
@@ -347,10 +474,10 @@ struct unit_type *dai_wants_defender_against(struct player *pplayer,
   wants for techs to get better units with given role, but only for the
   cheapest to research "next" unit up the "chain".
 **************************************************************************/
-struct unit_type *dai_wants_role_unit(struct player *pplayer,
-                                      struct city *pcity,
-                                      int role, int want)
+struct unit_type *dai_wants_role_unit(struct ai_type *ait, struct player *pplayer,
+                                      struct city *pcity, int role, int want)
 {
+  struct research *presearch = research_get(pplayer);
   int i, n;
   int best_cost = FC_INFINITY;
   struct advance *best_tech = A_NEVER;
@@ -369,20 +496,24 @@ struct unit_type *dai_wants_role_unit(struct player *pplayer,
       int cost = 0;
 
       if (A_NEVER != itech
-       && player_invention_state(pplayer, advance_number(itech)) != TECH_KNOWN) {
+       && research_invention_state(presearch,
+                                   advance_number(itech)) != TECH_KNOWN) {
         /* See if we want to invent this. */
-        cost = total_bulbs_required_for_goal(pplayer, advance_number(itech));
+        cost = research_goal_bulbs_required(presearch,
+                                            advance_number(itech));
       }
       if (iunit->need_improvement 
           && !can_player_build_improvement_direct(pplayer, iunit->need_improvement)) {
         struct impr_type *building = iunit->need_improvement;
 
 	requirement_vector_iterate(&building->reqs, preq) {
-	  if (VUT_ADVANCE == preq->source.kind && !preq->negated) {
+	  if (VUT_ADVANCE == preq->source.kind && preq->present) {
 	    int iimprtech = advance_number(preq->source.value.advance);
 
-	    if (TECH_KNOWN != player_invention_state(pplayer, iimprtech)) {
-	      int imprcost = total_bulbs_required_for_goal(pplayer, iimprtech);
+            if (TECH_KNOWN != research_invention_state(presearch,
+                                                       iimprtech)) {
+              int imprcost = research_goal_bulbs_required(presearch,
+                                                          iimprtech);
 
 	      if (imprcost < cost || cost == 0) {
 	        /* If we already have the primary tech (cost==0),
@@ -398,7 +529,7 @@ struct unit_type *dai_wants_role_unit(struct player *pplayer,
       }
 
       if (cost < best_cost
-       && player_invention_reachable(pplayer, advance_number(itech), TRUE)) {
+       && research_invention_reachable(presearch, advance_number(itech))) {
         best_tech = itech;
         best_cost = cost;
         best_unit = iunit;
@@ -407,16 +538,30 @@ struct unit_type *dai_wants_role_unit(struct player *pplayer,
   }
 
   if (A_NEVER != best_tech) {
+    struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
+
     /* Crank up chosen tech want */
     if (build_unit != NULL) {
       /* We already have a role unit of this kind */
       want /= 2;
     }
-    pplayer->ai_common.tech_want[advance_index(best_tech)] += want;
-    TECH_LOG(LOG_DEBUG, pplayer, best_tech,
+    plr_data->tech_want[advance_index(best_tech)] += want;
+    TECH_LOG(ait, LOG_DEBUG, pplayer, best_tech,
              "+ %d for %s by role",
              want,
              utype_rule_name(best_unit));
   }
   return build_unit;
 }
+
+/**************************************************************************
+  Zero player tech wants
+**************************************************************************/
+void dai_clear_tech_wants(struct ai_type *ait, struct player *pplayer)
+{
+  struct ai_plr *plr_data = def_ai_player_data(pplayer, ait);
+
+  advance_index_iterate(A_FIRST, i) {
+    plr_data->tech_want[i] = 0;
+  } advance_index_iterate_end;
+}
