@@ -1514,18 +1514,19 @@ void military_advisor_choose_build(struct ai_type *ait,
               uchoice.want = MIN(25, danger);
             }
           } else {
-            choice->want = danger;
+            uchoice.want = danger;
           }
 
           uchoice.want += martial_value;
 
-          CITY_LOG(LOG_DEBUG, pcity, "m_a_c_d wants %s with desire " ADV_WANT_PRINTF,
-                   utype_rule_name(choice->value.utype),
-                   choice->want);
-
           if (!build_walls || uchoice.want > choice->want) {
             *choice = uchoice;
           }
+
+          CITY_LOG(LOG_DEBUG, pcity,
+                   "m_a_c_d wants %s with desire " ADV_WANT_PRINTF,
+                   utype_rule_name(choice->value.utype),
+                   choice->want);
         } else {
           CITY_LOG(LOG_DEBUG, pcity, "m_a_c_d cannot select defender");
         }
@@ -1576,7 +1577,7 @@ void military_advisor_choose_build(struct ai_type *ait,
 
   /* Check if we want a sailing attacker. Have to put sailing first
      before we mung the seamap */
-  punittype = dai_choose_attacker(ait, pcity, TC_LAND);
+  punittype = dai_choose_attacker(ait, pcity, TC_OCEAN);
   if (punittype) {
     virtualunit = unit_virtual_create(pplayer, pcity, punittype,
                                       do_make_unit_veteran(pcity, punittype));
