@@ -17,6 +17,7 @@
 
 /* common */
 #include "ai.h"
+#include "player.h"
 
 const char *fc_ai_stub_capstr(void);
 bool fc_ai_stub_setup(struct ai_type *ai);
@@ -29,6 +30,14 @@ const char *fc_ai_stub_capstr(void)
   return FC_AI_MOD_CAPSTR;
 }
 
+/**************************************************************************
+  Set phase done
+**************************************************************************/
+static void stub_end_turn(struct player *pplayer)
+{
+  pplayer->ai_phase_done = TRUE;
+}
+
 /**************************************************************************
   Setup player ai_funcs function pointers.
 **************************************************************************/
@@ -36,5 +45,8 @@ bool fc_ai_stub_setup(struct ai_type *ai)
 {
   strncpy(ai->name, "stub", sizeof(ai->name));
 
+  ai->funcs.first_activities = stub_end_turn;
+  ai->funcs.restart_phase    = stub_end_turn;
+
   return TRUE;
 }
