@@ -22,6 +22,10 @@ extern "C" {
 #define MAX_AUDIO_NAME_LEN		20
 #define MAX_AUDIO_DESCR_LEN		200
 
+#define MAX_ALT_AUDIO_FILES             5
+
+typedef void (*audio_finished_callback)(void);
+
 struct audio_plugin {
   char name[MAX_AUDIO_NAME_LEN];
   char descr[MAX_AUDIO_DESCR_LEN];
@@ -31,23 +35,32 @@ struct audio_plugin {
   void (*wait) (void);
   double (*get_volume) (void);
   void (*set_volume) (double volume);
-  bool (*play) (const char *const tag, const char *const path, bool repeat);
+  bool (*play) (const char *const tag, const char *const path, bool repeat,
+                audio_finished_callback cb);
 };
 
+enum music_usage { MU_SINGLE, MU_MENU, MU_INGAME };
+
 struct strvec;
-const struct strvec *get_soundplugin_list(void);
-const struct strvec *get_soundset_list(void);
+struct option;
+const struct strvec *get_soundplugin_list(const struct option *poption);
+const struct strvec *get_soundset_list(const struct option *poption);
+const struct strvec *get_musicset_list(const struct option *poption);
 
 void audio_init(void);
-void audio_real_init(const char *const spec_name,
-		     const char *const prefered_plugin_name);
+void audio_real_init(const char *const soundspec_name,
+                     const char *const musicset_name,
+                     const char *const preferred_plugin_name);
 void audio_add_plugin(struct audio_plugin *p);
 void audio_shutdown(void);
 void audio_stop(void);
-void audio_restart(const char *soundset_name);
+void audio_stop_usage(void);
+void audio_restart(const char *soundset_name, const char *musicset_name);
 
 void audio_play_sound(const char *const tag, char *const alt_tag);
-void audio_play_music(const char *const tag, char *const alt_tag);
+void audio_play_music(const char *const tag, char *const alt_tag,
+                      enum music_usage usage);
+void audio_play_track(const char *const tag, char *const alt_tag);
 
 double audio_get_volume(void);
 void audio_set_volume(double volume);
