@@ -15,13 +15,17 @@
 #include <fc_config.h>
 #endif
 
+#include <stdarg.h>
+
 /* utility */
+#include "astring.h"
 #include "fcintl.h"
 #include "log.h"
 #include "support.h"
 
 /* common */
 #include "city.h"
+#include "culture.h"
 #include "game.h"
 #include "specialist.h"
 #include "unitlist.h"
@@ -447,6 +451,275 @@ void get_city_dialog_production_row(char *buf[], size_t column_size,
   }
 }
 
+/**********************************************************************//**
+  Helper structure to accumulate a breakdown of the constributions
+  to some numeric city property. Contributions are returned in order,
+  with duplicates merged.
+**************************************************************************/
+struct city_sum {
+  const char *format;
+  size_t n;
+  struct {
+    /* The net value that is accumulated. */
+    double value;
+    /* Description; compared for duplicate-merging.
+     * Both of these are maintained/compared until the net 'value' is known;
+     * then posdesc is used if value>=0, negdesc if value<0 */
+    char *posdesc, *negdesc;
+    /* Whether posdesc is printed for total==0 */
+    bool suppress_if_zero;
+    /* An auxiliary value that is also accumulated, but not tested */
+    double aux;
+    /* ...and the format string for the net aux value (appended to *desc) */
+    const char *auxfmt;
+  } *sums;
+};
+
+/**********************************************************************//**
+  Create a new city_sum.
+  'format' is how to print each contribution, of the form "%+4.0f : %s"
+  (the first item is the numeric value and must have a 'f' conversion
+  spec; the second is the description).
+**************************************************************************/
+static struct city_sum *city_sum_new(const char *format)
+{
+  struct city_sum *sum = fc_malloc(sizeof(struct city_sum));
+
+  sum->format = format;
+  sum->n = 0;
+  sum->sums = NULL;
+
+  return sum;
+}
+
+/**********************************************************************//**
+  Helper: add a new contribution to the city_sum.
+  If 'posdesc'/'negdesc' and other properties match an existing entry,
+  'value' is added to the existing entry, else a new one is appended.
+**************************************************************************/
+static void city_sum_add_real(struct city_sum *sum, double value,
+                              bool suppress_if_zero,
+                              const char *auxfmt,
+                              double aux,
+                              char *posdesc,
+                              char *negdesc)
+{
+  size_t i;
+
+  /* likely to lead to quadratic behaviour, but who cares: */
+  for (i = 0; i < sum->n; i++) {
+    fc_assert(sum->sums != NULL);
+    if ((strcmp(sum->sums[i].posdesc, posdesc) == 0)
+        && (strcmp(sum->sums[i].negdesc, negdesc) == 0)
+        && ((sum->sums[i].auxfmt == auxfmt)
+            || (strcmp(sum->sums[i].auxfmt, auxfmt) == 0))
+        && sum->sums[i].suppress_if_zero == suppress_if_zero) {
+      /* Looks like we already have an entry like this. Accumulate values. */
+      sum->sums[i].value += value;
+      sum->sums[i].aux += aux;
+      FC_FREE(posdesc);
+      FC_FREE(negdesc);
+      return;
+    }
+  }
+  
+  /* Didn't find description already, so add it to the end. */
+  sum->sums = fc_realloc(sum->sums, (sum->n + 1) * sizeof(sum->sums[0]));
+  sum->sums[sum->n].value   = value;
+  sum->sums[sum->n].posdesc = posdesc;
+  sum->sums[sum->n].negdesc = negdesc;
+  sum->sums[sum->n].suppress_if_zero = suppress_if_zero;
+  sum->sums[sum->n].aux     = aux;
+  sum->sums[sum->n].auxfmt  = auxfmt;
+  sum->n++;
+}
+
+/**********************************************************************//**
+  Add a new contribution to the city_sum (complex).
+   - Allows different descriptions for net positive and negative
+     contributions (posfmt/negfmt);
+   - Allows specifying another auxiliary number which isn't significant
+     for comparisons but will also be accumulated, and appended to the
+     description when rendered (e.g. the 50% in "+11: Bonus from
+     Marketplace+Luxury (+50%)")
+   - Allows control over whether the item will be discarded if its
+     net value is zero (suppress_if_zero).
+**************************************************************************/
+static void
+            fc__attribute((__format__(__printf__, 6, 8)))
+            fc__attribute((__format__(__printf__, 7, 8)))
+            fc__attribute((nonnull (1, 6, 7)))
+            city_sum_add_full(struct city_sum *sum, double value,
+                              bool suppress_if_zero,
+                              const char *auxfmt,
+                              double aux,
+                              const char *posfmt,
+                              const char *negfmt, 
+                              ...)
+{
+  va_list args;
+  struct astring astr = ASTRING_INIT;
+  char *posdesc, *negdesc;
+
+  /* Format both descriptions */
+  va_start(args, negfmt);  /* sic -- arguments follow negfmt */
+  astr_vadd(&astr, posfmt, args);
+  posdesc = astr_to_str(&astr);
+  va_end(args);
+  va_start(args, negfmt);
+  astr_vadd(&astr, negfmt, args);
+  negdesc = astr_to_str(&astr);
+  va_end(args);
+
+  city_sum_add_real(sum, value, suppress_if_zero, auxfmt, aux,
+                    posdesc, negdesc);
+}
+
+/**********************************************************************//**
+  Add a new contribution to the city_sum (simple).
+  Compared to city_sum_add_full():
+   - description does not depend on net value
+   - not suppressed if net value is zero (compare city_sum_add_nonzero())
+   - no auxiliary number
+**************************************************************************/
+static void
+            fc__attribute((__format__(__printf__, 3, 4)))
+            fc__attribute((nonnull (1, 3)))
+            city_sum_add(struct city_sum *sum, double value,
+                         const char *descfmt, ...)
+{
+  va_list args;
+  struct astring astr = ASTRING_INIT;
+  char *desc;
+
+  /* Format description (same used for positive or negative net value) */
+  va_start(args, descfmt);
+  astr_vadd(&astr, descfmt, args);
+  desc = astr_to_str(&astr);
+  va_end(args);
+
+  /* Descriptions will be freed individually, so need to strdup */
+  city_sum_add_real(sum, value, FALSE, NULL, 0, desc, fc_strdup(desc));
+}
+
+/**********************************************************************//**
+  Add a new contribution to the city_sum (simple).
+  Compared to city_sum_add_full():
+   - description does not depend on net value
+   - suppressed if net value is zero (compare city_sum_add())
+   - no auxiliary number
+**************************************************************************/
+static void
+            fc__attribute((__format__(__printf__, 3, 4)))
+            fc__attribute((nonnull (1, 3)))
+            city_sum_add_if_nonzero(struct city_sum *sum, double value,
+                                    const char *descfmt, ...)
+{
+  va_list args;
+  struct astring astr = ASTRING_INIT;
+  char *desc;
+
+  /* Format description (same used for positive or negative net value) */
+  va_start(args, descfmt);
+  astr_vadd(&astr, descfmt, args);
+  desc = astr_to_str(&astr);
+  va_end(args);
+
+  /* Descriptions will be freed individually, so need to strdup */
+  city_sum_add_real(sum, value, TRUE, NULL, 0, desc, fc_strdup(desc));
+}
+
+/**********************************************************************//**
+  Return the net total accumulated in the sum so far.
+**************************************************************************/
+static double city_sum_total(struct city_sum *sum)
+{
+  size_t i;
+  double total = 0;
+
+  for (i = 0; i < sum->n; i++) {
+    total += sum->sums[i].value;
+  }
+  return total;
+}
+
+/**********************************************************************//**
+  Compare two values, taking care of floating point comparison issues.
+    -1: val1 <  val2
+     0: val1 == val2 (approximately)
+    +1: val1 >  val2
+**************************************************************************/
+static inline int city_sum_compare(double val1, double val2)
+{
+  /* Fudgey epsilon -- probably the numbers we're dealing with have at
+   * most 1% or 0.1% real difference */
+  if (fabs(val1-val2) < 0.0000001) {
+    return 0;
+  }
+  return (val1 > val2 ? +1 : -1);
+}
+
+/**********************************************************************//**
+  Print out the sum, including total, and free the city_sum.
+  totalfmt's first format string must be some kind of %f, and first
+  argument must be a double (if account_for_unknown).
+  account_for_unknown is optional, as not every sum wants it (consider
+  pollution's clipping).
+**************************************************************************/
+static void
+            fc__attribute((__format__(__printf__, 5, 6)))
+            fc__attribute((nonnull (1, 2, 5)))
+            city_sum_print(struct city_sum *sum, char *buf, size_t bufsz,
+                           bool account_for_unknown,
+                           const char *totalfmt, ...)
+{
+  va_list args;
+  size_t i;
+
+  /* This probably ought not to happen in well-designed rulesets, but it's
+   * possible for incomplete client knowledge to give an inaccurate
+   * breakdown. If it does happen, at least acknowledge to the user that
+   * we are confused, rather than displaying an incorrect sum. */
+  if (account_for_unknown) {
+    double total = city_sum_total(sum);
+    double actual_total;
+
+    va_start(args, totalfmt);
+    actual_total = va_arg(args, double);
+    va_end(args);
+
+    if (city_sum_compare(total, actual_total) != 0) {
+      city_sum_add(sum, actual_total - total,
+                   /* TRANS: Client cannot explain some aspect of city
+                    * output. Should never happen. */
+                   Q_("?city_sum:(unknown)"));
+    }
+  }
+
+  for (i = 0; i < sum->n; i++) {
+    if (!sum->sums[i].suppress_if_zero
+        || city_sum_compare(sum->sums[i].value, 0) != 0) {
+      cat_snprintf(buf, bufsz,
+                   sum->format, sum->sums[i].value,
+                   (sum->sums[i].value < 0) ? sum->sums[i].negdesc
+                                            : sum->sums[i].posdesc);
+      if (sum->sums[i].auxfmt) {
+        cat_snprintf(buf, bufsz, sum->sums[i].auxfmt, sum->sums[i].aux);
+      }
+      cat_snprintf(buf, bufsz, "\n");
+    }
+    FC_FREE(sum->sums[i].posdesc);
+    FC_FREE(sum->sums[i].negdesc);
+  }
+
+  va_start(args, totalfmt);
+  fc_vsnprintf(buf + strlen(buf), bufsz - strlen(buf), totalfmt, args);
+  va_end(args);
+
+  FC_FREE(sum->sums);
+  FC_FREE(sum);
+}
+
 /**************************************************************************
   Return text describing the production output.
 **************************************************************************/
@@ -454,24 +727,23 @@ void get_city_dialog_output_text(const struct city *pcity,
                                  Output_type_id otype,
                                  char *buf, size_t bufsz)
 {
-  int total = 0;
   int priority;
   int tax[O_LAST];
   struct output_type *output = &output_types[otype];
+  /* TRANS: format string for a row of the city output sum that adds up
+   * to "Total surplus" */
+  struct city_sum *sum = city_sum_new(Q_("?city_surplus:%+4.0f : %s"));
 
   buf[0] = '\0';
 
-  cat_snprintf(buf, bufsz,
-	       _("%+4d : Citizens\n"), pcity->citizen_base[otype]);
-  total += pcity->citizen_base[otype];
+  city_sum_add(sum, pcity->citizen_base[otype],
+               Q_("?city_surplus:Citizens"));
 
   /* Hack to get around the ugliness of add_tax_income. */
   memset(tax, 0, O_LAST * sizeof(*tax));
   add_tax_income(city_owner(pcity), pcity->prod[O_TRADE], tax);
-  if (tax[otype] != 0) {
-    cat_snprintf(buf, bufsz, _("%+4d : Taxed from trade\n"), tax[otype]);
-    total += tax[otype];
-  }
+  city_sum_add_if_nonzero(sum, tax[otype],
+                          Q_("?city_surplus:Taxed from trade"));
 
   /* Special cases for "bonus" production.  See set_city_production in
    * city.c. */
@@ -488,30 +760,27 @@ void get_city_dialog_output_text(const struct city *pcity,
          * NB: (pcity->trade_value[i] == 0) is valid case.  The trade route
          * is established but doesn't give trade surplus. */
         struct city *trade_city = game_city_by_number(pcity->trade[i]);
-        /* TRANS: "unknown" location */
+        /* TRANS: "unknown" city name */
         const char *name = trade_city ? city_name_get(trade_city) : _("(unknown)");
+        int value = pcity->trade_value[i]
+                    * (100 + get_city_bonus(pcity, EFT_TRADEROUTE_PCT)) / 100;
 
-        cat_snprintf(buf, bufsz, _("%+4d : Trade route with %s\n"),
-                     pcity->trade_value[i]
-                     * (100 + get_city_bonus(pcity, EFT_TRADEROUTE_PCT)) / 100,
+        city_sum_add(sum, value, Q_("?city_surplus:Trade route with %s"),
                      name);
-        total += pcity->trade_value[i];
       }
     }
   } else if (otype == O_GOLD) {
     int tithes = get_city_tithes_bonus(pcity);
 
-    if (tithes != 0) {
-      cat_snprintf(buf, bufsz, _("%+4d : Building tithes\n"), tithes);
-      total += tithes;
-    }
+    city_sum_add_if_nonzero(sum, tithes,
+                            Q_("?city_surplus:Building tithes"));
   }
 
   for (priority = 0; priority < 2; priority++) {
     enum effect_type eft[] = {EFT_OUTPUT_BONUS, EFT_OUTPUT_BONUS_2};
 
     {
-      int base = total, bonus = 100;
+      int base = city_sum_total(sum), bonus = 100;
       struct effect_list *plist = effect_list_new();
 
       (void) get_city_bonus_effects(plist, pcity, output, eft[priority]);
@@ -539,11 +808,12 @@ void get_city_dialog_output_text(const struct city *pcity,
         }
         bonus += delta;
 	new_total = bonus * base / 100;
-	cat_snprintf(buf, bufsz,
-                     (delta > 0) ? _("%+4d : Bonus from %s (%+d%%)\n")
-                                 : _("%+4d : Loss from %s (%+d%%)\n"),
-		     (new_total - total), buf2, delta);
-	total = new_total;
+        city_sum_add_full(sum, new_total - city_sum_total(sum), TRUE,
+                          /* TRANS: percentage city output bonus/loss from
+                           * some source; preserve leading space */
+                          Q_("?city_surplus: (%+.0f%%)"), delta,
+                          Q_("?city_surplus:Bonus from %s"),
+                          Q_("?city_surplus:Loss from %s"), buf2);
       } effect_list_iterate_end;
       effect_list_destroy(plist);
     }
@@ -554,14 +824,14 @@ void get_city_dialog_output_text(const struct city *pcity,
     bool breakdown_ok;
     int regular_waste;
     /* FIXME: this will give the wrong answer in rulesets with waste on
-     * taxed outputs, such as 'science waste', as total includes tax whereas
-     * the equivalent bit in set_city_production() does not */
-    if (city_waste(pcity, otype, total, wastetypes) == pcity->waste[otype]) {
+     * taxed outputs, such as 'science waste', as our total so far includes
+     * contributions taxed from trade, whereas the equivalent bit in
+     * set_city_production() does not */
+    if (city_waste(pcity, otype, city_sum_total(sum), wastetypes)
+        == pcity->waste[otype]) {
       /* Our calculation matches the server's, so we trust our breakdown. */
-      if (wastetypes[OLOSS_SIZE] > 0) {
-        cat_snprintf(buf, bufsz,
-                     _("%+4d : Size penalty\n"), -wastetypes[OLOSS_SIZE]);
-      }
+      city_sum_add_if_nonzero(sum, -wastetypes[OLOSS_SIZE],
+                              Q_("?city_surplus:Size penalty"));
       regular_waste = wastetypes[OLOSS_WASTE];
       breakdown_ok = TRUE;
     } else {
@@ -571,51 +841,36 @@ void get_city_dialog_output_text(const struct city *pcity,
       breakdown_ok = FALSE;
     }
     if (regular_waste > 0) {
-      char *fmt;
+      const char *fmt;
       switch (otype) {
         case O_SHIELD:
         default: /* FIXME other output types? */
           /* TRANS: %s is normally empty, but becomes '?' if client is
            * uncertain about its accounting (should never happen) */
-          fmt = _("%+4d : Waste%s\n");
+          fmt = Q_("?city_surplus:Waste%s");
           break;
         case O_TRADE:
           /* TRANS: %s is normally empty, but becomes '?' if client is
            * uncertain about its accounting (should never happen) */
-          fmt = _("%+4d : Corruption%s\n");
+          fmt = Q_("?city_surplus:Corruption%s");
           break;
       }
-      cat_snprintf(buf, bufsz, fmt, -regular_waste, breakdown_ok ? "" : "?");
+      city_sum_add(sum, -regular_waste, fmt, breakdown_ok ? "" : "?");
     }
-    total -= pcity->waste[otype];
   }
 
-  if (pcity->unhappy_penalty[otype] != 0) {
-    cat_snprintf(buf, bufsz,
-		 _("%+4d : Disorder\n"), -pcity->unhappy_penalty[otype]);
-    total -= pcity->unhappy_penalty[otype];
-  }
+  city_sum_add_if_nonzero(sum, -pcity->unhappy_penalty[otype],
+                          Q_("?city_surplus:Disorder"));
 
   if (pcity->usage[otype] > 0) {
-    cat_snprintf(buf, bufsz,
-		 _("%+4d : Used\n"), -pcity->usage[otype]);
-    total -= pcity->usage[otype];
+    city_sum_add(sum, -pcity->usage[otype],
+                 Q_("?city_surplus:Used"));
   }
 
-  /* This should never happen, but if it does, at least acknowledge to
-   * the user that we are confused, rather than displaying an incorrect
-   * sum. */
-  if (total != pcity->surplus[otype]) {
-    cat_snprintf(buf, bufsz,
-                 /* TRANS: City output that we cannot explain.
-                  * Should never happen. */
-                 _("%+4d : (unknown)\n"), pcity->surplus[otype] - total);
-  }
-
-  cat_snprintf(buf, bufsz,
-	       _("==== : Adds up to\n"));
-  cat_snprintf(buf, bufsz,
-	       _("%4d : Total surplus"), pcity->surplus[otype]);
+  city_sum_print(sum, buf, bufsz, TRUE,
+                 Q_("?city_surplus:"
+	            "==== : Adds up to\n"
+	            "%4.0f : Total surplus"), (double) pcity->surplus[otype]);
 }
 
 /**************************************************************************
@@ -626,6 +881,7 @@ void get_city_dialog_illness_text(const struct city *pcity,
 {
   int illness, ill_base, ill_size, ill_trade, ill_pollution;
   struct effect_list *plist;
+  struct city_sum *sum;
 
   buf[0] = '\0';
 
@@ -634,15 +890,17 @@ void get_city_dialog_illness_text(const struct city *pcity,
     return;
   }
 
+  sum = city_sum_new(Q_("?city_plague:%+5.1f%% : %s"));
+
   illness = city_illness_calc(pcity, &ill_base, &ill_size, &ill_trade,
                               &ill_pollution);
 
-  cat_snprintf(buf, bufsz, _("%+5.1f : Risk from overcrowding\n"),
-               ((float)(ill_size) / 10.0));
-  cat_snprintf(buf, bufsz, _("%+5.1f : Risk from trade\n"),
-               ((float)(ill_trade) / 10.0));
-  cat_snprintf(buf, bufsz, _("%+5.1f : Risk from pollution\n"),
-               ((float)(ill_pollution) / 10.0));
+  city_sum_add(sum, (float)(ill_size) / 10.0,
+               Q_("?city_plague:Risk from overcrowding"));
+  city_sum_add(sum, (float)(ill_trade) / 10.0,
+               Q_("?city_plague:Risk from trade"));
+  city_sum_add(sum, (float)(ill_pollution) / 10.0,
+               Q_("?city_plague:Risk from pollution"));
 
   plist = effect_list_new();
 
@@ -669,16 +927,22 @@ void get_city_dialog_illness_text(const struct city *pcity,
       delta = peffect->value;
     }
 
-    cat_snprintf(buf, bufsz,
-                 (delta > 0) ? _("%+5.1f : Bonus from %s\n")
-                             : _("%+5.1f : Risk from %s\n"),
-                 -(0.1 * ill_base * delta / 100), buf2);
+    city_sum_add_full(sum, -(0.1 * ill_base * delta / 100), TRUE,
+                      Q_("?city_plague: (%+.0f%%)"), -delta,
+                      Q_("?city_plague:Risk from %s"),
+                      Q_("?city_plague:Bonus from %s"), buf2);
   } effect_list_iterate_end;
   effect_list_destroy(plist);
 
-  cat_snprintf(buf, bufsz, _("==== : Adds up to\n"));
-  cat_snprintf(buf, bufsz, _("%5.1f : Total chance for a plague"),
-               ((float)(illness) / 10.0));
+  /* XXX: account_for_unknown==FALSE: the displayed sum can fail to
+   * add up due to rounding. Making it always add up probably requires
+   * arbitrary assignment of 0.1% rounding figures to particular
+   * effects with something like distribute(). */
+  city_sum_print(sum, buf, bufsz, FALSE,
+                 Q_("?city_plague:"
+                    "====== : Adds up to\n"
+                    "%5.1f%% : Plague chance per turn"),
+                 ((double)(illness) / 10.0));
 }
 
 /**************************************************************************
@@ -688,6 +952,7 @@ void get_city_dialog_pollution_text(const struct city *pcity,
 				    char *buf, size_t bufsz)
 {
   int pollu, prod, pop, mod;
+  struct city_sum *sum = city_sum_new(Q_("?city_pollution:%+4.0f : %s"));
 
   /* On the server, pollution is calculated before production is deducted
    * for disorder; we need to compensate for that */
@@ -697,16 +962,13 @@ void get_city_dialog_pollution_text(const struct city *pcity,
 			       &prod, &pop, &mod);
   buf[0] = '\0';
 
-  cat_snprintf(buf, bufsz,
-	       _("%+4d : Pollution from shields\n"), prod);
-  cat_snprintf(buf, bufsz,
-	       _("%+4d : Pollution from citizens\n"), pop);
-  cat_snprintf(buf, bufsz,
-	       _("%+4d : Pollution modifier\n"), mod);
-  cat_snprintf(buf, bufsz,
-	       _("==== : Adds up to\n"));
-  cat_snprintf(buf, bufsz,
-	       _("%4d : Total surplus"), pollu);
+  city_sum_add(sum, prod, Q_("?city_pollution:Pollution from shields"));
+  city_sum_add(sum, pop,  Q_("?city_pollution:Pollution from citizens"));
+  city_sum_add(sum, mod,  Q_("?city_pollution:Pollution modifier"));
+  city_sum_print(sum, buf, bufsz, FALSE,
+                 Q_("?city_pollution:"
+	            "==== : Adds up to\n"
+	            "%4.0f : Total surplus"), (double)pollu);
 }
 
 /**************************************************************************
@@ -716,12 +978,13 @@ void get_city_dialog_culture_text(const struct city *pcity,
                                   char *buf, size_t bufsz)
 {
   struct effect_list *plist;
-  int total_performance = 0;
+  struct city_sum *sum = city_sum_new(Q_("?city_culture:%4.0f : %s"));
 
   buf[0] = '\0';
 
-  cat_snprintf(buf, bufsz,
-               _("%4d : History\n"), pcity->history);
+  /* XXX: no way to check whether client's idea of gain/turn is accurate */
+  city_sum_add(sum, pcity->history, Q_("?city_culture:History (%+d/turn)"),
+               city_history_gain(pcity));
 
   plist = effect_list_new();
 
@@ -747,27 +1010,15 @@ void get_city_dialog_culture_text(const struct city *pcity,
     }
 
     value = (peffect->value * mul) / 100;
-    cat_snprintf(buf, bufsz, _("%4d : %s\n"), value, buf2);
-    total_performance += value;
+    /* TRANS: text describing source of culture bonus ("Library+Republic") */
+    city_sum_add_if_nonzero(sum, value, Q_("?city_culture:%s"), buf2);
   } effect_list_iterate_end;
   effect_list_destroy(plist);
 
-  /* This probably ought not to happen in well-designed rulesets, but it's
-   * possible for incomplete client knowledge to give an inaccurate
-   * breakdown. If it does happen, at least acknowledge to the user that
-   * we are confused, rather than displaying an incorrect sum. */
-  if (total_performance != pcity->client.culture - pcity->history) {
-    cat_snprintf(buf, bufsz,
-                 /* TRANS: City culture that we cannot explain.
-                  * Unlikely to happen. */
-                 _("%4d : (unknown)\n"),
-                 pcity->client.culture - pcity->history - total_performance);
-  }
-
-  cat_snprintf(buf, bufsz,
-	       _("==== : Adds up to\n"));
-  cat_snprintf(buf, bufsz,
-	       _("%4d : Total culture"), pcity->client.culture);
+  city_sum_print(sum, buf, bufsz, TRUE,
+                 Q_("?city_culture:"
+                    "==== : Adds up to\n"
+	            "%4.0f : Total culture"), (double)pcity->client.culture);
 }
 
 /**************************************************************************
