@@ -1,39 +1,32 @@
-/***********************************************************************
+/**********************************************************************
 Freeciv - Copyright (C) 2004 - The Freeciv Project
    This program is free software; you can redistribute it and / or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This program is distributed in the hope that it will be useful, 
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-***********************************************************************/
+***********************************************************************/ 
 #ifdef HAVE_CONFIG_H
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <fcntl.h>
 #include <stdio.h>
 #include <signal.h>             /* SIGTERM and kill */
 #include <string.h>
 #include <time.h>
 
-/* Must be before <windows.h> */
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
-
 #ifdef WIN32_NATIVE
 #include <windows.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
+#ifdef FREECIV_HAVE_SYS_TYPES_H
 #include <sys/types.h>		/* fchmod */
 #endif
 
@@ -48,6 +41,7 @@ Freeciv - Copyright (C) 2004 - The Freeciv Project
 /* utility */
 #include "astring.h"
 #include "capability.h"
+#include "deprecations.h"
 #include "fciconv.h"
 #include "fcintl.h"
 #include "ioz.h"
@@ -81,10 +75,10 @@ Freeciv - Copyright (C) 2004 - The Freeciv Project
 
 #ifdef HAVE_USABLE_FORK
 static pid_t server_pid = -1;
-#elif WIN32_NATIVE
+#elif FREECIV_MSWINDOWS
 HANDLE server_process = INVALID_HANDLE_VALUE;
 HANDLE loghandle = INVALID_HANDLE_VALUE;
-#endif
+#endif /* HAVE_USABLE_FORK || FREECIV_MSWINDOWS */
 bool server_quitting = FALSE;
 
 static char challenge_fullname[MAX_LEN_PATH];
@@ -127,7 +121,7 @@ bool is_server_running(void)
   }
 #ifdef HAVE_USABLE_FORK
   return (server_pid > 0);
-#elif WIN32_NATIVE
+#elif FREECIV_MSWINDOWS
   return (server_process != INVALID_HANDLE_VALUE);
 #else
   return FALSE; /* We've been unable to start one! */
@@ -162,7 +156,7 @@ void client_kill_server(bool force)
     server_pid = -1;
     server_quitting = FALSE;
   }
-#elif WIN32_NATIVE
+#elif FREECIV_MSWINDOWS
   if (server_quitting && server_process != INVALID_HANDLE_VALUE) {
     /* Already asked to /quit.
      * If it didn't do that, kill it. */
@@ -175,7 +169,7 @@ void client_kill_server(bool force)
     loghandle = INVALID_HANDLE_VALUE;
     server_quitting = FALSE;
   }
-#endif /* WIN32_NATIVE || HAVE_USABLE_FORK */
+#endif /* FREECIV_MSWINDOWS || HAVE_USABLE_FORK */
 
   if (is_server_running()) {
     if (client.conn.used && client_has_hack) {
@@ -201,7 +195,7 @@ void client_kill_server(bool force)
       kill(server_pid, SIGTERM);
       waitpid(server_pid, NULL, WUNTRACED);
       server_pid = -1;
-#elif WIN32_NATIVE
+#elif FREECIV_MSWINDOWS
       TerminateProcess(server_process, 0);
       CloseHandle(server_process);
       if (loghandle != INVALID_HANDLE_VALUE) {
@@ -209,7 +203,7 @@ void client_kill_server(bool force)
       }
       server_process = INVALID_HANDLE_VALUE;
       loghandle = INVALID_HANDLE_VALUE;
-#endif /* WIN32_NATIVE || HAVE_USABLE_FORK */
+#endif /* FREECIV_MSWINDOWS || HAVE_USABLE_FORK */
       server_quitting = FALSE;
     }
   }
@@ -237,10 +231,11 @@ bool client_start_server(void)
   char savesdir[MAX_LEN_PATH];
   char scensdir[MAX_LEN_PATH];
   char options[512];
-#ifdef DEBUG
+  char *depr;
+#ifdef FREECIV_DEBUG
   char cmdline1[512];
   char cmdline2[512];
-#endif /* DEBUG */
+#endif /* FREECIV_DEBUG */
   char cmdline3[512];
   char cmdline4[512];
   char logcmdline[512];
@@ -250,11 +245,11 @@ bool client_start_server(void)
   char scenscmdline[512];
 #endif /* !HAVE_USABLE_FORK -> WIN32_NATIVE */
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   enum fc_addr_family family = FC_ADDR_ANY;
 #else
   enum fc_addr_family family = FC_ADDR_IPV4;
-#endif /* IPV6_SUPPORT */
+#endif /* FREECIV_IPV6_SUPPORT */
 
   /* only one server (forked from this client) shall be running at a time */
   /* This also resets client_has_hack. */
@@ -280,7 +275,7 @@ bool client_start_server(void)
 #ifdef HAVE_USABLE_FORK
   {
     int argc = 0;
-    const int max_nargs = 22;
+    const int max_nargs = 23;
     char *argv[max_nargs + 1];
     char port_buf[32];
     char dbg_lvl_buf[32]; /* Do not move this inside the block where it gets filled,
@@ -298,17 +293,16 @@ bool client_start_server(void)
     argv[argc++] = "1";
     argv[argc++] = "-e";
     argv[argc++] = "--saves";
-    argv[argc++] = "~/.freeciv/saves";
+    argv[argc++] = "~" DIR_SEPARATOR ".freeciv" DIR_SEPARATOR "saves";
     argv[argc++] = "--scenarios";
-    argv[argc++] = "~/.freeciv/scenarios";
+    argv[argc++] = "~" DIR_SEPARATOR ".freeciv" DIR_SEPARATOR "scenarios";
     argv[argc++] = "-A";
     argv[argc++] = "none";
     if (logfile) {
       enum log_level llvl = log_get_level();
 
       argv[argc++] = "--debug";
-      /* Use of LOG_DEBUG would require limiting also the logged files. */
-      fc_snprintf(dbg_lvl_buf, sizeof(dbg_lvl_buf), "%d", llvl < LOG_DEBUG ? llvl : LOG_DEBUG - 1);
+      fc_snprintf(dbg_lvl_buf, sizeof(dbg_lvl_buf), "%d", llvl);
       argv[argc++] = dbg_lvl_buf;
       argv[argc++] = "--log";
       argv[argc++] = logfile;
@@ -321,18 +315,22 @@ bool client_start_server(void)
       argv[argc++] = "--file";
       argv[argc++] = savefile;
     }
+    if (are_deprecation_warnings_enabled()) {
+      argv[argc++] = "--warnings";
+    }
     argv[argc] = NULL;
     fc_assert(argc <= max_nargs);
 
     {
-      struct astring options = ASTRING_INIT;
+      struct astring srv_cmdline_opts = ASTRING_INIT;
       int i;
+
       for (i = 1; i < argc; i++) {
-        astr_add(&options, i == 1 ? "%s" : " %s", argv[i]);
+        astr_add(&srv_cmdline_opts, i == 1 ? "%s" : " %s", argv[i]);
       }
       log_verbose("Arguments to spawned server: %s",
-                  astr_str(&options));
-      astr_free(&options);
+                  astr_str(&srv_cmdline_opts));
+      astr_free(&srv_cmdline_opts);
     }
 
     server_pid = fork();
@@ -413,9 +411,7 @@ bool client_start_server(void)
     enum log_level llvl = log_get_level();
 
     fc_snprintf(logcmdline, sizeof(logcmdline), " --debug %d --log %s",
-                /* Use of LOG_DEBUG would require limiting also the logged files. */
-                llvl < LOG_DEBUG ? llvl : LOG_DEBUG - 1,
-                logfile_in_local_encoding);
+                llvl, logfile_in_local_encoding);
     free(logfile_in_local_encoding);
   }
   if (scriptfile) {
@@ -435,17 +431,25 @@ bool client_start_server(void)
     free(savefile_in_local_encoding);
   }
 
-  interpret_tilde(savesdir, sizeof(savesdir), "~/.freeciv/saves");
+  interpret_tilde(savesdir, sizeof(savesdir),
+                  "~" DIR_SEPARATOR ".freeciv" DIR_SEPARATOR "saves");
   internal_to_local_string_buffer(savesdir, savescmdline, sizeof(savescmdline));
 
-  interpret_tilde(scensdir, sizeof(scensdir), "~/.freeciv/scenarios");
+  interpret_tilde(scensdir, sizeof(scensdir),
+                  "~" DIR_SEPARATOR ".freeciv" DIR_SEPARATOR "scenarios");
   internal_to_local_string_buffer(scensdir, scenscmdline, sizeof(scenscmdline));
 
+  if (are_deprecation_warnings_enabled()) {
+    depr = " --warnings";
+  } else {
+    depr = "";
+  }
+
   fc_snprintf(options, sizeof(options),
               "-p %d --bind localhost -q 1 -e%s%s%s --saves \"%s\" "
-              "--scenarios \"%s\" -A none",
+              "--scenarios \"%s\" -A none %s",
               internal_server_port, logcmdline, scriptcmdline, savefilecmdline,
-              savescmdline, scenscmdline);
+              savescmdline, scenscmdline, depr);
 #ifdef DEBUG
   fc_snprintf(cmdline1, sizeof(cmdline1), "./fcser %s", options);
   fc_snprintf(cmdline2, sizeof(cmdline2),
@@ -545,16 +549,16 @@ bool client_start_server(void)
    * Don't send it now, it will be sent to the server when receiving the
    * server setting infos. */
   {
-    char buf[16];
+    char topobuf[16];
 
-    fc_strlcpy(buf, "WRAPX", sizeof(buf));
+    fc_strlcpy(topobuf, "WRAPX", sizeof(topobuf));
     if (tileset_is_isometric(tileset) && 0 == tileset_hex_height(tileset)) {
-      fc_strlcat(buf, "|ISO", sizeof(buf));
+      fc_strlcat(topobuf, "|ISO", sizeof(topobuf));
     }
     if (0 < tileset_hex_width(tileset) || 0 < tileset_hex_height(tileset)) {
-      fc_strlcat(buf, "|HEX", sizeof(buf));
+      fc_strlcat(topobuf, "|HEX", sizeof(topobuf));
     }
-    desired_settable_option_update("topology", buf, FALSE);
+    desired_settable_option_update("topology", topobuf, FALSE);
   }
 
   return TRUE;
@@ -596,7 +600,7 @@ void send_client_wants_hack(const char *filename)
 
     /* get the full filename path */
     interpret_tilde(challenge_fullname, sizeof(challenge_fullname),
-		    "~/.freeciv/");
+                    "~" DIR_SEPARATOR ".freeciv" DIR_SEPARATOR);
     make_dir(challenge_fullname);
 
     sz_strlcat(challenge_fullname, filename);
@@ -676,7 +680,7 @@ void handle_ruleset_choices(const struct packet_ruleset_choices *packet)
       rulesets[i][len - suf_len] = '\0';
     }
   }
-  gui_set_rulesets(packet->ruleset_count, rulesets);
+  set_rulesets(packet->ruleset_count, rulesets);
 
   for (i = 0; i < packet->ruleset_count; i++) {
     free(rulesets[i]);
@@ -685,7 +689,7 @@ void handle_ruleset_choices(const struct packet_ruleset_choices *packet)
 
 /**************************************************************************
   Called by the GUI code when the user sets the ruleset.  The ruleset
-  passed in here should match one of the strings given to gui_set_rulesets.
+  passed in here should match one of the strings given to set_rulesets().
 **************************************************************************/
 void set_ruleset(const char *ruleset)
 {
