@@ -44,6 +44,22 @@ void canvas_free(struct canvas *store)
   free(store);
 }
 
+/****************************************************************************
+  Set canvas zoom for future drawing operations.
+****************************************************************************/
+void canvas_set_zoom(struct canvas *store, float zoom)
+{
+  /* gtk2-client has no zoom support */
+}
+
+/****************************************************************************
+  This gui has zoom support.
+****************************************************************************/
+bool has_zoom_support(void)
+{
+  return FALSE;
+}
+
 /****************************************************************************
   Copies an area from the source canvas to the destination canvas.
 ****************************************************************************/
@@ -212,27 +228,6 @@ void canvas_fill_sprite_area(struct canvas *pcanvas,
   }
 }
 
-/****************************************************************************
-  Fill the area covered by the sprite with the given color.
-****************************************************************************/
-void canvas_fog_sprite_area(struct canvas *pcanvas, struct sprite *psprite,
-			    int canvas_x, int canvas_y)
-{
-  if (pcanvas->type == CANVAS_PIXMAP) {
-    gdk_gc_set_clip_origin(fill_tile_gc, canvas_x, canvas_y);
-    gdk_gc_set_clip_mask(fill_tile_gc, sprite_get_mask(psprite));
-    gdk_gc_set_foreground(fill_tile_gc,
-			  &get_color(tileset, COLOR_MAPVIEW_UNKNOWN)->color);
-    gdk_gc_set_stipple(fill_tile_gc, black50);
-    gdk_gc_set_ts_origin(fill_tile_gc, canvas_x, canvas_y);
-
-    gdk_draw_rectangle(pcanvas->v.pixmap, fill_tile_gc, TRUE,
-		       canvas_x, canvas_y, psprite->width, psprite->height);
-
-    gdk_gc_set_clip_mask(fill_tile_gc, NULL); 
-  }
-}
-
 /****************************************************************************
   Draw a colored line onto the mapview or citydialog canvas.
 ****************************************************************************/
