@@ -32,7 +32,7 @@
 /* client */
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-2.0 */
 #include "dialogs.h"
 #include "gui_main.h"
 #include "gui_stuff.h"
@@ -48,7 +48,7 @@ static void update_find_dialog(GtkListStore *store);
 static void find_response(struct gui_dialog *dlg, int response, gpointer data);
 static void find_destroy_callback(GtkWidget *w, gpointer data);
 static void find_selection_callback(GtkTreeSelection *selection,
-                                    GtkTreeModel *model);
+				    GtkTreeModel *model);
 
 static struct tile *pos;
 
@@ -72,10 +72,10 @@ void popup_find_dialog(void)
     gui_dialog_set_title(find_dialog_shell, _("Find City"));
     gui_dialog_set_default_size(find_dialog_shell, -1, 240);
 
-    gui_dialog_add_button(find_dialog_shell, "edit-find", _("Find"),
-                          GTK_RESPONSE_ACCEPT);
-    gui_dialog_add_button(find_dialog_shell, NULL, _("Cancel"),
-                          GTK_RESPONSE_CANCEL);
+    gui_dialog_add_button(find_dialog_shell,
+	GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+    gui_dialog_add_button(find_dialog_shell,
+	GTK_STOCK_FIND, GTK_RESPONSE_ACCEPT);
 
     gui_dialog_set_default_response(find_dialog_shell, GTK_RESPONSE_ACCEPT);
 
@@ -101,23 +101,21 @@ void popup_find_dialog(void)
     gtk_tree_view_append_column(GTK_TREE_VIEW(find_view), column);
 
     sw = gtk_scrolled_window_new(NULL, NULL);
-    g_object_set(sw, "margin", 2, NULL);
     gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
 	GTK_SHADOW_ETCHED_IN);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
     gtk_container_add(GTK_CONTAINER(sw), find_view);
 
-    gtk_widget_set_hexpand(GTK_WIDGET(find_view), TRUE);
-    gtk_widget_set_vexpand(GTK_WIDGET(find_view), TRUE);
-
     label = g_object_new(GTK_TYPE_LABEL,
 	"use-underline", TRUE,
 	"mnemonic-widget", find_view,
 	"label", _("Ci_ties:"),
 	"xalign", 0.0, "yalign", 0.5, NULL);
-    gtk_container_add(GTK_CONTAINER(find_dialog_shell->vbox), label);
-    gtk_container_add(GTK_CONTAINER(find_dialog_shell->vbox), sw);
+    gtk_box_pack_start(GTK_BOX(find_dialog_shell->vbox), label,
+	FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(find_dialog_shell->vbox), sw,
+	TRUE, TRUE, 2);
 
     g_signal_connect(selection, "changed",
 	G_CALLBACK(find_selection_callback), store);
