@@ -43,7 +43,7 @@
 #include "options.h"
 #include "text.h"
 
-/* clien/gui-gtk-3.22 */
+/* clien/gui-gtk-2.0 */
 #include "plrdlg.h"
 #include "dialogs.h"
 #include "gui_main.h"
@@ -60,7 +60,6 @@ static GtkWidget *all_toggle;
 static GtkListStore *goto_list_store;
 static GtkTreeSelection *goto_list_selection;
 struct tile *original_tile;
-static bool gotodlg_updating = FALSE;
 
 static void update_goto_dialog(GtkToggleButton *button);
 static void update_source_label(void);
@@ -139,15 +138,15 @@ static void create_goto_dialog(void)
   GtkTreeViewColumn *col;
 
   dshell = gtk_dialog_new_with_buttons(_("Goto/Airlift Unit"),
-                                       NULL,
-                                       0,
-                                       _("Cancel"),
-                                       GTK_RESPONSE_CANCEL,
-                                       _("Air_lift"),
-                                       CMD_AIRLIFT,
-                                       _("_Goto"),
-                                       CMD_GOTO,
-                                       NULL);
+    NULL,
+    0,
+    GTK_STOCK_CANCEL,
+    GTK_RESPONSE_CANCEL,
+    _("Air_lift"),
+    CMD_AIRLIFT,
+    _("_Goto"),
+    CMD_GOTO,
+    NULL);
   setup_dialog(dshell, toplevel);
   gtk_window_set_position(GTK_WINDOW(dshell), GTK_WIN_POS_MOUSE);
   gtk_dialog_set_default_response(GTK_DIALOG(dshell), CMD_GOTO);
@@ -159,7 +158,7 @@ static void create_goto_dialog(void)
   source = gtk_label_new("" /* filled in later */);
   gtk_label_set_line_wrap(GTK_LABEL(source), TRUE);
   gtk_label_set_justify(GTK_LABEL(source), GTK_JUSTIFY_CENTER);
-  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dshell)->vbox),
         source, FALSE, FALSE, 0);
 
   label = g_object_new(GTK_TYPE_LABEL,
@@ -170,13 +169,10 @@ static void create_goto_dialog(void)
     NULL);
   frame = gtk_frame_new("");
   gtk_frame_set_label_widget(GTK_FRAME(frame), label);
-  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dshell)->vbox),
         frame, TRUE, TRUE, 0);
 
-  vbox = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
-                                 GTK_ORIENTATION_VERTICAL);
-  gtk_grid_set_row_spacing(GTK_GRID(vbox), 6);
+  vbox = gtk_vbox_new(FALSE, 6);
   gtk_container_add(GTK_CONTAINER(frame), vbox);
 
   goto_list_store = gtk_list_store_new(GD_COL_NUM, G_TYPE_INT, G_TYPE_STRING,
@@ -185,8 +181,6 @@ static void create_goto_dialog(void)
                                        GD_COL_CITY_NAME, GTK_SORT_ASCENDING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(goto_list_store));
-  gtk_widget_set_hexpand(view, TRUE);
-  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(goto_list_store);
   goto_list_selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), TRUE);
@@ -231,19 +225,21 @@ static void create_goto_dialog(void)
   gtk_container_add(GTK_CONTAINER(sw), view);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
     GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-  gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), 200);
+  gtk_widget_set_size_request(sw, -1, 200);
 
-  gtk_container_add(GTK_CONTAINER(vbox), sw);
+  gtk_box_pack_start(GTK_BOX(vbox), sw, TRUE, TRUE, 0);
 
   all_toggle = gtk_check_button_new_with_mnemonic(_("Show _All Cities"));
-  gtk_container_add(GTK_CONTAINER(vbox), all_toggle);
+  gtk_box_pack_start(GTK_BOX(vbox), all_toggle, FALSE, FALSE, 0);
 
   g_signal_connect(all_toggle, "toggled", G_CALLBACK(update_goto_dialog), NULL);
 
   g_signal_connect(goto_list_selection, "changed",
     G_CALLBACK(goto_selection_callback), NULL);
 
-  gtk_widget_show_all(dshell);
+  gtk_widget_show_all(GTK_DIALOG(dshell)->vbox);
+  gtk_widget_show_all(GTK_DIALOG(dshell)->action_area);
+
 
   original_tile = get_center_tile_mapcanvas();
 
@@ -432,16 +428,14 @@ static void update_source_label(void)
 static void update_goto_dialog(GtkToggleButton *button)
 {
   bool nonempty = FALSE;
-  
+
+  gtk_list_store_clear(goto_list_store);
+
   if (!client_has_player()) {
     /* Case global observer. */
     return;
   }
 
-  gotodlg_updating = TRUE;
-
-  gtk_list_store_clear(goto_list_store);
-
   if (gtk_toggle_button_get_active(button)) {
     players_iterate(pplayer) {
       nonempty |= list_store_append_player_cities(goto_list_store, pplayer);
@@ -450,8 +444,6 @@ static void update_goto_dialog(GtkToggleButton *button)
     nonempty |= list_store_append_player_cities(goto_list_store, client_player());
   }
 
-  gotodlg_updating = FALSE;
-
   refresh_airlift_column();
 
   if (!nonempty) {
@@ -521,13 +513,7 @@ static void refresh_airlift_button(void)
 static void goto_selection_callback(GtkTreeSelection *selection,
                                     gpointer data)
 {
-  struct city *pdestcity;
-
-  if (gotodlg_updating) {
-    return;
-  }
-
-  pdestcity = get_selected_city();
+  struct city *pdestcity = get_selected_city();
 
   if (NULL != pdestcity) {
     center_tile_mapcanvas(city_tile(pdestcity));
