@@ -27,10 +27,6 @@
 #include "audio.h"
 #include "client_main.h"
 
-/* client/gui-gtk-3.0 */
-#include "gui_main.h"
-#include "gui_stuff.h"
-
 #include "dialogs_g.h"
 
 static void soundset_suggestion_callback(GtkWidget *dlg, gint arg);
@@ -43,8 +39,7 @@ static void soundset_suggestion_callback(GtkWidget *dlg, gint arg)
 {
   if (arg == GTK_RESPONSE_YES) {
     /* User accepted soundset loading */
-    audio_restart(game.control.preferred_soundset,
-                  music_set_name);
+    audio_restart(game.control.preferred_soundset, music_set_name);
   }
 }
 
@@ -60,12 +55,11 @@ void popup_soundset_suggestion_dialog(void)
   dialog = gtk_dialog_new_with_buttons(_("Preferred soundset"),
                                        NULL,
                                        0,
-                                       _("Load soundset"),
+                                       _("_Load soundset"),
                                        GTK_RESPONSE_YES,
-                                       _("Keep current soundset"),
+                                       _("_Keep current soundset"),
                                        GTK_RESPONSE_NO,
                                        NULL);
-  setup_dialog(dialog, toplevel);
   gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_YES);
   gtk_window_set_destroy_with_parent(GTK_WINDOW(dialog), TRUE);
 
@@ -76,7 +70,7 @@ void popup_soundset_suggestion_dialog(void)
               game.control.preferred_soundset, sound_set_name);
 
   label = gtk_label_new(buf);
-  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
+  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
   gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
   gtk_widget_show(label);
 
@@ -114,9 +108,9 @@ void popup_musicset_suggestion_dialog(void)
   dialog = gtk_dialog_new_with_buttons(_("Preferred musicset"),
                                        NULL,
                                        0,
-                                       _("Load musicset"),
+                                       _("_Load musicset"),
                                        GTK_RESPONSE_YES,
-                                       _("Keep current musicset"),
+                                       _("_Keep current musicset"),
                                        GTK_RESPONSE_NO,
                                        NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_YES);
@@ -129,7 +123,7 @@ void popup_musicset_suggestion_dialog(void)
               game.control.preferred_musicset, music_set_name);
 
   label = gtk_label_new(buf);
-  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))), label);
+  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
   gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
   gtk_widget_show(label);
 
