@@ -43,7 +43,7 @@
 #include "mapview.h"
 #include "packhand.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "citydlg.h"
 #include "dialogs.h"
 #include "unitselunitdlg.h"
@@ -508,10 +508,13 @@ static void create_advances_list(struct player *pplayer,
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
 
   spy_tech_shell = gtk_dialog_new_with_buttons(_("Steal Technology"),
-                                               NULL, 0,
-                                               _("Cancel"), GTK_RESPONSE_CANCEL,
-                                               _("_Steal"), GTK_RESPONSE_ACCEPT,
-                                               NULL);
+    NULL,
+    0,
+    GTK_STOCK_CANCEL,
+    GTK_RESPONSE_CANCEL,
+    _("_Steal"),
+    GTK_RESPONSE_ACCEPT,
+    NULL);
   setup_dialog(spy_tech_shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(spy_tech_shell), GTK_WIN_POS_MOUSE);
 
@@ -690,10 +693,13 @@ static void create_improvements_list(struct player *pplayer,
   struct unit *actor_unit = game_unit_by_number(args->actor_unit_id);
   
   spy_sabotage_shell = gtk_dialog_new_with_buttons(_("Sabotage Improvements"),
-                                                   NULL, 0,
-                                                   _("Cancel"), GTK_RESPONSE_CANCEL,
-                                                   _("_Sabotage"), GTK_RESPONSE_ACCEPT,
-                                                   NULL);
+    NULL,
+    0,
+    GTK_STOCK_CANCEL,
+    GTK_RESPONSE_CANCEL,
+    _("_Sabotage"), 
+    GTK_RESPONSE_ACCEPT,
+    NULL);
   setup_dialog(spy_sabotage_shell, toplevel);
   gtk_window_set_position(GTK_WINDOW(spy_sabotage_shell), GTK_WIN_POS_MOUSE);
 
@@ -1150,7 +1156,7 @@ static void action_entry(GtkWidget *shl,
     return;
   }
 
-  label = action_prepare_ui_name(act_id, "",
+  label = action_prepare_ui_name(act_id, "_",
                                  act_probs[act_id],
                                  custom);
 
@@ -1181,7 +1187,7 @@ static void action_entry_update(GtkWidget *shl,
       action_prob_possible(act_probs[act_id]));
 
   /* The probability may have changed. */
-  label = action_prepare_ui_name(act_id, "",
+  label = action_prepare_ui_name(act_id, "_",
                                  act_probs[act_id], custom);
 
   tooltip = action_get_tool_tip(act_id,
@@ -1309,7 +1315,7 @@ void popup_action_selection(struct unit *actor_unit,
       || (!target_city && unit_has_type_flag(actor_unit, UTYF_CAPTURER))) {
     action_button_map[BUTTON_MOVE] =
         choice_dialog_get_number_of_buttons(shl);
-    choice_dialog_add(shl, _("Keep moving"),
+    choice_dialog_add(shl, _("_Keep moving"),
                       (GCallback)act_sel_keep_moving_callback,
                       data, FALSE, NULL);
   }
@@ -1331,13 +1337,13 @@ void popup_action_selection(struct unit *actor_unit,
 
   action_button_map[BUTTON_WAIT] =
       choice_dialog_get_number_of_buttons(shl);
-  choice_dialog_add(shl, _("Wait"),
+  choice_dialog_add(shl, _("_Wait"),
                     (GCallback)act_sel_wait_callback, data,
                     TRUE, NULL);
 
   action_button_map[BUTTON_CANCEL] =
       choice_dialog_get_number_of_buttons(shl);
-  choice_dialog_add(shl, _("Cancel"),
+  choice_dialog_add(shl, GTK_STOCK_CANCEL,
                     (GCallback)act_sel_cancel_callback, data,
                     FALSE, NULL);
 
