@@ -21,8 +21,6 @@
 
 #include <gtk/gtk.h>
 
-#include "gtkpixcomm.h"
-
 /* utility */
 #include "log.h"
 #include "mem.h"
@@ -53,19 +51,17 @@ struct sprite *radar_gfx_sprite;
 GdkCursor *fc_cursors[CURSOR_LAST][NUM_CURSOR_FRAMES];
 
 /***************************************************************************
-  Returns TRUE to indicate that gtk-client supports isometric view
+  Returns TRUE to indicate that gtk3-client supports given view type
 ***************************************************************************/
-bool isometric_view_supported(void)
+bool is_view_supported(enum ts_type type)
 {
-  return TRUE;
-}
+  switch (type) {
+  case TS_ISOMETRIC:
+  case TS_OVERHEAD:
+    return TRUE;
+  }
 
-/***************************************************************************
-  Returns TRUE to indicate that gtk-client supports overhead view
-***************************************************************************/
-bool overhead_view_supported(void)
-{
-  return TRUE;
+  return FALSE;
 }
 
 #define COLOR_MOTTO_FACE_R    0x2D
