@@ -1,4 +1,4 @@
-/***********************************************************************
+/********************************************************************** 
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "log.h"
 #include "mem.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 
@@ -52,6 +52,14 @@ static void input_dialog_response(GtkDialog *shell, gint response,
   FC_FREE(cb);
 }
 
+/**************************************************************************
+  Called when user closes dialog with key (Esc).
+**************************************************************************/
+static void input_dialog_close(GtkDialog *shell, gpointer data)
+{
+  input_dialog_response(shell, GTK_RESPONSE_CANCEL, data);
+}
+
 /**************************************************************************
   Create a popup with a text entry box and "OK" and "Cancel" buttons.
 **************************************************************************/
@@ -65,16 +73,17 @@ GtkWidget *input_dialog_create(GtkWindow *parent, const char *dialogname,
 
   cb->response_callback = response_callback;
   cb->response_cli_data = response_cli_data;
-
+  
   shell = gtk_dialog_new_with_buttons(dialogname,
-                                      parent,
-                                      GTK_DIALOG_DESTROY_WITH_PARENT,
-                                      _("Cancel"), GTK_RESPONSE_CANCEL,
-                                      _("OK"), GTK_RESPONSE_OK,
-                                      NULL);
+        parent,
+        GTK_DIALOG_DESTROY_WITH_PARENT,
+        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+        GTK_STOCK_OK, GTK_RESPONSE_OK,
+        NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(shell), GTK_RESPONSE_OK);
   setup_dialog(shell, GTK_WIDGET(parent));
   g_signal_connect(shell, "response", G_CALLBACK(input_dialog_response), cb);
+  g_signal_connect(shell, "close", G_CALLBACK(input_dialog_close), cb);
   gtk_window_set_position(GTK_WINDOW(shell), GTK_WIN_POS_CENTER_ON_PARENT);
 
   label = gtk_frame_new(text);
