@@ -36,7 +36,7 @@
 #include "client_main.h"
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "mapview.h"
@@ -95,7 +95,7 @@ static struct intel_dialog *create_intel_dialog(struct player *p);
 /****************************************************************
   Initialize intelligenze dialogs
 *****************************************************************/
-void intel_dialog_init()
+void intel_dialog_init(void)
 {
   dialog_list = dialog_list_new();
 }
@@ -103,7 +103,7 @@ void intel_dialog_init()
 /****************************************************************
   Free resources allocated for intelligenze dialogs
 *****************************************************************/
-void intel_dialog_done()
+void intel_dialog_done(void)
 {
   dialog_list_destroy(dialog_list);
 }
@@ -171,17 +171,18 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   GtkWidget *shell, *notebook, *label, *sw, *view, *table;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
-  int i;
 
+  int i;
+ 
   pdialog = fc_malloc(sizeof(*pdialog));
   pdialog->pplayer = p;
-
+ 
   shell = gtk_dialog_new_with_buttons(NULL,
-                                      NULL,
-                                      0,
-                                      _("_Close"),
-                                      GTK_RESPONSE_CLOSE,
-                                      NULL);
+      NULL,
+      0,
+      GTK_STOCK_CLOSE,
+      GTK_RESPONSE_CLOSE,
+      NULL);
   pdialog->shell = shell;
   gtk_window_set_default_size(GTK_WINDOW(shell), 350, 350);
   setup_dialog(shell, toplevel);
