@@ -1,4 +1,4 @@
-/***********************************************************************
+/********************************************************************** 
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 /* client */
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "colors.h"
 #include "gui_main.h"
 #include "gui_stuff.h"
@@ -69,8 +69,8 @@ static void create_messageopt_dialog(void)
 
   gui_dialog_set_default_size(shell, -1, 450);
 
-  gui_dialog_add_button(shell, NULL, _("OK"), GTK_RESPONSE_OK);
-  gui_dialog_add_button(shell, NULL, _("Cancel"), GTK_RESPONSE_CANCEL);
+  gui_dialog_add_button(shell, GTK_STOCK_OK, GTK_RESPONSE_OK);
+  gui_dialog_add_button(shell, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
   explanation = gtk_label_new(NULL);
   g_object_set(explanation, "margin", 4, NULL);
