@@ -13,9 +13,6 @@
 #ifndef FC__OPTIONDLG_H
 #define FC__OPTIONDLG_H
 
-#include <gtk/gtk.h>
-
-void popup_option_dialog(void);
-void toggle_callback(GtkWidget *w, gpointer data);
+#include "optiondlg_g.h"
 
 #endif  /* FC__OPTIONDLG_H */
