@@ -573,17 +573,14 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       dlg->v.window = window;
       g_signal_connect(window, "delete_event",
         G_CALLBACK(gui_dialog_delete_handler), dlg);
-      
+
     }
     break;
   case GUI_DIALOG_TAB:
     {
       GtkWidget *hbox, *label, *image, *button, *event_box;
-      gint w, h;
       gchar *buf;
 
-      gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &w, &h);
-
       hbox = gtk_grid_new();
 
       label = gtk_label_new(NULL);
@@ -598,7 +595,7 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       button = gtk_button_new();
       gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
       g_signal_connect_swapped(button, "clicked",
-	  G_CALLBACK(gui_dialog_delete_tab_handler), dlg);
+                               G_CALLBACK(gui_dialog_delete_tab_handler), dlg);
 
       buf = g_strdup_printf(_("Close Tab:\n%s"), _("Ctrl+W"));
       gtk_widget_set_tooltip_text(button, buf);
@@ -621,8 +618,8 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
 
       gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox, event_box);
       dlg->v.tab.handler_id =
-	g_signal_connect(notebook, "switch-page",
-	    G_CALLBACK(gui_dialog_switch_page_handler), dlg);
+        g_signal_connect(notebook, "switch-page",
+                         G_CALLBACK(gui_dialog_switch_page_handler), dlg);
       dlg->v.tab.child = vbox;
 
       gtk_style_context_add_provider(gtk_widget_get_style_context(label),
@@ -630,7 +627,7 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
                                      GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
       dlg->v.tab.label = label;
       dlg->v.tab.notebook = GTK_WIDGET(notebook);
-      
+
       gtk_widget_add_events(event_box, GDK_BUTTON2_MOTION_MASK);
       g_signal_connect(event_box, "button-press-event",
                        G_CALLBACK(click_on_tab_callback), dlg);
