@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,21 +34,25 @@
 #include "player.h"
 
 /* client */
-#include "chatline.h"
 #include "client_main.h"
 #include "climisc.h"
 #include "connectdlg_common.h"
-#include "dialogs.h"
-#include "gui_main.h"
-#include "gui_stuff.h"
-#include "inteldlg.h"
-#include "spaceshipdlg.h"
 #include "tilespec.h"
 #include "colors.h"
 #include "graphics.h"
 #include "options.h"
 #include "text.h"
 
+/* client/gui-gtk-3.22 */
+#include "chatline.h"
+#include "dialogs.h"
+#include "gui_main.h"
+#include "gui_stuff.h"
+#include "inteldlg.h"
+#include "spaceshipdlg.h"
+#include "colors.h"
+#include "graphics.h"
+
 #include "plrdlg.h"
 
 struct gui_dialog *players_dialog_shell;
@@ -110,28 +114,33 @@ GdkPixbuf *create_player_icon(const struct player *plr)
 {
   int width, height;
   GdkPixbuf *tmp;
-  GdkPixmap *pixmap;
+  cairo_surface_t *surface;
+  struct color *color;
+  cairo_t *cr;
 
   if (!player_has_color(tileset, plr)) {
     return NULL;
   }
 
   gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &width, &height);
+  surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, width, height);
 
-  pixmap = gdk_pixmap_new(root_window, width, height, -1);
+  cr = cairo_create(surface);
 
-  gdk_gc_set_foreground(civ_gc,
-                        &get_color(tileset,
-				   COLOR_PLAYER_COLOR_BACKGROUND)->color);
-  gdk_draw_rectangle(pixmap, civ_gc, TRUE, 0, 0, width, height);
+  color = get_color(tileset, COLOR_PLAYER_COLOR_BACKGROUND);
+  gdk_cairo_set_source_rgba(cr, &color->color);
+  cairo_rectangle(cr, 0, 0, width, height);
+  cairo_fill(cr);
 
-  gdk_gc_set_foreground(civ_gc, &get_player_color(tileset, plr)->color);
-  gdk_draw_rectangle(pixmap, civ_gc, TRUE, 1, 1, width - 2, height - 2);
+  color = get_player_color(tileset, plr);
+  gdk_cairo_set_source_rgba(cr, &color->color);
+  cairo_rectangle(cr, 1, 1, width - 2, height - 2);
+  cairo_fill(cr);
 
-  tmp = gdk_pixbuf_get_from_drawable(NULL, pixmap, NULL, 
-      0, 0, 0, 0, -1, -1);
+  cairo_destroy(cr);
+  tmp = surface_get_pixbuf(surface, width, height);
+  cairo_surface_destroy(surface);
 
-  g_object_unref(pixmap);
   return tmp;
 }
 
@@ -310,7 +319,7 @@ static void toggle_dead_players(GtkCheckMenuItem* item, gpointer data)
 {
   gui_options.player_dlg_show_dead_players = 
     gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(item));
-  real_players_dialog_update();
+  real_players_dialog_update(NULL);
 }
 
 /**************************************************************************
@@ -397,7 +406,7 @@ static GtkWidget* create_show_menu(void)
                                  gui_options.player_dlg_show_dead_players);
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
   g_signal_connect(item, "toggled", G_CALLBACK(toggle_dead_players), NULL);
-
+  
   return menu;
 }
 
@@ -416,8 +425,8 @@ void create_players_dialog(void)
   /* TRANS: Nations report title */
   gui_dialog_set_title(players_dialog_shell, _("Nations"));
 
-  gui_dialog_add_button(players_dialog_shell,
-      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+  gui_dialog_add_button(players_dialog_shell, "window-close", _("_Close"),
+                        GTK_RESPONSE_CLOSE);
 
   gui_dialog_set_default_size(players_dialog_shell, -1, 270);
 
@@ -425,6 +434,8 @@ void create_players_dialog(void)
 
   players_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL
                                               (players_dialog_store));
+  gtk_widget_set_hexpand(players_list, TRUE);
+  gtk_widget_set_vexpand(players_list, TRUE);
   g_object_unref(players_dialog_store);
   gtk_widget_set_name(players_list, "small_font");
 
@@ -502,21 +513,20 @@ void create_players_dialog(void)
 		                 GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
   gtk_container_add(GTK_CONTAINER(sw), players_list);
 
-  gtk_box_pack_start(GTK_BOX(players_dialog_shell->vbox), sw,
-		     TRUE, TRUE, 0);
+  gtk_container_add(GTK_CONTAINER(players_dialog_shell->vbox), sw);
 
-  vbox = gtk_vbox_new(FALSE, 0);
+  vbox = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
+                                 GTK_ORIENTATION_VERTICAL);
   
-  sep = gtk_hseparator_new();
-  gtk_box_pack_start(GTK_BOX(vbox), sep, FALSE, FALSE, 0);
+  sep = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
+  gtk_container_add(GTK_CONTAINER(vbox), sep);
 
   menubar = gtk_aux_menu_bar_new();
-  gtk_box_pack_start(GTK_BOX(vbox), menubar, TRUE, TRUE, 0);
+  gtk_container_add(GTK_CONTAINER(vbox), menubar);
 
 
   gui_dialog_add_widget(players_dialog_shell, vbox);
-  gtk_box_set_child_packing(GTK_BOX(players_dialog_shell->action_area), 
-                            vbox, FALSE, FALSE, 0, GTK_PACK_START);
 
   item = gtk_menu_item_new_with_mnemonic(_("Di_plomacy"));
   menu = create_diplomacy_menu();
@@ -562,7 +572,7 @@ void create_players_dialog(void)
 
   gui_dialog_show_all(players_dialog_shell);
 
-  real_players_dialog_update();
+  real_players_dialog_update(NULL);
 
   gui_dialog_set_default_response(players_dialog_shell,
     GTK_RESPONSE_CLOSE);
@@ -606,11 +616,14 @@ GdkPixbuf *get_flag(const struct nation_type *nation)
   /* croping */
   im = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, w, h);
   if (im != NULL) {
-    gdk_pixbuf_copy_area(sprite_get_pixbuf(flag), x0, y0, w, h,
+    GdkPixbuf *pixbuf = sprite_get_pixbuf(flag);
+
+    gdk_pixbuf_copy_area(pixbuf, x0, y0, w, h,
                          im, 0, 0);
+    g_object_unref(G_OBJECT(pixbuf));
   }
 
-  /* and finaly store the scaled flag pixbuf in the static flags array */
+  /* and finally store the scaled flag pixbuf in the static flags array */
   return im;
 }
 
@@ -698,7 +711,7 @@ static bool player_should_be_shown(const struct player *pplayer)
 /**************************************************************************
   Clear and refill the entire player list.
 **************************************************************************/
-void real_players_dialog_update(void)
+void real_players_dialog_update(void *unused)
 {
   GtkTreeModel *model;
   GtkTreeIter iter;
