@@ -81,9 +81,14 @@ void gui_clear_theme(void)
 
   /* still no theme loaded -> load system default theme */
   if (!theme_loaded) {
+    static GtkCssProvider *default_provider = NULL;
+
+    if (default_provider == NULL) {
+      default_provider = gtk_css_provider_new();
+    }
     gtk_style_context_add_provider_for_screen(
         gtk_widget_get_screen(toplevel),
-        GTK_STYLE_PROVIDER(gtk_css_provider_get_default()),
+        GTK_STYLE_PROVIDER(default_provider),
         GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   }
 }
