@@ -27,11 +27,12 @@
 /* client */
 #include "tilespec.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-3.22 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 
 #include "dialogs_g.h"
+
 extern char forced_tileset_name[512];
 static void tileset_suggestion_callback(GtkWidget *dlg, gint arg);
 
@@ -43,7 +44,7 @@ static void tileset_suggestion_callback(GtkWidget *dlg, gint arg)
   if (arg == GTK_RESPONSE_YES) {
     /* User accepted tileset loading */
     sz_strlcpy(forced_tileset_name, game.control.preferred_tileset);
-    if (!tilespec_reread(game.control.preferred_tileset, FALSE, 1.0)) {
+    if (!tilespec_reread(game.control.preferred_tileset, TRUE, 1.0)) {
       tileset_error(LOG_ERROR, _("Can't load requested tileset %s."),
                     game.control.preferred_tileset);
     }
@@ -62,9 +63,9 @@ void popup_tileset_suggestion_dialog(void)
   dialog = gtk_dialog_new_with_buttons(_("Preferred tileset"),
                                        NULL,
                                        0,
-                                       _("Load tileset"),
+                                       _("_Load tileset"),
                                        GTK_RESPONSE_YES,
-                                       _("Keep current tileset"),
+                                       _("_Keep current tileset"),
                                        GTK_RESPONSE_NO,
                                        NULL);
   setup_dialog(dialog, toplevel);
