@@ -1353,7 +1353,6 @@ void refresh_worklist(GtkWidget *editor)
   } else {
     selected = FALSE;
   }
-  gtk_list_store_clear(ptr->src);
 
   /* These behave just right if ptr->pcity is NULL -> in case of global
    * worklist. */
@@ -1361,21 +1360,49 @@ void refresh_worklist(GtkWidget *editor)
                                                       ptr->future);
   name_and_sort_items(targets, targets_used, items, FALSE, ptr->pcity);
 
+  /* Re-purpose existing items in the list store -- this avoids the
+   * UI jumping around (especially as the set of source tasks doesn't
+   * actually change much in practice). */
+  model = GTK_TREE_MODEL(ptr->src);
+  exists = gtk_tree_model_get_iter_first(model, &it);
+
   path = NULL;
   for (i = 0; i < targets_used; i++) {
-    gtk_list_store_append(ptr->src, &it);
+    if (!exists) {
+      gtk_list_store_append(ptr->src, &it);
+    }
+
     gtk_list_store_set(ptr->src, &it, 0, (gint) cid_encode(items[i].item), -1);
 
     if (selected && cid_encode(items[i].item) == id) {
       path = gtk_tree_model_get_path(GTK_TREE_MODEL(ptr->src), &it);
     }
+
+    if (exists) {
+      exists = gtk_tree_model_iter_next(model, &it);
+    }
   }
+
+  /* If the list got shorter, delete any excess items. */
+  if (exists) {
+    GtkTreeIter it_next;
+    bool more;
+
+    do {
+      it_next = it;
+      more = gtk_tree_model_iter_next(model, &it_next);
+
+      gtk_list_store_remove(ptr->src, &it);
+      it = it_next;
+    } while (more);
+  }
+
+  /* Select the same item that was previously selected, if any. */
   if (path) {
     gtk_tree_view_set_cursor(GTK_TREE_VIEW(ptr->src_view), path, NULL, FALSE);
     gtk_tree_path_free(path);
   }
 
-
   /* refresh target worklist. */
   model = GTK_TREE_MODEL(ptr->dst);
   exists = gtk_tree_model_get_iter_first(model, &it);
