@@ -95,7 +95,6 @@ private:
 public:
   static fc_icons* instance();
   static void drop();
-  QPixmapCache pixmap_cache;
   QIcon get_icon(const QString& id);
   QPixmap *get_pixmap(const QString& id);
   QString get_path(const QString& id);
@@ -277,6 +276,7 @@ public:
   fc_sidewidget *sw_indicators;
   fc_sidewidget *sw_diplo;
   float map_scale;
+  bool map_font_scale;
   void gimme_place(QWidget* widget, QString str);
   int gimme_index_of(QString str);
   void remove_repo_dlg(QString str);
@@ -334,6 +334,7 @@ private:
   bool check_server_scan(server_scan *scan_data);
   void update_load_page(void);
   void create_cursors(void);
+  void delete_cursors(void);
   void update_scenarios_page(void);
   void set_connection_state(enum connection_state state);
   void update_buttons();
@@ -373,6 +374,7 @@ public:
 
   void set_rulesets(int num_rulesets, char **rulesets);
   void set_aifill(int aifill);
+  void update_ai_level();
   void update_buttons();
 private slots:
   void max_players_change(int i);
