@@ -156,13 +156,11 @@ static bool parse_options(int argc, char **argv)
 **************************************************************************/
 static void migrate_options_from_2_5()
 {
-  if (!gui_options.first_boot) {
-    log_normal(_("Migrating Qt-client options from freeciv-2.5 options."));
+  log_normal(_("Migrating Qt-client options from freeciv-2.5 options."));
 
-    gui_options.gui_qt_fullscreen = gui_options.migrate_fullscreen;
+  gui_options.gui_qt_fullscreen = gui_options.migrate_fullscreen;
 
-    gui_options.gui_qt_migrated_from_2_5 = TRUE;
-  }
+  gui_options.gui_qt_migrated_from_2_5 = TRUE;
 }
 
 /**************************************************************************
@@ -181,10 +179,16 @@ void qtg_ui_main(int argc, char *argv[])
     qpm = get_icon_sprite(tileset, ICON_FREECIV)->pm;
     app_icon = ::QIcon(*qpm);
     qapp->setWindowIcon(app_icon);
-    if (!gui_options.gui_qt_migrated_from_2_5) {
+    if (gui_options.first_boot) {
+      /* We're using fresh defaults for this version of this client,
+       * so prevent any future migrations from other versions */
+      gui_options.gui_qt_migrated_from_2_5 = TRUE;
+    } else if (!gui_options.gui_qt_migrated_from_2_5) {
       migrate_options_from_2_5();
     }
-    load_theme(gui_options.gui_qt_default_theme_name);
+    if (!load_theme(gui_options.gui_qt_default_theme_name)) {
+      qtg_gui_clear_theme();
+    }
     freeciv_qt = new fc_client();
     freeciv_qt->fc_main(qapp);
   }
@@ -359,7 +363,7 @@ void apply_titlebar(struct option *poption)
     return;
   }
 
-  if (val == true) {
+  if (val) {
     w = new QWidget();
     gui()->setWindowFlags(flags);
     delete gui()->corner_wid;
@@ -565,11 +569,3 @@ void qtg_insert_client_build_info(char *outbuf, size_t outlen)
                QT_VERSION_STR, qVersion());
   */
 }
-
-/**************************************************************************
-  Make dynamic adjustments to first-launch default options.
-**************************************************************************/
-void qtg_adjust_default_options()
-{
-  /* Nothing in case of this gui */
-}
