@@ -14,7 +14,8 @@
 #ifndef FC__CANVAS_H
 #define FC__CANVAS_H
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
 
 #include "canvas_g.h"
 
