@@ -25,8 +25,10 @@
 #include <fc_config.h>
 #endif
 
-#include "SDL/SDL_image.h"
-#include "SDL/SDL_syswm.h"
+/* SDL */
+#include <SDL/SDL_image.h>
+#include <SDL/SDL_syswm.h>
+#include <SDL/SDL_ttf.h>
 
 /* utility */
 #include "fcintl.h"
@@ -36,7 +38,6 @@
 #include "tilespec.h"
 
 /* gui-sdl */
-#include "SDL_ttf.h"
 #include "gui_tilespec.h"
 #include "mapview.h"
 #include "themebackgrounds.h"
@@ -3304,19 +3305,17 @@ SDL_Surface *ResizeSurfaceBox(const SDL_Surface * pSrc,
 /* ============ Freeciv game graphics function =========== */
 
 /**************************************************************************
-  Return whether the client supports isometric view (isometric tilesets).
+  Return whether the client supports given view type
 **************************************************************************/
-bool isometric_view_supported(void)
+bool is_view_supported(enum ts_type type)
 {
-  return TRUE;
-}
+  switch (type) {
+  case TS_ISOMETRIC:
+  case TS_OVERHEAD:
+    return TRUE;
+  }
 
-/**************************************************************************
-  Return whether the client supports "overhead" (non-isometric) view.
-**************************************************************************/
-bool overhead_view_supported(void)
-{
-  return TRUE;
+  return FALSE;
 }
 
 /**************************************************************************
