@@ -32,8 +32,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "SDL/SDL_byteorder.h"
-#include "SDL/SDL_types.h"
+/* SDL */
+#include <SDL/SDL_byteorder.h>
+#include <SDL/SDL_types.h>
 
 #ifdef HAVE_LIBCHARSET
 #include <libcharset.h>
