@@ -23,13 +23,15 @@
 #include <fc_config.h>
 #endif
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
 
 /* utility */
 #include "fcintl.h"
 #include "log.h"
 
 /* common */
+#include "research.h"
 #include "specialist.h"
 
 /* client */
@@ -45,7 +47,7 @@
 
 #include "gui_tilespec.h"
 
-struct Theme *pTheme;
+struct Theme *current_theme = NULL;
 struct City_Icon *pIcons;
 
 static SDL_Surface *pCity_Surf;
@@ -60,18 +62,18 @@ do {								  \
   fc_assert_action(pSpr != NULL, break);                          \
   pStruct->pSurf = adj_surf(GET_SURF_REAL(pSpr));                 \
   FREESURFACE(GET_SURF_REAL(pSpr));                               \
-} while(0)
+} while(FALSE)
 
 #define load_theme_surface(pSpr, pSurf, tag)		\
-	load_GUI_surface(pSpr, pTheme, pSurf, tag)
+	load_GUI_surface(pSpr, current_theme, pSurf, tag)
 
 #define load_city_icon_surface(pSpr, pSurf, tag)        \
         load_GUI_surface(pSpr, pIcons, pSurf, tag)
 
 #define load_order_theme_surface(pSpr, pSurf, tag)	\
 do {							\
-  load_GUI_surface(pSpr, pTheme, pSurf, tag);		\
-} while(0)
+  load_GUI_surface(pSpr, current_theme, pSurf, tag);	\
+} while(FALSE)
 
 /*******************************************************************************
  * reload small citizens "style" icons.
@@ -244,8 +246,8 @@ void tilespec_free_city_icons(void)
 void tilespec_setup_theme(void)
 {
   struct sprite *pBuf = NULL;
-  
-  pTheme = fc_calloc(1, sizeof(struct Theme));
+
+  current_theme = fc_calloc(1, sizeof(struct Theme));
 
   load_theme_surface(pBuf, FR_Left, "theme.left_frame");
   load_theme_surface(pBuf, FR_Right, "theme.right_frame");
@@ -353,11 +355,12 @@ void tilespec_setup_theme(void)
 ***********************************************************************/
 void tilespec_free_theme(void)
 {
-  if (!pTheme) {
+  if (!current_theme) {
     return;
   }
 
-  FC_FREE(pTheme);
+  FC_FREE(current_theme);
+  current_theme = NULL;
 }
 
 /**************************************************************************
@@ -443,10 +446,10 @@ SDL_Surface * get_tech_icon(Tech_type_id tech)
 **************************************************************************/
 SDL_Color *get_tech_color(Tech_type_id tech_id)
 {
-  if (player_invention_reachable(client.conn.playing, tech_id, FALSE))
-  {
-    switch (player_invention_state(client.conn.playing, tech_id))
-    {
+  if (research_invention_gettable(research_get(client_player()),
+                                  tech_id, TRUE)) {
+    switch (research_invention_state(research_get(client_player()),
+                                     tech_id)) {
       case TECH_UNKNOWN:
         return get_game_color(COLOR_REQTREE_UNKNOWN);
       case TECH_KNOWN:
