@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,20 +11,20 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-/**********************************************************************
+/***********************************************************************
                           mapview.c  -  description
                              -------------------
     begin                : Aug 10 2002
     copyright            : (C) 2002 by Rafał Bursig
     email                : Rafał Bursig <bursig@poczta.fm>
- *********************************************************************/
+***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include <fc_config.h>
 #endif
 
 /* SDL */
-#include "SDL/SDL.h"
+#include <SDL/SDL.h>
 
 /* utility */
 #include "astring.h"
@@ -32,6 +32,7 @@
 #include "log.h"
 
 /* common */
+#include "calendar.h"
 #include "game.h"
 #include "goto.h"
 #include "government.h"
@@ -332,18 +333,26 @@ void set_indicator_icons(struct sprite *bulb, struct sprite *sol,
     /* TRANS: Research report action */
     fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)\n%s (%d/%d)", _("Research"), "F6",
                 Q_("?tech:None"), 0, 0);
-  } else if (A_UNSET != player_research_get(client.conn.playing)->researching) {
-    /* TRANS: Research report action */
-    fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)\n%s (%d/%d)", _("Research"), "F6",
-		advance_name_researching(client.conn.playing),
-		player_research_get(client.conn.playing)->bulbs_researched,
-                player_research_get(client_player())->client.researching_cost);
   } else {
-    /* TRANS: Research report action */
-    fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)\n%s (%d/%d)", _("Research"), "F6",
-		advance_name_researching(client.conn.playing),
-		player_research_get(client.conn.playing)->bulbs_researched,
-		0);
+    const struct research *presearch = research_get(client_player());
+
+    if (A_UNSET != presearch->researching) {
+      /* TRANS: Research report action */
+      fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)\n%s (%d/%d)",
+                  _("Research"), "F6",
+                  research_advance_name_translation(presearch,
+                                                    presearch->researching),
+                  presearch->bulbs_researched,
+                  presearch->client.researching_cost);
+    } else {
+      /* TRANS: Research report action */
+      fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)\n%s (%d/%d)",
+                  _("Research"), "F6",
+                  research_advance_name_translation(presearch,
+                                                    presearch->researching),
+                  presearch->bulbs_researched,
+                  0);
+    }
   }
 
   copy_chars_to_string16(pBuf->info_label, cBuf);
@@ -363,13 +372,14 @@ void set_indicator_icons(struct sprite *bulb, struct sprite *sol,
 ****************************************************************************/
 void overview_size_changed(void)
 {
-  map_canvas_resized(Main.screen->w, Main.screen->h);  	
-  
+  map_canvas_resized(Main.screen->w, Main.screen->h);
+
   if (overview_canvas) {
     canvas_free(overview_canvas);
-  }      
-  overview_canvas = canvas_create(overview.width, overview.height);
-  
+  }
+  overview_canvas = canvas_create(gui_options.overview.width,
+                                  gui_options.overview.height);
+
   resize_minimap();
 }
 
@@ -413,20 +423,20 @@ void update_info_label(void)
                   "Gold %d "),
                 nation_adjective_for_player(client.conn.playing),
                 population_to_text(civ_population(client.conn.playing)),
-                textyear(game.info.year),
+                calendar_text(),
                 client.conn.playing->economic.gold);
-#else
+#else /* SMALL_SCREEN */
     fc_snprintf(buffer, sizeof(buffer),
                 _("%s Population: %s  Year: %s  "
                   "Gold %d Tax: %d Lux: %d Sci: %d "),
                 nation_adjective_for_player(client.conn.playing),
                 population_to_text(civ_population(client.conn.playing)),
-                textyear(game.info.year),
+                calendar_text(),
                 client.conn.playing->economic.gold,
                 client.conn.playing->economic.tax,
                 client.conn.playing->economic.luxury,
                 client.conn.playing->economic.science);
-#endif
+#endif /* SMALL_SCREEN */
     /* convert to unistr and create text surface */
     copy_chars_to_string16(pText, buffer);
     pTmp = create_text_surf_from_str16(pText);
@@ -536,7 +546,8 @@ void redraw_unit_info_label(struct unit_list *punitlist)
 	right = FALSE;
       }
 
-      vetname = utype_veteran_name_translation(unit_type(pUnit), pUnit->veteran);
+      vetname = utype_veteran_name_translation(unit_type_get(pUnit),
+                                               pUnit->veteran);
       if (vetname != NULL) {
         copy_chars_to_string16(pStr, vetname);
         change_ptsize16(pStr, adj_font(10));
@@ -610,11 +621,11 @@ void redraw_unit_info_label(struct unit_list *punitlist)
 			{Q_("?city:Neutral"), Q_("?city:Hostile"),
 			  Q_("?city:Neutral"), Q_("?city:Peaceful"),
 			  Q_("?city:Friendly"), Q_("?city:Mysterious")};
-			  
+
 	    cat_snprintf(buffer, sizeof(buffer),
-			 _("\nCity of %s"),
-			 city_name(pCity));
-                          
+                         _("\nCity of %s"),
+                         city_name_get(pCity));
+
 #if 0       
             /* This has hardcoded assumption that EFT_LAND_REGEN is always
              * provided by *building* named *Barracks*. Similar assumptions for
@@ -712,7 +723,8 @@ void redraw_unit_info_label(struct unit_list *punitlist)
       FREESURFACE(pName);
       
       /* draw unit sprite */
-      pTmpSurf = ResizeSurfaceBox(get_unittype_surface(unit_type(pUnit), pUnit->facing),
+      pTmpSurf = ResizeSurfaceBox(get_unittype_surface(unit_type_get(pUnit),
+                                                       pUnit->facing),
                                   adj_size(80), adj_size(80), 1, TRUE, TRUE);
       pBuf_Surf = blend_surface(pTmpSurf, 32);
       FREESURFACE(pTmpSurf);
@@ -770,13 +782,11 @@ void redraw_unit_info_label(struct unit_list *punitlist)
 	pDock = pInfo_Window;
 	n = 0;
         unit_list_iterate(pTile->units, aunit) {
-          const char *vetname;
-
           if (aunit == pUnit) {
             continue;
 	  }
 
-          pUType = unit_type(aunit);
+          pUType = unit_type_get(aunit);
           vetname = utype_veteran_name_translation(pUType, aunit->veteran);
           pHome_City = game_city_by_number(aunit->homecity);
           fc_snprintf(buffer, sizeof(buffer), "%s (%d,%d,%s)%s%s\n%s\n(%d/%d)\n%s",
@@ -788,7 +798,7 @@ void redraw_unit_info_label(struct unit_list *punitlist)
                       (vetname != NULL ? vetname : ""),
                       unit_activity_text(aunit),
                       aunit->hp, pUType->hp,
-                      pHome_City ? city_name(pHome_City) : Q_("?homecity:None"));
+                      pHome_City ? city_name_get(pHome_City) : Q_("?homecity:None"));
 
 	  pBuf_Surf = create_surf(tileset_full_tile_width(tileset),
                                   tileset_full_tile_height(tileset), SDL_SWSURFACE);
@@ -796,7 +806,7 @@ void redraw_unit_info_label(struct unit_list *punitlist)
           destcanvas = canvas_create(tileset_full_tile_width(tileset),
                                      tileset_full_tile_height(tileset));
   
-          put_unit(aunit, destcanvas, 0, 0);
+          put_unit(aunit, destcanvas, 1.0, 0, 0);
           
           pTmpSurf = adj_surf(destcanvas->surf);
           
@@ -906,7 +916,8 @@ void redraw_unit_info_label(struct unit_list *punitlist)
       }
 
       if (!client_is_observer() && !client.conn.playing->phase_done
-          && (!client.conn.playing->ai_controlled || ai_manual_turn_done)) {
+          && (!client.conn.playing->ai_controlled
+              || gui_options.ai_manual_turn_done)) {
         char buf[256];
         fc_snprintf(buf, sizeof(buf), "%s\n%s\n%s",
                     _("End of Turn"), _("Press"), _("Shift+Return"));
@@ -1065,19 +1076,19 @@ void get_overview_area_dimensions(int *width, int *height)
   
   int xfact = MAP_IS_ISOMETRIC ? 2 : 1;
   int shift = (MAP_IS_ISOMETRIC && !current_topo_has_flag(TF_WRAPX)) ? -1 : 0;
-  
-  OVERVIEW_TILE_SIZE = MIN((DEFAULT_OVERVIEW_W - 1) / (map.xsize * xfact),
-                           (DEFAULT_OVERVIEW_H - 1) / map.ysize) + 1;
+
+  OVERVIEW_TILE_SIZE = MIN((DEFAULT_OVERVIEW_W - 1) / (game.map.xsize * xfact),
+                           (DEFAULT_OVERVIEW_H - 1) / game.map.ysize) + 1;
 
   do {
-    *height = OVERVIEW_TILE_HEIGHT * map.ysize;
+    *height = OVERVIEW_TILE_HEIGHT * game.map.ysize;
     if (*height < DEFAULT_OVERVIEW_H) {
       OVERVIEW_TILE_SIZE++;
     }
   } while (*height < DEFAULT_OVERVIEW_H);
 
-  *width = OVERVIEW_TILE_WIDTH * map.xsize + shift * OVERVIEW_TILE_SIZE; 
-  
+  *width = OVERVIEW_TILE_WIDTH * game.map.xsize + shift * OVERVIEW_TILE_SIZE;
+
   OVERVIEW_TILE_SIZE = overview_tile_size_bak;
 }
 
@@ -1163,6 +1174,9 @@ SDL_Surface *create_city_map(struct city *pCity)
   return city_map_canvas->surf;
 }
 
+/**************************************************************************
+  Return surface containing terrain of the tile.
+**************************************************************************/
 SDL_Surface *get_terrain_surface(struct tile *ptile)
 {
   /* tileset dimensions might have changed, so create a new canvas each time */
@@ -1174,7 +1188,7 @@ SDL_Surface *get_terrain_surface(struct tile *ptile)
   terrain_canvas = canvas_create_with_alpha(tileset_full_tile_width(tileset),
                                             tileset_full_tile_height(tileset));
 
-  put_terrain(ptile, terrain_canvas, 0, 0);
+  put_terrain(ptile, terrain_canvas, 1.0, 0, 0);
   
   return terrain_canvas->surf;
 }
