@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,19 +11,20 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-/***************************************************************************
+/***********************************************************************
                           menu.c  -  description
                              -------------------
     begin                : Wed Sep 04 2002
     copyright            : (C) 2002 by Rafał Bursig
     email                : Rafał Bursig <bursig@poczta.fm>
- ***************************************************************************/
+***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include <fc_config.h>
 #endif
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
 
 /* utility */
 #include "fcintl.h"
@@ -37,6 +38,7 @@
 
 /* client */
 #include "client_main.h" /* client_state */
+#include "climisc.h"
 #include "control.h"
 
 /* gui-sdl */
@@ -147,7 +149,7 @@ static int unit_order_callback(struct widget *pOrder_Widget)
       break;
     case ID_UNIT_ORDER_LOAD:
       unit_list_iterate(get_units_in_focus(), punit) {
-        request_unit_load(punit, NULL);
+        request_unit_load(punit, NULL, unit_tile(punit));
       } unit_list_iterate_end;
       break;
     case ID_UNIT_ORDER_UNLOAD:
@@ -167,17 +169,28 @@ static int unit_order_callback(struct widget *pOrder_Widget)
       key_unit_auto_explore();
       break;
     case ID_UNIT_ORDER_CONNECT_IRRIGATE:
-      key_unit_connect(ACTIVITY_IRRIGATE, NULL);
+      {
+        struct extra_type_list *extras = extra_type_list_by_cause(EC_IRRIGATION);
+
+        if (extra_type_list_size(extras) > 0) {
+          struct extra_type *pextra;
+
+          pextra = extra_type_list_get(extra_type_list_by_cause(EC_IRRIGATION), 0);
+
+          key_unit_connect(ACTIVITY_IRRIGATE, pextra);
+        }
+      }
       break;
     case ID_UNIT_ORDER_CONNECT_ROAD:
       {
         struct road_type *proad = road_by_compat_special(ROCO_ROAD);
 
         if (proad != NULL) {
-          struct act_tgt tgt = { .type = ATT_ROAD,
-                                 .obj.road = road_number(proad) };
+          struct extra_type *tgt;
 
-          key_unit_connect(ACTIVITY_GEN_ROAD, &tgt);
+          tgt = road_extra_get(proad);
+
+          key_unit_connect(ACTIVITY_GEN_ROAD, tgt);
         }
       }
       break;
@@ -186,10 +199,11 @@ static int unit_order_callback(struct widget *pOrder_Widget)
         struct road_type *prail = road_by_compat_special(ROCO_RAILROAD);
 
         if (prail != NULL) {
-          struct act_tgt tgt = { .type = ATT_ROAD,
-                                 .obj.road = road_number(prail) };
+          struct extra_type *tgt;
 
-          key_unit_connect(ACTIVITY_GEN_ROAD, &tgt);
+          tgt = road_extra_get(prail);
+
+          key_unit_connect(ACTIVITY_GEN_ROAD, tgt);
         }
       }
       break;
@@ -220,7 +234,7 @@ static int unit_order_callback(struct widget *pOrder_Widget)
       popup_unit_disband_dlg(pUnit, FALSE);
       break;
     case ID_UNIT_ORDER_DIPLOMAT_DLG:
-      key_unit_diplomat_actions();
+      key_unit_action_select_tgt();
       break;
     case ID_UNIT_ORDER_NUKE:
       key_unit_nuke();
@@ -242,15 +256,8 @@ static int unit_order_callback(struct widget *pOrder_Widget)
 }
 
 /**************************************************************************
-  ...
+  Refresh order widgets.
 **************************************************************************/
-#if 0
-static bool has_city_airport(struct city *pCity)
-{
-  return (pCity && (get_city_bonus(pCity, EFT_AIR_VETERAN) > 0));
-}
-#endif
-
 static Uint16 redraw_order_widgets(void)
 {
   Uint16 count = 0;
@@ -393,12 +400,12 @@ void create_units_order_widgets(void)
   size_t len;
   struct road_type *proad;
   struct road_type *prail;
-  
+
   /* No orders */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("No Orders"),
               /* TRANS: "Space" refers to the space bar on a keyboard. */
               _("Space"));
-  pBuf = create_themeicon(pTheme->ODone_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->ODone_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -412,7 +419,7 @@ void create_units_order_widgets(void)
 
   /* Wait */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Wait"), "W");
-  pBuf = create_themeicon(pTheme->OWait_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OWait_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -424,7 +431,7 @@ void create_units_order_widgets(void)
 
   /* Explode Nuclear */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Explode Nuclear"), "Shift+N");
-  pBuf = create_themeicon(pTheme->ONuke_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->ONuke_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -435,9 +442,10 @@ void create_units_order_widgets(void)
   add_to_gui_list(ID_UNIT_ORDER_NUKE, pBuf);
   /* --------- */
 
-  /* Diplomat|Spy Actions */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Diplomat/Spy Actions"), "D");
-  pBuf = create_themeicon(pTheme->OSpy_Icon, Main.gui,
+  /* Act against the specified tile. */
+  /* TRANS: Button to bring up the action selection dialog. */
+  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Do..."), "D");
+  pBuf = create_themeicon(current_theme->OSpy_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -449,7 +457,7 @@ void create_units_order_widgets(void)
 
   /* Disband */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Disband Unit"), "Shift+D");
-  pBuf = create_themeicon(pTheme->ODisband_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->ODisband_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -462,7 +470,7 @@ void create_units_order_widgets(void)
 
   /* Upgrade */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Upgrade Unit"), "Shift+U");
-  pBuf = create_themeicon(pTheme->Order_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->Order_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -475,7 +483,7 @@ void create_units_order_widgets(void)
 
   /* Convert */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Convert Unit"), "Shift+O");
-  pBuf = create_themeicon(pTheme->Order_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->Order_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -488,7 +496,7 @@ void create_units_order_widgets(void)
 
   /* Return to nearest city */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Return to Nearest City"), "Shift+G");
-  pBuf = create_themeicon(pTheme->OReturn_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OReturn_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -501,7 +509,7 @@ void create_units_order_widgets(void)
   
   /* Goto City */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Go to City"), "T");
-  pBuf = create_themeicon(pTheme->OGotoCity_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OGotoCity_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -513,7 +521,7 @@ void create_units_order_widgets(void)
 
   /* Airlift */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Airlift to City"), "T");
-  pBuf = create_themeicon(pTheme->Order_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->Order_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -525,7 +533,7 @@ void create_units_order_widgets(void)
   
   /* Goto location */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Go to Tile"), "G");
-  pBuf = create_themeicon(pTheme->OGoto_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OGoto_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -537,7 +545,7 @@ void create_units_order_widgets(void)
 
   /* Patrol */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Patrol"), "Q");
-  pBuf = create_themeicon(pTheme->OPatrol_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OPatrol_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -549,7 +557,7 @@ void create_units_order_widgets(void)
 
   /* Connect irrigation */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Connect With Irrigation"), "Shift+I");
-  pBuf = create_themeicon(pTheme->OAutoConnect_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OAutoConnect_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -566,9 +574,9 @@ void create_units_order_widgets(void)
   if (proad != NULL) {
     fc_snprintf(cBuf, sizeof(cBuf),
                 _("Connect With %s (%s)"),
-                road_name_translation(proad),
+                extra_name_translation(road_extra_get(proad)),
                 "Shift+R");
-    pBuf = create_themeicon(pTheme->OAutoConnect_Icon, Main.gui,
+    pBuf = create_themeicon(current_theme->OAutoConnect_Icon, Main.gui,
                             WF_HIDDEN | WF_RESTORE_BACKGROUND
                             | WF_WIDGET_HAS_INFO_LABEL);
     set_wstate(pBuf, FC_WS_NORMAL);
@@ -585,9 +593,9 @@ void create_units_order_widgets(void)
   if (prail != NULL) {
     fc_snprintf(cBuf, sizeof(cBuf),
                 _("Connect With %s (%s)"),
-                road_name_translation(prail),
+                extra_name_translation(road_extra_get(prail)),
                 "Shift+L");
-    pBuf = create_themeicon(pTheme->OAutoConnect_Icon, Main.gui,
+    pBuf = create_themeicon(current_theme->OAutoConnect_Icon, Main.gui,
                             WF_HIDDEN | WF_RESTORE_BACKGROUND
                             | WF_WIDGET_HAS_INFO_LABEL);
     set_wstate(pBuf, FC_WS_NORMAL);
@@ -601,7 +609,7 @@ void create_units_order_widgets(void)
 
   /* Auto-Explore */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Explore"), "X");
-  pBuf = create_themeicon(pTheme->OAutoExp_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OAutoExp_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -616,8 +624,8 @@ void create_units_order_widgets(void)
   len = strlen(cBuf);
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Settler"), "A");
   len = MAX(len, strlen(cBuf));
-  
-  pBuf = create_themeicon(pTheme->OAutoSett_Icon, Main.gui,
+
+  pBuf = create_themeicon(current_theme->OAutoSett_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -630,11 +638,11 @@ void create_units_order_widgets(void)
   add_to_gui_list(ID_UNIT_ORDER_AUTO_SETTLER, pBuf);
   
   pOrder_Automate_Unit_Button = pBuf;
-  /* --------- */    
-  
+  /* --------- */
+
   /* Wake Up Others */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Unsentry All On Tile"), "Shift+S");
-  pBuf = create_themeicon(pTheme->OWakeUp_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OWakeUp_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -647,7 +655,7 @@ void create_units_order_widgets(void)
 
   /* Unload */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Unload All From Transporter"), "Shift+T");
-  pBuf = create_themeicon(pTheme->OUnload_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OUnload_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -660,7 +668,7 @@ void create_units_order_widgets(void)
 
   /* Load */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Load Unit"), "L");
-  pBuf = create_themeicon(pTheme->OLoad_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OLoad_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -672,7 +680,7 @@ void create_units_order_widgets(void)
 
   /* Unload */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Unload Unit"), "U");
-  pBuf = create_themeicon(pTheme->OUnload_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OUnload_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -684,7 +692,7 @@ void create_units_order_widgets(void)
 
   /* Find Homecity */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Find Home City"), "H");
-  pBuf = create_themeicon(pTheme->OHomeCity_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OHomeCity_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -696,7 +704,7 @@ void create_units_order_widgets(void)
 
   /* Pillage */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Pillage"), "Shift+P");
-  pBuf = create_themeicon(pTheme->OPillage_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OPillage_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -709,7 +717,7 @@ void create_units_order_widgets(void)
 
   /* Sentry */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Sentry Unit"), "S");
-  pBuf = create_themeicon(pTheme->OSentry_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OSentry_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -721,7 +729,7 @@ void create_units_order_widgets(void)
 
   /* Clean Nuclear Fallout */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Clean Nuclear Fallout"), "N");
-  pBuf = create_themeicon(pTheme->OFallout_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OFallout_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -733,7 +741,7 @@ void create_units_order_widgets(void)
 
   /* Paradrop */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Drop Paratrooper"), "P");
-  pBuf = create_themeicon(pTheme->OParaDrop_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OParaDrop_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -745,7 +753,7 @@ void create_units_order_widgets(void)
 
   /* Clean Pollution */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Clean Pollution"), "P");
-  pBuf = create_themeicon(pTheme->OPollution_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OPollution_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -756,8 +764,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Airbase */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Airbase"), "E");
-  pBuf = create_themeicon(pTheme->OAirBase_Icon, Main.gui,
+  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Airbase"), "Shift+E");
+  pBuf = create_themeicon(current_theme->OAirBase_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -769,7 +777,7 @@ void create_units_order_widgets(void)
 
   /* Fortify */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Fortify Unit"), "F");
-  pBuf = create_themeicon(pTheme->OFortify_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OFortify_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -780,8 +788,8 @@ void create_units_order_widgets(void)
   /* --------- */
 
   /* Build Fortress */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Fortress"), "F");
-  pBuf = create_themeicon(pTheme->OFortress_Icon, Main.gui,
+  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Fortress"), "Shift+F");
+  pBuf = create_themeicon(current_theme->OFortress_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -793,7 +801,7 @@ void create_units_order_widgets(void)
 
   /* Transform Tile */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Transform Tile"), "O");
-  pBuf = create_themeicon(pTheme->OTransform_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OTransform_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -806,7 +814,7 @@ void create_units_order_widgets(void)
 
   /* Build Mine */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Mine"), "M");
-  pBuf = create_themeicon(pTheme->OMine_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OMine_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -814,13 +822,13 @@ void create_units_order_widgets(void)
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   pBuf->key = SDLK_m;
   add_to_gui_list(ID_UNIT_ORDER_MINE, pBuf);
-  
+
   pOrder_Mine_Button = pBuf;
-  /* --------- */    
+  /* --------- */
 
   /* Build Irrigation */
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build Irrigation"), "I");
-  pBuf = create_themeicon(pTheme->OIrrigation_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->OIrrigation_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -828,13 +836,14 @@ void create_units_order_widgets(void)
   pBuf->key = SDLK_i;
   pBuf->info_label = create_str16_from_char(cBuf, adj_font(10));
   add_to_gui_list(ID_UNIT_ORDER_IRRIGATE, pBuf);
-  
+
   pOrder_Irrigation_Button = pBuf;
-  /* --------- */    
+  /* --------- */
 
   /* Form Trade route */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Establish Trade Route"), "R");
-  pBuf = create_themeicon(pTheme->OTrade_Icon, Main.gui,
+  fc_snprintf(cBuf, sizeof(cBuf), "%s (%s)",
+              action_id_name_translation(ACTION_TRADE_ROUTE), "R");
+  pBuf = create_themeicon(current_theme->OTrade_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -850,19 +859,19 @@ void create_units_order_widgets(void)
   /* TRANS: "Build Railroad (R) 999 turns" */
   if (prail != NULL) {
     fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                road_name_translation(prail), "R", 999, 
+                extra_name_translation(road_extra_get(prail)), "R", 999,
                 PL_("turn", "turns", 999));
     len = strlen(cBuf);
   }
   /* TRANS: "Build Road (R) 999 turns" */
   if (proad != NULL) {
     fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                road_name_translation(proad), "R", 999, 
+                extra_name_translation(road_extra_get(proad)), "R", 999,
                 PL_("turn", "turns", 999));
     len = MAX(len, strlen(cBuf));
   }
 
-  pBuf = create_themeicon(pTheme->ORoad_Icon, Main.gui,
+  pBuf = create_themeicon(current_theme->ORoad_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -874,12 +883,13 @@ void create_units_order_widgets(void)
   pBuf->key = SDLK_r;
   add_to_gui_list(ID_UNIT_ORDER_ROAD, pBuf);
 
-  pOrder_Road_Button = pBuf;  
-  /* --------- */  
-  
+  pOrder_Road_Button = pBuf;
+  /* --------- */
+
   /* Help Build Wonder */
-  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Help Build Wonder"), "B");
-  pBuf = create_themeicon(pTheme->OWonder_Icon, Main.gui,
+  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)",
+              action_id_name_translation(ACTION_HELP_WONDER), "B");
+  pBuf = create_themeicon(current_theme->OWonder_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -894,8 +904,8 @@ void create_units_order_widgets(void)
   len = strlen(cBuf);
   fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Build City"), "B");
   len = MAX(len, strlen(cBuf));
-      
-  pBuf = create_themeicon(pTheme->OBuildCity_Icon, Main.gui,
+
+  pBuf = create_themeicon(current_theme->OBuildCity_Icon, Main.gui,
                           WF_HIDDEN | WF_RESTORE_BACKGROUND
                           | WF_WIDGET_HAS_INFO_LABEL);
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -1072,7 +1082,8 @@ void real_menus_update(void)
       struct city *pCity = tile_city(pTile);
       struct terrain *pTerrain = tile_terrain(pTile);
       struct base_type *pbase;
-      struct road_type *proad = next_road_for_tile(pTile, unit_owner(pUnit), pUnit);
+      struct extra_type *pextra = next_extra_for_tile(pTile, EC_ROAD,
+                                                      unit_owner(pUnit), pUnit);
 
       if (!counter) {
 	local_show(ID_UNIT_ORDER_GOTO);
@@ -1104,45 +1115,50 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_BUILD_WONDER);
       }
 
-      if (proad != NULL) {
+      if (pextra != NULL) {
+        struct road_type *proad = extra_road_get(pextra);
         enum road_compat compat = road_compat_special(proad);
 
-	time = tile_activity_road_time(pTile, road_number(proad));
+        time = tile_activity_time(ACTIVITY_GEN_ROAD, pTile, road_extra_get(proad));
 
         /* TRANS: "Build Railroad (R) 3 turns" */
 	fc_snprintf(cBuf, sizeof(cBuf), _("Build %s (%s) %d %s"),
-                    road_name_translation(proad),
-                    "R", time, 
+                    extra_name_translation(pextra),
+                    "R", time,
                     PL_("turn", "turns", time));
 
 	if (compat == ROCO_RAILROAD) {
-	  pOrder_Road_Button->theme = pTheme->ORailRoad_Icon;
+	  pOrder_Road_Button->theme = current_theme->ORailRoad_Icon;
 	} else {
-	  pOrder_Road_Button->theme = pTheme->ORoad_Icon;
+	  pOrder_Road_Button->theme = current_theme->ORoad_Icon;
 	}
         copy_chars_to_string16(pOrder_Road_Button->info_label, cBuf);
 	clear_wflag(pOrder_Road_Button, WF_HIDDEN);
       } else {
 	set_wflag(pOrder_Road_Button, WF_HIDDEN);
       }
-      
-	/* unit_can_est_trade_route_here(pUnit) */
-      if (pCity && unit_has_type_flag(pUnit, UTYF_TRADE_ROUTE)
+
+      /* unit_can_est_trade_route_here(pUnit) */
+      if (pCity && utype_can_do_action(unit_type_get(pUnit),
+                                       ACTION_TRADE_ROUTE)
           && (pHomecity = game_city_by_number(pUnit->homecity))
           && can_cities_trade(pHomecity, pCity)) {
-	int revenue = get_caravan_enter_city_trade_bonus(pHomecity, pCity);
+        int revenue = get_caravan_enter_city_trade_bonus(pHomecity, pCity,
+                                                         TRUE);
 	
         if (can_establish_trade_route(pHomecity, pCity)) {
           fc_snprintf(cBuf, sizeof(cBuf),
-                      _("Establish Trade Route With %s ( %d R&G + %d trade ) (R)"),
-                      city_name(pHomecity),
+                      _("%s With %s ( %d one time bonus + %d trade ) (R)"),
+                      action_id_name_translation(ACTION_TRADE_ROUTE),
+                      city_name_get(pHomecity),
                       revenue,
                       trade_between_cities(pHomecity, pCity));
         } else {
           revenue = (revenue + 2) / 3;
           fc_snprintf(cBuf, sizeof(cBuf),
-                      _("Trade With %s ( %d R&G bonus ) (R)"),
-                      city_name(pHomecity),
+                      _("%s Of %s ( %d one time bonus ) (R)"),
+                      action_id_name_translation(ACTION_MARKETPLACE),
+                      city_name_get(pHomecity),
                       revenue);
         }
         copy_chars_to_string16(pOrder_Trade_Button->info_label, cBuf);
@@ -1152,7 +1168,7 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_IRRIGATE)) {
-	time = tile_activity_time(ACTIVITY_IRRIGATE, unit_tile(pUnit));
+        time = tile_activity_time(ACTIVITY_IRRIGATE, unit_tile(pUnit), NULL);
 
         if (!strcmp(terrain_rule_name(pTerrain), "Forest") ||
           !strcmp(terrain_rule_name(pTerrain), "Jungle")) {
@@ -1161,19 +1177,19 @@ void real_menus_update(void)
 			_("Cut Down to"),
                 terrain_name_translation(pTerrain->irrigation_result)
 			,"I", time , PL_("turn", "turns", time));
-	  pOrder_Irrigation_Button->theme = pTheme->OCutDownForest_Icon;
+	  pOrder_Irrigation_Button->theme = current_theme->OCutDownForest_Icon;
         }	else if (!strcmp(terrain_rule_name(pTerrain), "Swamp")) {
 	  fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
 			_("Irrigate to"),
                 terrain_name_translation(pTerrain->irrigation_result)
 			,"I", time , PL_("turn", "turns", time));
-	  pOrder_Irrigation_Button->theme = pTheme->OIrrigation_Icon;
+	  pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
         } else {
 	  /* set Irrigation Icon */
 	  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
 			_("Build Irrigation"), "I", time , 
 			PL_("turn", "turns", time));
-	  pOrder_Irrigation_Button->theme = pTheme->OIrrigation_Icon;
+	  pOrder_Irrigation_Button->theme = current_theme->OIrrigation_Icon;
 	}
 
         copy_chars_to_string16(pOrder_Irrigation_Button->info_label, cBuf);
@@ -1183,7 +1199,7 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_MINE)) {
-	time = tile_activity_time(ACTIVITY_MINE, unit_tile(pUnit));
+        time = tile_activity_time(ACTIVITY_MINE, unit_tile(pUnit), NULL);
 
 	/* FIXME: THIS CODE IS WRONG */
    if (!strcmp(terrain_rule_name(pTerrain), "Forest")) {  
@@ -1192,7 +1208,7 @@ void real_menus_update(void)
 			_("Irrigate to"),
 			terrain_name_translation(pTerrain->mining_result)
 			,"M", time , PL_("turn", "turns", time));
-	  pOrder_Mine_Button->theme = pTheme->OIrrigation_Icon;
+	  pOrder_Mine_Button->theme = current_theme->OIrrigation_Icon;
    } else if (!strcmp(terrain_rule_name(pTerrain), "Jungle") ||
               !strcmp(terrain_rule_name(pTerrain), "Plains") ||
               !strcmp(terrain_rule_name(pTerrain), "Grassland") ||
@@ -1201,14 +1217,14 @@ void real_menus_update(void)
 	  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
 			_("Plant Forest"), "M", time , 
 			PL_("turn", "turns", time));
-	  pOrder_Mine_Button->theme = pTheme->OPlantForest_Icon;
-   
+	  pOrder_Mine_Button->theme = current_theme->OPlantForest_Icon;
+
    } else {
 	  /* set Mining Icon */
 	  fc_snprintf(cBuf, sizeof(cBuf),"%s (%s) %d %s",
 			_("Build Mine"), "M", time , 
 			PL_("turn", "turns", time));
-	  pOrder_Mine_Button->theme = pTheme->OMine_Icon;
+	  pOrder_Mine_Button->theme = current_theme->OMine_Icon;
 	}
 
         copy_chars_to_string16(pOrder_Mine_Button->info_label, cBuf);
@@ -1218,7 +1234,7 @@ void real_menus_update(void)
       }
 
       if (can_unit_do_activity(pUnit, ACTIVITY_TRANSFORM)) {
-        time = tile_activity_time(ACTIVITY_TRANSFORM, unit_tile(pUnit));
+        time = tile_activity_time(ACTIVITY_TRANSFORM, unit_tile(pUnit), NULL);
         fc_snprintf(cBuf, sizeof(cBuf),"%s %s (%s) %d %s",
                     _("Transform to"),
                     terrain_name_translation(pTerrain->transform_result),
@@ -1313,16 +1329,16 @@ void real_menus_update(void)
 
       if (can_unit_do_autosettlers(pUnit)) {
 	if (unit_has_type_flag(pUnit, UTYF_SETTLERS)) {
-	  if(pOrder_Automate_Unit_Button->theme != pTheme->OAutoSett_Icon) {
+	  if(pOrder_Automate_Unit_Button->theme != current_theme->OAutoSett_Icon) {
 	    fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Settler"), "A");
-	    pOrder_Automate_Unit_Button->theme = pTheme->OAutoSett_Icon;
+	    pOrder_Automate_Unit_Button->theme = current_theme->OAutoSett_Icon;
             copy_chars_to_string16(pOrder_Automate_Unit_Button->info_label,
                                    cBuf);
 	  }
 	} else {
-	  if(pOrder_Automate_Unit_Button->theme != pTheme->OAutoAtt_Icon) {
+	  if(pOrder_Automate_Unit_Button->theme != current_theme->OAutoAtt_Icon) {
 	    fc_snprintf(cBuf, sizeof(cBuf),"%s (%s)", _("Auto Attack"), "A");
-	    pOrder_Automate_Unit_Button->theme = pTheme->OAutoAtt_Icon;
+	    pOrder_Automate_Unit_Button->theme = current_theme->OAutoAtt_Icon;
             copy_chars_to_string16(pOrder_Automate_Unit_Button->info_label,
                                    cBuf);
 	  }
@@ -1338,10 +1354,24 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_AUTO_EXPLORE);
       }
 
-      if (can_unit_do_connect(pUnit, ACTIVITY_IRRIGATE, NULL)) {
-	local_show(ID_UNIT_ORDER_CONNECT_IRRIGATE);
-      } else {
-	local_hide(ID_UNIT_ORDER_CONNECT_IRRIGATE);
+      {
+        bool conn_possible = FALSE;
+        struct extra_type_list *extras;
+
+        extras = extra_type_list_by_cause(EC_IRRIGATION);
+
+        if (extra_type_list_size(extras) > 0) {
+          struct extra_type *tgt;
+
+          tgt = extra_type_list_get(extras, 0);
+          conn_possible = can_units_do_connect(punits, ACTIVITY_IRRIGATE, tgt);
+        }
+
+        if (conn_possible) {
+          local_show(ID_UNIT_ORDER_CONNECT_IRRIGATE);
+        } else {
+          local_hide(ID_UNIT_ORDER_CONNECT_IRRIGATE);
+        }
       }
 
       {
@@ -1349,11 +1379,11 @@ void real_menus_update(void)
         bool road_conn_possible;
 
         if (proad != NULL) {
-          struct act_tgt tgt = { .type = ATT_ROAD,
-                                 .obj.road = road_number(proad) }; 
+          struct extra_type *tgt;
 
-          road_conn_possible = can_unit_do_connect(pUnit, ACTIVITY_GEN_ROAD,
-                                                   &tgt);
+          tgt = road_extra_get(proad);
+
+          road_conn_possible = can_unit_do_connect(pUnit, ACTIVITY_GEN_ROAD, tgt);
         } else {
           road_conn_possible = FALSE;
         }
@@ -1370,11 +1400,11 @@ void real_menus_update(void)
         bool road_conn_possible;
 
         if (proad != NULL) {
-          struct act_tgt tgt = { .type = ATT_ROAD,
-                                 .obj.road = road_number(proad) }; 
+          struct extra_type *tgt;
 
-          road_conn_possible = can_unit_do_connect(pUnit, ACTIVITY_GEN_ROAD,
-                                                   &tgt);
+          tgt = road_extra_get(proad);
+
+          road_conn_possible = can_unit_do_connect(pUnit, ACTIVITY_GEN_ROAD, tgt);
         } else {
           road_conn_possible = FALSE;
         }
@@ -1386,8 +1416,7 @@ void real_menus_update(void)
         }
       }
 
-      if (is_diplomat_unit(pUnit) &&
-	  diplomat_can_do_action(pUnit, DIPLOMAT_ANY_ACTION, unit_tile(pUnit))) {
+      if (unit_can_do_action(pUnit, ACTION_ANY)) {
 	local_show(ID_UNIT_ORDER_DIPLOMAT_DLG);
       } else {
 	local_hide(ID_UNIT_ORDER_DIPLOMAT_DLG);
@@ -1399,7 +1428,6 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_NUKE);
       }
 
-/*      if (pCity && has_city_airport(pCity) && pCity->airlift) {*/
       if (pCity && pCity->airlift) {      
 	local_show(ID_UNIT_ORDER_AIRLIFT);
 	hide(ID_UNIT_ORDER_GOTO_CITY);
@@ -1408,7 +1436,8 @@ void real_menus_update(void)
 	local_hide(ID_UNIT_ORDER_AIRLIFT);
       }
 
-      if (pCity && can_upgrade_unittype(client.conn.playing, unit_type(pUnit))) {
+      if (pCity && can_upgrade_unittype(client.conn.playing,
+                                        unit_type_get(pUnit))) {
 	local_show(ID_UNIT_ORDER_UPGRADE);
       } else {
 	local_hide(ID_UNIT_ORDER_UPGRADE);
