@@ -117,12 +117,12 @@ struct small_sprite {
 #define small_sprite_list_iterate_end LIST_ITERATE_END
 
 #define SPECHASH_TAG small_sprite
-#define SPECHASH_KEY_TYPE char *
-#define SPECHASH_DATA_TYPE struct small_sprite *
-#define SPECHASH_KEY_VAL genhash_str_val_func
-#define SPECHASH_KEY_COMP genhash_str_comp_func
-#define SPECHASH_KEY_COPY genhash_str_copy_func
-#define SPECHASH_KEY_FREE genhash_str_free_func
+#define SPECHASH_IKEY_TYPE char *
+#define SPECHASH_IDATA_TYPE struct small_sprite *
+#define SPECHASH_IKEY_VAL genhash_str_val_func
+#define SPECHASH_IKEY_COMP genhash_str_comp_func
+#define SPECHASH_IKEY_COPY genhash_str_copy_func
+#define SPECHASH_IKEY_FREE genhash_str_free_func
 #include "spechash.h"
 #define small_sprite_hash_iterate(hash, tag_name, pitem)                    \
   TYPED_HASH_ITERATE(const char *, struct small_sprite *, hash,             \
@@ -232,9 +232,8 @@ static char *themespec_fullname(const char *theme_name)
     char fname[strlen(theme_name) + strlen(THEMESPEC_SUFFIX) + 1], *dname;
 
     fc_snprintf(fname, sizeof(fname),
-		"%s%s", theme_name, THEMESPEC_SUFFIX);
+                "%s%s", theme_name, THEMESPEC_SUFFIX);
 
-/*    dname = fileinfoname(get_data_dirs(), fname);*/
     dname = fname;
 
     if (dname) {
@@ -741,8 +740,8 @@ struct theme *theme_read_toplevel(const char *theme_name)
 
   sz_strlcpy(t->name, theme_name);
   t->priority = secfile_lookup_int_default(file, 0, "themespec.priority");
-  
-  langname = get_langname();
+
+  langname = setup_langname();
   if (langname) {
     if (strstr(langname, "zh_CN") != NULL) {
       c = secfile_lookup_str(file, "themespec.font_file_zh_CN");
@@ -856,7 +855,7 @@ static struct sprite *load_sprite(struct theme *t, const char *tag_name)
       }
       ss->sprite =
 	crop_sprite(ss->sf->big_sprite, ss->x, ss->y, ss->width, ss->height,
-		    NULL, -1, -1);
+		    NULL, -1, -1, 1.0, FALSE);
     }
   }
 
