@@ -15,7 +15,8 @@
 #include <fc_config.h>
 #endif
 
-#include "SDL/SDL.h"
+/* SDL */
+#include <SDL/SDL.h>
 
 /* utility */
 #include "log.h"
@@ -151,21 +152,21 @@ static void window_unselect(struct widget *pWindow)
 static void set_client_area(struct widget *pWindow)
 {
   SDL_Rect area;
-  
+
   if (get_wflags(pWindow) & WF_DRAW_FRAME_AROUND_WIDGET) {
-    area.x = pTheme->FR_Left->w;
-    area.y = pTheme->FR_Top->h;
-    area.w = pWindow->size.w - pTheme->FR_Left->w - pTheme->FR_Right->w;
-    area.h = pWindow->size.h - pTheme->FR_Top->h - pTheme->FR_Bottom->h;
+    area.x = current_theme->FR_Left->w;
+    area.y = current_theme->FR_Top->h;
+    area.w = pWindow->size.w - current_theme->FR_Left->w - current_theme->FR_Right->w;
+    area.h = pWindow->size.h - current_theme->FR_Top->h - current_theme->FR_Bottom->h;
   } else {
     area = pWindow->size;
   }
-    
+
   if (pWindow->string16) {
     area.y += (WINDOW_TITLE_HEIGHT + 1);
     area.h -= (WINDOW_TITLE_HEIGHT + 1);
   }
-  
+
   widget_set_area(pWindow, area);
 }
 
@@ -194,12 +195,13 @@ struct widget *create_window_skeleton(struct gui_layer *pDest,
   pWindow->mod = KMOD_NONE;
 
   if (get_wflags(pWindow) & WF_DRAW_FRAME_AROUND_WIDGET) {
-    w += pTheme->FR_Left->w + pTheme->FR_Right->w;
-    h += pTheme->FR_Top->h + pTheme->FR_Bottom->h;
+    w += current_theme->FR_Left->w + current_theme->FR_Right->w;
+    h += current_theme->FR_Top->h + current_theme->FR_Bottom->h;
   }
-  
+
   if (pTitle) {
     SDL_Rect size = str16size(pTitle);
+
     w += size.w + adj_size(10);
     h += MAX(size.h, WINDOW_TITLE_HEIGHT + 1);
   }
