@@ -30,7 +30,7 @@
 
 #include "wldlg_g.h"
 
-void popup_worklist_editor(struct city *pCity, struct global_worklist *pGWL);
+void popup_worklist_editor(struct city *pCity, struct global_worklist *gwl);
 void popdown_worklist_editor(void);
 
 #endif	/* FC__WLDLG_H */
