@@ -142,7 +142,7 @@ void action_selection_no_longer_in_progress_gui_specific(int actor_id)
 *****************************************************************/
 static int caravan_marketplace_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])
         && NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)) {
@@ -163,7 +163,7 @@ static int caravan_marketplace_callback(struct widget *pWidget)
 *****************************************************************/
 static int caravan_establish_trade_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])
         && NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)) {
@@ -184,7 +184,7 @@ static int caravan_establish_trade_callback(struct widget *pWidget)
 *****************************************************************/
 static int caravan_help_build_wonder_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])
         && NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)) {
@@ -209,7 +209,7 @@ static int caravan_help_build_wonder_callback(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_dlg_window_callback(struct widget *pWindow)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     move_window_group(pDiplomat_Dlg->pdialog->pBeginWidgetList, pWindow);
   }
 
@@ -221,7 +221,7 @@ static int diplomat_dlg_window_callback(struct widget *pWindow)
 *****************************************************************/
 static int diplomat_embassy_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])
         && NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)) {
@@ -242,7 +242,7 @@ static int diplomat_embassy_callback(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_investigate_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])) {
@@ -264,7 +264,7 @@ static int diplomat_investigate_callback(struct widget *pWidget)
 *****************************************************************/
 static int spy_poison_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])) {
@@ -284,7 +284,7 @@ static int spy_poison_callback(struct widget *pWidget)
 ********************************************************************/
 static int spy_steal_gold_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL != game_city_by_number(
           pDiplomat_Dlg->target_ids[ATK_CITY])) {
@@ -326,7 +326,7 @@ static int spy_sabotage_request(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_sabotage_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL != game_city_by_number(
                 pDiplomat_Dlg->target_ids[ATK_CITY])) {
@@ -349,7 +349,7 @@ static int diplomat_sabotage_callback(struct widget *pWidget)
 *****************************************************************/
 static int spy_steal_dlg_window_callback(struct widget *pWindow)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     move_window_group(pDiplomat_Dlg->pdialog->pBeginWidgetList, pWindow);
   }
 
@@ -361,7 +361,7 @@ static int spy_steal_dlg_window_callback(struct widget *pWindow)
 *****************************************************************/
 static int exit_spy_tgt_dlg_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     int actor_id = pDiplomat_Dlg->actor_unit_id;
 
     fc_assert(is_more_user_input_needed);
@@ -377,7 +377,7 @@ static int exit_spy_tgt_dlg_callback(struct widget *pWidget)
 *****************************************************************/
 static int spy_steal_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     int steal_advance = MAX_ID - pWidget->ID;
     int actor_id = pDiplomat_Dlg->actor_unit_id;
 
@@ -652,7 +652,7 @@ static int spy_steal_popup(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_steal_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL != game_city_by_number(
                 pDiplomat_Dlg->target_ids[ATK_CITY])) {
@@ -673,7 +673,7 @@ static int diplomat_steal_callback(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_incite_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL != game_city_by_number(
                 pDiplomat_Dlg->target_ids[ATK_CITY])) {
@@ -697,7 +697,7 @@ static int diplomat_incite_callback(struct widget *pWidget)
 *********************************************************************/
 static int act_sel_keep_moving_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     struct unit *punit;
 
     if ((punit = game_unit_by_number(pDiplomat_Dlg->actor_unit_id))
@@ -716,7 +716,7 @@ static int act_sel_keep_moving_callback(struct widget *pWidget)
 *********************************************************************/
 static int act_sel_wait_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     key_unit_wait();
 
     /* The dialog was popped down when key_unit_wait() resulted in
@@ -731,7 +731,7 @@ static int act_sel_wait_callback(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_bribe_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pDiplomat_Dlg->actor_unit_id)
         && NULL !=
          game_unit_by_number(pDiplomat_Dlg->target_ids[ATK_UNIT])) {
@@ -753,7 +753,7 @@ static int diplomat_bribe_callback(struct widget *pWidget)
 *****************************************************************/
 static int spy_sabotage_unit_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     int diplomat_id = MAX_ID - pWidget->ID;
     int target_id = pWidget->data.unit->id;
 
@@ -770,7 +770,7 @@ static int spy_sabotage_unit_callback(struct widget *pWidget)
 *****************************************************************/
 static int diplomat_close_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     popdown_diplomat_dialog();
   }
 
@@ -1182,7 +1182,7 @@ void action_selection_close(void)
 ****************************************************************/
 static int sabotage_impr_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     int sabotage_improvement = MAX_ID - pWidget->ID;
     int diplomat_target_id = pWidget->data.cont->id0;
     int diplomat_id = pWidget->data.cont->id1;
@@ -1455,7 +1455,7 @@ static struct small_diplomat_dialog *pIncite_Dlg = NULL;
 *****************************************************************/
 static int incite_dlg_window_callback(struct widget *pWindow)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     move_window_group(pIncite_Dlg->pdialog->pBeginWidgetList, pWindow);
   }
 
@@ -1467,7 +1467,7 @@ static int incite_dlg_window_callback(struct widget *pWindow)
 *****************************************************************/
 static int diplomat_incite_yes_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pIncite_Dlg->actor_unit_id)
         && NULL != game_city_by_number(pIncite_Dlg->target_id)) {
       request_do_action(ACTION_SPY_INCITE_CITY, pIncite_Dlg->actor_unit_id,
@@ -1485,7 +1485,7 @@ static int diplomat_incite_yes_callback(struct widget *pWidget)
 *****************************************************************/
 static int exit_incite_dlg_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     popdown_incite_dialog();
   }
 
@@ -1717,7 +1717,7 @@ static struct small_diplomat_dialog *pBribe_Dlg = NULL;
 **************************************************************************/
 static int bribe_dlg_window_callback(struct widget *pWindow)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     move_window_group(pBribe_Dlg->pdialog->pBeginWidgetList, pWindow);
   }
 
@@ -1729,7 +1729,7 @@ static int bribe_dlg_window_callback(struct widget *pWindow)
 **************************************************************************/
 static int diplomat_bribe_yes_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     if (NULL != game_unit_by_number(pBribe_Dlg->actor_unit_id)
         && NULL != game_unit_by_number(pBribe_Dlg->target_id)) {
       request_do_action(ACTION_SPY_BRIBE_UNIT, pBribe_Dlg->actor_unit_id,
@@ -1746,7 +1746,7 @@ static int diplomat_bribe_yes_callback(struct widget *pWidget)
 **************************************************************************/
 static int exit_bribe_dlg_callback(struct widget *pWidget)
 {
-  if (Main.event.button.button == SDL_BUTTON_LEFT) {
+  if (PRESSED_EVENT(Main.event)) {
     popdown_bribe_dialog();
   }
 
