@@ -1073,7 +1073,7 @@ void ui_main(int argc, char *argv[])
 /**************************************************************************
   Do any necessary UI-specific cleanup
 **************************************************************************/
-void ui_exit()
+void ui_exit(void)
 {
 
 #if defined UNDER_CE && defined SMALL_SCREEN
@@ -1233,11 +1233,3 @@ void insert_client_build_info(char *outbuf, size_t outlen)
 {
   /* PORTME */
 }
-
-/**************************************************************************
-  Make dynamic adjustments to first-launch default options.
-**************************************************************************/
-void adjust_default_options(void)
-{
-  /* Nothing in case of this gui */
-}
