@@ -125,21 +125,21 @@ static int players_action_callback(struct widget *pWidget)
   set_wstate(pWidget, FC_WS_NORMAL);
   widget_redraw(pWidget);
   widget_mark_dirty(pWidget);
-  if (PRESSED_EVENT(Main.event)) {
+  if (Main.event.type == SDL_MOUSEBUTTONDOWN) {
     switch (Main.event.button.button) {
 #if 0
-      case SDL_BUTTON_LEFT:
+    case SDL_BUTTON_LEFT:
 
       break;
-      case SDL_BUTTON_MIDDLE:
+    case SDL_BUTTON_MIDDLE:
 
       break;
 #endif /* 0 */
-      case SDL_BUTTON_RIGHT:
-        popup_players_nations_dialog();
+    case SDL_BUTTON_RIGHT:
+      popup_players_nations_dialog();
       break;
-      default:
-        popup_players_dialog(true);
+    default:
+      popup_players_dialog(true);
       break;
     }
   } else {
@@ -172,25 +172,28 @@ static int cities_action_callback(struct widget *pButton)
   set_wstate(pButton, FC_WS_DISABLED);
   widget_redraw(pButton);
   widget_mark_dirty(pButton);
-  if (PRESSED_EVENT(Main.event)) {
+  if (Main.event.type == SDL_KEYDOWN) {
+    /* Ctrl-F shortcut */
+    popup_find_dialog();
+  } else if (Main.event.type == SDL_MOUSEBUTTONDOWN) {
     switch (Main.event.button.button) {
 #if 0
-      case SDL_BUTTON_LEFT:
+    case SDL_BUTTON_LEFT:
 
       break;
-      case SDL_BUTTON_MIDDLE:
+    case SDL_BUTTON_MIDDLE:
 
       break;
 #endif /* 0 */
-      case SDL_BUTTON_RIGHT:
-        popup_find_dialog();
+    case SDL_BUTTON_RIGHT:
+      popup_find_dialog();
       break;
-      default:
-        city_report_dialog_popup(FALSE);
+    default:
+      city_report_dialog_popup(FALSE);
       break;
     }
-  } else {
-    popup_find_dialog();
+  } else if (PRESSED_EVENT(Main.event)) {
+    city_report_dialog_popup(FALSE);
   }
 
   return -1;
@@ -201,10 +204,7 @@ static int cities_action_callback(struct widget *pButton)
 **************************************************************************/
 static int end_turn_callback(struct widget *pButton)
 {
-  if (Main.event.type == SDL_KEYDOWN
-      || Main.event.type == SDL_FINGERDOWN
-      || (Main.event.type == SDL_MOUSEBUTTONDOWN
-          && Main.event.button.button == SDL_BUTTON_LEFT)) {
+  if (PRESSED_EVENT(Main.event)) {
     widget_redraw(pButton);
     widget_flush(pButton);
     disable_focus_animation();
@@ -1301,23 +1301,27 @@ static int minimap_window_callback(struct widget *pWidget)
 **************************************************************************/
 static int unit_info_window_callback(struct widget *pWidget)
 {
-  switch(Main.event.button.button) {
+  if (Main.event.type == SDL_MOUSEBUTTONDOWN) {
+    switch (Main.event.button.button) {
 #if 0
     case SDL_BUTTON_LEFT:
 
-    break;
+      break;
 #endif
     case SDL_BUTTON_MIDDLE:
       request_center_focus_unit();
-    break;
+      break;
     case SDL_BUTTON_RIGHT:
 #ifdef SCALE_UNITINFO
       popup_unitinfo_scale_dialog();
 #endif
-    break;
+      break;
     default:
       key_unit_wait();
-    break;
+      break;
+    }
+  } else if (PRESSED_EVENT(Main.event)) {
+    key_unit_wait();
   }
 
   return -1;
@@ -2740,10 +2744,7 @@ static int newcity_name_edit_callback(struct widget *pEdit)
 **************************************************************************/
 static int newcity_ok_callback(struct widget *ok_button)
 {
-  if (Main.event.type == SDL_KEYDOWN
-      || Main.event.type == SDL_FINGERDOWN
-      || (Main.event.type == SDL_MOUSEBUTTONDOWN
-          && Main.event.button.button == SDL_BUTTON_LEFT)) {
+  if (PRESSED_EVENT(Main.event)) {
 
     finish_city(ok_button->data.tile, pNewCity_Dlg->pBeginWidgetList->string_utf8->text);
 
