@@ -38,6 +38,22 @@ void gui_canvas_free(struct canvas *store)
   /* PORTME */
 }
 
+/****************************************************************************
+  Set canvas zoom for future drawing operations.
+****************************************************************************/
+void gui_canvas_set_zoom(struct canvas *store, float zoom)
+{
+  /* PORTME */
+}
+
+/****************************************************************************
+  This gui has zoom support.
+****************************************************************************/
+bool gui_has_zoom_support(void)
+{
+  return FALSE;
+}
+
 /****************************************************************************
   Copies an area from the source canvas to the destination canvas.
 ****************************************************************************/
@@ -101,15 +117,6 @@ void gui_canvas_fill_sprite_area(struct canvas *pcanvas,
   /* PORTME */
 }
 
-/****************************************************************************
-  Fill the area covered by the sprite with the given color.
-****************************************************************************/
-void gui_canvas_fog_sprite_area(struct canvas *pcanvas, struct sprite *psprite,
-                                int canvas_x, int canvas_y)
-{
-  /* PORTME */
-}
-
 /****************************************************************************
   Draw a 1-pixel-width colored line onto the canvas.
 ****************************************************************************/
