@@ -45,7 +45,7 @@ void really_close_connection_dialog(void)
  Close and destroy the dialog. But only if we don't have a local
  server running (that we started).
 **************************************************************************/
-void gui_close_connection_dialog()
+void gui_close_connection_dialog(void)
 {
   /* PORTME */
 }
