@@ -22,6 +22,9 @@
 #include "client_main.h"
 #include "control.h"
 
+/* gui main header */
+#include "gui_stub.h"
+
 #include "gotodlg.h"
 
 /**************************************************************************
