@@ -12,9 +12,12 @@
 ***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <fc_config.h>
 #endif
 
+/* gui main header */
+#include "gui_stub.h"
+
 /* client */
 #include "voteinfo.h"
 
