@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #include "map.h"
 #include "packets.h"
 #include "player.h"
+#include "research.h"
 
 /* client */
 #include "client_main.h"
@@ -252,6 +253,7 @@ static void popup_diplomacy_dialog(int other_player_id)
 static int fill_diplomacy_tech_menu(Widget popupmenu, 
 				    struct player *plr0, struct player *plr1)
 {
+  const struct research *presearch0, *presearch1;
   int flag = 0;
 
   if (!game.info.trading_tech) {
@@ -259,11 +261,13 @@ static int fill_diplomacy_tech_menu(Widget popupmenu,
     return 0;
   }
 
+  presearch0 = research_get(plr0);
+  presearch1 = research_get(plr1);
   advance_index_iterate(A_FIRST, i) {
-    if (player_invention_state(plr0, i) == TECH_KNOWN
-        && player_invention_reachable(plr1, i, FALSE)
-        && (player_invention_state(plr1, i) == TECH_UNKNOWN
-	    || player_invention_state(plr1, i) == TECH_PREREQS_KNOWN)) {
+    if (research_invention_state(presearch0, i) == TECH_KNOWN
+        && research_invention_gettable(presearch1, i,
+                                       game.info.tech_trade_allow_holes)
+        && research_invention_state(presearch1, i) != TECH_KNOWN) {
       Widget entry=
 	XtVaCreateManagedWidget(advance_name_translation(advance_by_number(i)),
 				smeBSBObjectClass,
@@ -311,21 +315,21 @@ static int fill_diplomacy_city_menu(Widget popupmenu,
   } city_list_iterate_end;
 
   qsort(city_list_ptrs, i, sizeof(struct city*), city_name_compare);
-  
-  for(j=0; j<i; j++) {
-    Widget entry=
-      XtVaCreateManagedWidget(city_name(city_list_ptrs[j]), smeBSBObjectClass, 
-			      popupmenu, NULL);
+
+  for (j = 0; j < i; j++) {
+    Widget entry =
+      XtVaCreateManagedWidget(city_name_get(city_list_ptrs[j]), smeBSBObjectClass,
+                              popupmenu, NULL);
     XtAddCallback(entry, XtNcallback, diplomacy_dialog_city_callback,
-		  INT_TO_XTPOINTER((player_number(plr0) << 24) |
-				   (player_number(plr1) << 16) |
-				   city_list_ptrs[j]->id));
+                  INT_TO_XTPOINTER((player_number(plr0) << 24) |
+                                   (player_number(plr1) << 16) |
+                                   city_list_ptrs[j]->id));
   }
   free(city_list_ptrs);
+
   return i;
 }
 
-
 /****************************************************************
 ...
 *****************************************************************/
