@@ -59,6 +59,8 @@
 
 static void pixmap_put_overlay_tile(Pixmap pixmap, int x, int y,
  				    struct sprite *ssprite);
+static void canvas_fog_sprite_area(struct canvas *pcanvas, struct sprite *psprite,
+                                   int canvas_x, int canvas_y);
 
 /* the intro picture is held in this pixmap, which is scaled to
    the screen size */
@@ -83,8 +85,8 @@ void overview_size_changed(void)
 {
   Dimension h, w;
 
-  XtVaSetValues(overview_canvas, XtNwidth, overview.width, XtNheight,
-		overview.height, NULL);
+  XtVaSetValues(overview_canvas, XtNwidth, gui_options.overview.width,
+                XtNheight, gui_options.overview.height, NULL);
 
   XtVaGetValues(left_column_form, XtNheight, &h, NULL);
   XtVaSetValues(map_form, XtNheight, h, NULL);
@@ -95,7 +97,7 @@ void overview_size_changed(void)
 }
 
 /**************************************************************************
-...
+  Create a canvas of the given size.
 **************************************************************************/
 struct canvas *canvas_create(int width, int height)
 {
@@ -107,7 +109,8 @@ struct canvas *canvas_create(int width, int height)
 }
 
 /**************************************************************************
-...
+  Free any resources associated with this canvas and the canvas struct
+  itself.
 **************************************************************************/
 void canvas_free(struct canvas *store)
 {
@@ -115,6 +118,22 @@ void canvas_free(struct canvas *store)
   free(store);
 }
 
+/****************************************************************************
+  Set canvas zoom for future drawing operations.
+****************************************************************************/
+void canvas_set_zoom(struct canvas *store, float zoom)
+{
+  /* xaw-client has no zoom support */
+}
+
+/****************************************************************************
+  This gui has zoom support.
+****************************************************************************/
+bool has_zoom_support(void)
+{
+  return FALSE;
+}
+
 /****************************************************************************
   Return a canvas that is the overview window.
 ****************************************************************************/
@@ -232,6 +251,9 @@ void update_unit_info_label(struct unit_list *punitlist)
     case HOVER_PARADROP:
       XDefineCursor(display, XtWindow(map_canvas), cursors[CURSOR_PARADROP]);
       break;
+    case HOVER_ACT_SEL_TGT:
+      XDefineCursor(display, XtWindow(map_canvas), cursors[CURSOR_SELECT]);
+      break;
     }
   } else {
     xaw_set_label(unit_info_label, "");
@@ -475,8 +497,8 @@ void canvas_fill_sprite_area(struct canvas *pcanvas,
 /****************************************************************************
   Fill the area covered by the sprite with the given color.
 ****************************************************************************/
-void canvas_fog_sprite_area(struct canvas *pcanvas, struct sprite *psprite,
-			    int canvas_x, int canvas_y)
+static void canvas_fog_sprite_area(struct canvas *pcanvas, struct sprite *psprite,
+                                   int canvas_x, int canvas_y)
 {
   if (psprite->has_mask) {
     XSetClipOrigin(display, fill_tile_gc, canvas_x, canvas_y);
@@ -642,7 +664,8 @@ void gui_flush(void)
 void update_map_canvas_scrollbars(void)
 {
   float shown_h, top_h, shown_v, top_v;
-  int xmin, ymin, xmax, ymax, xsize, ysize;
+  float xmin, ymin, xmax, ymax;
+  int xsize, ysize;
   int scroll_x, scroll_y;
 
   get_mapview_scroll_window(&xmin, &ymin, &xmax, &ymax, &xsize, &ysize);
@@ -678,24 +701,24 @@ void update_city_descriptions(void)
 Draw at x = left of string, y = top of string.
 **************************************************************************/
 static void draw_shadowed_string(struct canvas *pcanvas,
-				 XFontSet fontset, GC font_gc,
-				 struct color *foreground,
-				 struct color *shadow,
-				 int x, int y, const char *string)
+                                 XFontSet fontset, GC fgc,
+                                 struct color *foreground,
+                                 struct color *shadow,
+                                 int x, int y, const char *string)
 {
   size_t len = strlen(string);
 
   y -= XExtentsOfFontSet(fontset)->max_logical_extent.y;
 
   if (foreground->color.pixel != shadow->color.pixel) {
-    XSetForeground(display, font_gc, shadow->color.pixel);
-    XmbDrawString(display, pcanvas->pixmap, fontset, font_gc,
+    XSetForeground(display, fgc, shadow->color.pixel);
+    XmbDrawString(display, pcanvas->pixmap, fontset, fgc,
                   x + 1, y + 1, string, len);
   }
 
-  XSetForeground(display, font_gc, foreground->color.pixel);
-  XmbDrawString(display, pcanvas->pixmap, fontset, font_gc,
-      x, y, string, len);
+  XSetForeground(display, fgc, foreground->color.pixel);
+  XmbDrawString(display, pcanvas->pixmap, fontset, fgc,
+                x, y, string, len);
 }
 
 static XFontSet *fonts[FONT_COUNT] = {&main_font_set, &prod_font_set};
@@ -772,7 +795,7 @@ static void pixmap_put_overlay_tile(Pixmap pixmap, int canvas_x, int canvas_y,
 **************************************************************************/
 void put_cross_overlay_tile(struct tile *ptile)
 {
-  int canvas_x, canvas_y;
+  float canvas_x, canvas_y;
 
   if (tile_to_canvas_pos(&canvas_x, &canvas_y, ptile)) {
     pixmap_put_overlay_tile(XtWindow(map_canvas), canvas_x, canvas_y,
@@ -787,7 +810,8 @@ void scrollbar_jump_callback(Widget w, XtPointer client_data,
 			     XtPointer percent_ptr)
 {
   float percent=*(float*)percent_ptr;
-  int xmin, ymin, xmax, ymax, xsize, ysize;
+  float xmin, ymin, xmax, ymax;
+  int xsize, ysize;
   int scroll_x, scroll_y;
 
   if (!can_client_change_view()) {
