@@ -224,8 +224,9 @@ void create_start_page(void)
 
 /**************************************************************************
   Update start page players list.
+  (Separate from update_start_page() to avoid recursion.)
 **************************************************************************/
-void update_start_page(void)
+void real_update_start_page(void)
 {
   if (!start_page_shell) {
     return;
@@ -303,6 +304,14 @@ void update_start_page(void)
   }
 }
 
+/**************************************************************************
+  Entry point to update start page.
+**************************************************************************/
+void update_start_page(void)
+{
+  real_update_start_page();
+}
+
 /**************************************************************************
   Callback for start page "Cancel" button
 **************************************************************************/
