@@ -38,7 +38,7 @@
 /**************************************************************************
   Setup the gui callback table.
 **************************************************************************/
-void setup_gui_funcs()
+void setup_gui_funcs(void)
 {
   struct gui_funcs *funcs = get_gui_funcs();
 
@@ -48,7 +48,6 @@ void setup_gui_funcs()
 
   funcs->get_gui_type = gui_get_gui_type;
   funcs->insert_client_build_info = gui_insert_client_build_info;
-  funcs->adjust_default_options = gui_adjust_default_options;
 
   funcs->version_message = gui_version_message;
   funcs->real_output_window_append = gui_real_output_window_append;
