@@ -101,14 +101,6 @@ void insert_client_build_info(char *outbuf, size_t outlen)
   funcs.insert_client_build_info(outbuf, outlen);
 }
 
-/**************************************************************************
-  Call adjust_default_options callback
-**************************************************************************/
-void adjust_default_options(void)
-{
-  funcs.adjust_default_options();
-}
-
 /**************************************************************************
   Call is_view_supported callback
 **************************************************************************/
@@ -373,7 +365,7 @@ void real_conn_list_dialog_update(void *unused)
 /**************************************************************************
   Call close_connection_dialog callback
 **************************************************************************/
-void close_connection_dialog()
+void close_connection_dialog(void)
 {
   funcs.close_connection_dialog();
 }
@@ -546,7 +538,7 @@ void popdown_city_dialog(struct city *pcity)
 /**************************************************************************
   Call popdown_all_city_dialogs callback
 **************************************************************************/
-void popdown_all_city_dialogs()
+void popdown_all_city_dialogs(void)
 {
   funcs.popdown_all_city_dialogs();
 }
@@ -554,7 +546,7 @@ void popdown_all_city_dialogs()
 /**************************************************************************
   Call handmade_scenario_warning callback
 **************************************************************************/
-bool handmade_scenario_warning()
+bool handmade_scenario_warning(void)
 {
   return funcs.handmade_scenario_warning();
 }
