@@ -63,6 +63,12 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_game_info(packet);
     return TRUE;
 
+  case PACKET_TIMEOUT_INFO:
+    handle_timeout_info(
+      ((const struct packet_timeout_info *)packet)->seconds_to_phasedone,
+      ((const struct packet_timeout_info *)packet)->last_turn_change_time);
+    return TRUE;
+
   case PACKET_MAP_INFO:
     handle_map_info(
       ((const struct packet_map_info *)packet)->xsize,
@@ -81,12 +87,19 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_team_name_info *)packet)->team_name);
     return TRUE;
 
+  case PACKET_ACHIEVEMENT_INFO:
+    handle_achievement_info(
+      ((const struct packet_achievement_info *)packet)->id,
+      ((const struct packet_achievement_info *)packet)->gained,
+      ((const struct packet_achievement_info *)packet)->first);
+    return TRUE;
+
   case PACKET_CHAT_MSG:
-    handle_chat_msg(
-      ((const struct packet_chat_msg *)packet)->message,
-      ((const struct packet_chat_msg *)packet)->tile,
-      ((const struct packet_chat_msg *)packet)->event,
-      ((const struct packet_chat_msg *)packet)->conn_id);
+    handle_chat_msg(packet);
+    return TRUE;
+
+  case PACKET_EARLY_CHAT_MSG:
+    handle_early_chat_msg(packet);
     return TRUE;
 
   case PACKET_CONNECT_MSG:
@@ -120,6 +133,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_city_sabotage_list *)packet)->improvements);
     return TRUE;
 
+  case PACKET_WORKER_TASK:
+    handle_worker_task(packet);
+    return TRUE;
+
   case PACKET_PLAYER_REMOVE:
     handle_player_remove(
       ((const struct packet_player_remove *)packet)->playerno);
@@ -129,11 +146,6 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_player_info(packet);
     return TRUE;
 
-  case PACKET_TECH_GAINED:
-    handle_tech_gained(
-      ((const struct packet_tech_gained *)packet)->tech);
-    return TRUE;
-
   case PACKET_PLAYER_ATTRIBUTE_CHUNK:
     handle_player_attribute_chunk(packet);
     return TRUE;
@@ -142,6 +154,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_player_diplstate(packet);
     return TRUE;
 
+  case PACKET_RESEARCH_INFO:
+    handle_research_info(packet);
+    return TRUE;
+
   case PACKET_UNIT_REMOVE:
     handle_unit_remove(
       ((const struct packet_unit_remove *)packet)->unit_id);
@@ -164,12 +180,16 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_unit_combat_info *)packet)->make_winner_veteran);
     return TRUE;
 
-  case PACKET_UNIT_DIPLOMAT_ANSWER:
-    handle_unit_diplomat_answer(
-      ((const struct packet_unit_diplomat_answer *)packet)->diplomat_id,
-      ((const struct packet_unit_diplomat_answer *)packet)->target_id,
-      ((const struct packet_unit_diplomat_answer *)packet)->cost,
-      ((const struct packet_unit_diplomat_answer *)packet)->action_type);
+  case PACKET_UNIT_ACTION_ANSWER:
+    handle_unit_action_answer(
+      ((const struct packet_unit_action_answer *)packet)->diplomat_id,
+      ((const struct packet_unit_action_answer *)packet)->target_id,
+      ((const struct packet_unit_action_answer *)packet)->cost,
+      ((const struct packet_unit_action_answer *)packet)->action_type);
+    return TRUE;
+
+  case PACKET_UNIT_ACTIONS:
+    handle_unit_actions(packet);
     return TRUE;
 
   case PACKET_DIPLOMACY_INIT_MEETING:
@@ -207,21 +227,13 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_diplomacy_accept_treaty *)packet)->other_accepted);
     return TRUE;
 
-  case PACKET_PAGE_MSG_OLD:
-    handle_page_msg_old(
-      ((const struct packet_page_msg_old *)packet)->caption,
-      ((const struct packet_page_msg_old *)packet)->headline,
-      ((const struct packet_page_msg_old *)packet)->lines,
-      ((const struct packet_page_msg_old *)packet)->event);
-    return TRUE;
-
-  case PACKET_PAGE_MSG_NEW:
-    handle_page_msg_new(
-      ((const struct packet_page_msg_new *)packet)->caption,
-      ((const struct packet_page_msg_new *)packet)->headline,
-      ((const struct packet_page_msg_new *)packet)->event,
-      ((const struct packet_page_msg_new *)packet)->len,
-      ((const struct packet_page_msg_new *)packet)->parts);
+  case PACKET_PAGE_MSG:
+    handle_page_msg(
+      ((const struct packet_page_msg *)packet)->caption,
+      ((const struct packet_page_msg *)packet)->headline,
+      ((const struct packet_page_msg *)packet)->event,
+      ((const struct packet_page_msg *)packet)->len,
+      ((const struct packet_page_msg *)packet)->parts);
     return TRUE;
 
   case PACKET_PAGE_MSG_PART:
@@ -256,6 +268,7 @@ bool client_handle_packet(enum packet_type type, const void *packet)
   case PACKET_NEW_YEAR:
     handle_new_year(
       ((const struct packet_new_year *)packet)->year,
+      ((const struct packet_new_year *)packet)->fragments,
       ((const struct packet_new_year *)packet)->turn);
     return TRUE;
 
@@ -342,6 +355,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_nation_availability *)packet)->nationset_change);
     return TRUE;
 
+  case PACKET_RULESET_STYLE:
+    handle_ruleset_style(packet);
+    return TRUE;
+
   case PACKET_RULESET_CITY:
     handle_ruleset_city(packet);
     return TRUE;
@@ -362,6 +379,10 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_ruleset_unit_class(packet);
     return TRUE;
 
+  case PACKET_RULESET_EXTRA:
+    handle_ruleset_extra(packet);
+    return TRUE;
+
   case PACKET_RULESET_BASE:
     handle_ruleset_base(packet);
     return TRUE;
@@ -374,14 +395,42 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_ruleset_disaster(packet);
     return TRUE;
 
+  case PACKET_RULESET_ACHIEVEMENT:
+    handle_ruleset_achievement(packet);
+    return TRUE;
+
   case PACKET_RULESET_TRADE:
     handle_ruleset_trade(packet);
     return TRUE;
 
+  case PACKET_RULESET_ACTION:
+    handle_ruleset_action(packet);
+    return TRUE;
+
+  case PACKET_RULESET_ACTION_ENABLER:
+    handle_ruleset_action_enabler(packet);
+    return TRUE;
+
+  case PACKET_RULESET_MUSIC:
+    handle_ruleset_music(packet);
+    return TRUE;
+
+  case PACKET_RULESET_MULTIPLIER:
+    handle_ruleset_multiplier(packet);
+    return TRUE;
+
   case PACKET_RULESET_CONTROL:
     handle_ruleset_control(packet);
     return TRUE;
 
+  case PACKET_RULESET_SUMMARY:
+    handle_ruleset_summary(packet);
+    return TRUE;
+
+  case PACKET_RULESET_DESCRIPTION_PART:
+    handle_ruleset_description_part(packet);
+    return TRUE;
+
   case PACKET_SINGLE_WANT_HACK_REPLY:
     handle_single_want_hack_reply(
       ((const struct packet_single_want_hack_reply *)packet)->you_have_hack);
@@ -425,12 +474,13 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_server_setting_bitwise(packet);
     return TRUE;
 
-  case PACKET_RULESET_EFFECT:
-    handle_ruleset_effect(packet);
+  case PACKET_SET_TOPOLOGY:
+    handle_set_topology(
+      ((const struct packet_set_topology *)packet)->topology_id);
     return TRUE;
 
-  case PACKET_RULESET_EFFECT_REQ:
-    handle_ruleset_effect_req(packet);
+  case PACKET_RULESET_EFFECT:
+    handle_ruleset_effect(packet);
     return TRUE;
 
   case PACKET_RULESET_RESOURCE:
@@ -441,6 +491,11 @@ bool client_handle_packet(enum packet_type type, const void *packet)
     handle_scenario_info(packet);
     return TRUE;
 
+  case PACKET_SCENARIO_DESCRIPTION:
+    handle_scenario_description(
+      ((const struct packet_scenario_description *)packet)->description);
+    return TRUE;
+
   case PACKET_VOTE_NEW:
     handle_vote_new(packet);
     return TRUE;
@@ -479,6 +534,11 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_edit_object_created *)packet)->id);
     return TRUE;
 
+  case PACKET_PLAY_MUSIC:
+    handle_play_music(
+      ((const struct packet_play_music *)packet)->tag);
+    return TRUE;
+
   default:
     return FALSE;
   }
