@@ -127,7 +127,7 @@ void get_economy_report_units_data(struct unit_entry *entries,
 
     city_list_iterate(client.conn.playing->cities, pcity) {
       unit_list_iterate(pcity->units_supported, punit) {
-	if (unit_type(punit) == unittype) {
+	if (unit_type_get(punit) == unittype) {
 	  count++;
 	  partial_cost += punit->upkeep[O_GOLD];
 	}
@@ -220,7 +220,7 @@ void disband_all_units(struct unit_type *punittype, bool in_cities_only,
     unit_list_iterate(pcity->units_supported, punit) {
       struct city *incity = tile_city(unit_tile(punit));
 
-      if (unit_type(punit) == punittype
+      if (unit_type_get(punit) == punittype
 	  && (!in_cities_only
 	      || (incity && city_owner(incity) == client.conn.playing))) {
 	count++;
