@@ -31,6 +31,7 @@
 #include "citizens.h"
 #include "clientutils.h"
 #include "combat.h"
+#include "culture.h"
 #include "fc_types.h" /* LINE_BREAK */
 #include "game.h"
 #include "government.h"
@@ -278,15 +279,19 @@ const char *popup_info_text(struct tile *ptile)
       int count = unit_list_size(ptile->units);
 
       if (count > 0) {
+        /* TRANS: preserve leading space */
         astr_add(&str, PL_(" | Occupied with %d unit.",
                                 " | Occupied with %d units.", count), count);
       } else {
+        /* TRANS: preserve leading space */
         astr_add(&str, _(" | Not occupied."));
       }
     } else {
       if (pcity->client.occupied) {
+        /* TRANS: preserve leading space */
         astr_add(&str, _(" | Occupied."));
       } else {
+        /* TRANS: preserve leading space */
         astr_add(&str, _(" | Not occupied."));
       }
     }
@@ -1003,6 +1008,14 @@ const char *get_info_label_text_popup(void)
       fc_assert(upkeep == 0);
       astr_add_line(&str, _("Bulbs per turn: %d"), perturn);
     }
+    {
+      int history_perturn = nation_history_gain(client.conn.playing);
+      city_list_iterate(client.conn.playing->cities, pcity) {
+        history_perturn += city_history_gain(pcity);
+      } city_list_iterate_end;
+      astr_add_line(&str, _("Culture: %d (%+d/turn)"),
+                    player_culture(client.conn.playing), history_perturn);
+    }
   }
 
   /* See also get_global_warming_tooltip and get_nuclear_winter_tooltip. */
