@@ -476,14 +476,20 @@ static bool get_discounted_reward(const struct unit *caravan,
   }
 
   consider_wonder = parameter->consider_wonders
-    && is_action_enabled_unit_on_city_full(ACTION_HELP_WONDER,
-                                           caravan, dest, src, TRUE);
+    && action_prob_possible(
+        action_speculate_unit_on_city(ACTION_HELP_WONDER,
+                                      caravan, src, city_tile(dest),
+                                      TRUE, dest));
   consider_trade = parameter->consider_trade
-    && is_action_enabled_unit_on_city_full(ACTION_TRADE_ROUTE,
-                                           caravan, dest, src, TRUE);
+    && action_prob_possible(
+        action_speculate_unit_on_city(ACTION_TRADE_ROUTE,
+                                      caravan, src, city_tile(dest),
+                                      TRUE, dest));
   consider_windfall = parameter->consider_windfall
-    && is_action_enabled_unit_on_city_full(ACTION_MARKETPLACE,
-                                           caravan, dest, src, TRUE);
+    && action_prob_possible(
+        action_speculate_unit_on_city(ACTION_MARKETPLACE,
+                                      caravan, src, city_tile(dest),
+                                      TRUE, dest));
 
   if (!consider_wonder && !consider_trade && !consider_windfall) {
     /* No caravan action is possible against this target. */
