@@ -1,4 +1,4 @@
-/**********************************************************************0
+/***********************************************************************
  Freeciv - Copyright (C) 2002 - The Freeciv Project
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -278,7 +278,8 @@ static void cm_result_copy(struct cm_result *result,
 
 static double estimate_fitness(const struct cm_state *state,
 			       const int production[]);
-static bool choice_is_promising(struct cm_state *state, int newchoice);
+static bool choice_is_promising(struct cm_state *state, int newchoice,
+                                bool negative_ok);
 
 /****************************************************************************
   Initialize the CM data at the start of each game.  Note the citymap
@@ -433,8 +434,8 @@ static void tile_type_vector_free_all(struct tile_type_vector *vec)
 static bool tile_type_equal(const struct cm_tile_type *a,
 			    const struct cm_tile_type *b)
 {
-  output_type_iterate(stat) {
-    if (a->production[stat] != b->production[stat])  {
+  output_type_iterate(stat_index) {
+    if (a->production[stat_index] != b->production[stat_index])  {
       return FALSE;
     }
   } output_type_iterate_end;
@@ -455,8 +456,8 @@ static bool tile_type_equal(const struct cm_tile_type *a,
 static bool tile_type_better(const struct cm_tile_type *a,
 			     const struct cm_tile_type *b)
 {
-  output_type_iterate(stat) {
-    if (a->production[stat] < b->production[stat])  {
+  output_type_iterate(stat_index) {
+    if (a->production[stat_index] < b->production[stat_index])  {
       return FALSE;
     }
   } output_type_iterate_end;
@@ -590,9 +591,9 @@ static struct cm_fitness compute_fitness(const int surplus[],
   fitness.sufficient = TRUE;
   fitness.weighted = 0;
 
-  output_type_iterate(stat) {
-    fitness.weighted += surplus[stat] * parameter->factor[stat];
-    if (surplus[stat] < parameter->minimal_surplus[stat]) {
+  output_type_iterate(stat_index) {
+    fitness.weighted += surplus[stat_index] * parameter->factor[stat_index];
+    if (surplus[stat_index] < parameter->minimal_surplus[stat_index]) {
       fitness.sufficient = FALSE;
     }
   } output_type_iterate_end;
@@ -621,17 +622,23 @@ static struct cm_fitness compute_fitness(const int surplus[],
   Allocate and initialize an empty solution.
 ****************************************************************************/
 static void init_partial_solution(struct partial_solution *into,
-                                  int ntypes, int idle)
+                                  int ntypes, int idle, bool negative_ok)
 {
   into->worker_counts = fc_calloc(ntypes, sizeof(*into->worker_counts));
   into->prereqs_filled = fc_calloc(ntypes, sizeof(*into->prereqs_filled));
-  memset(into->production, 0, sizeof(into->production));
+  if (negative_ok) {
+    output_type_iterate(otype) {
+      into->production[otype] = -FC_INFINITY;
+    } output_type_iterate_end;
+  } else {
+    memset(into->production, 0, sizeof(into->production));
+  }
   into->idle = idle;
 }
 
 /****************************************************************************
   Free all storage associated with the solution.  This is basically the
-  opposite of init_partial_solution.
+  opposite of init_partial_solution().
 ****************************************************************************/
 static void destroy_partial_solution(struct partial_solution *into)
 {
@@ -766,11 +773,11 @@ static struct cm_fitness evaluate_solution(struct cm_state *state,
        (Specialists may also be making angry citizens content, requiring
        additional luxuries, but we don't try to consider that here; this
        just means we might explore some solutions unnecessarily.) */
-    int specialist_count = city_specialists(pcity);
+    int specialists_amount = city_specialists(pcity);
     int max_content = player_content_citizens(city_owner(pcity));
 
     state->min_luxury = surplus[O_LUXURY] 
-       + game.info.happy_cost * MAX(specialist_count - max_content, 0)
+      + game.info.happy_cost * MAX(specialists_amount - max_content, 0)
        + 1;
   }
 
@@ -829,9 +836,9 @@ static int compare_tile_type_by_lattice_order(const struct cm_tile_type *a,
   }
 
   /* With equal depth, break ties arbitrarily, more production first. */
-  output_type_iterate(stat) {
-    if (a->production[stat] != b->production[stat]) {
-      return b->production[stat] - a->production[stat];
+  output_type_iterate(stat_index) {
+    if (a->production[stat_index] != b->production[stat_index]) {
+      return b->production[stat_index] - a->production[stat_index];
     }
   } output_type_iterate_end;
 
@@ -936,7 +943,7 @@ static void compute_tile_production(const struct city *pcity,
 ****************************************************************************/
 static void tile_type_lattice_add(struct tile_type_vector *lattice,
                                   const struct cm_tile_type *newtype,
-                                  int index)
+                                  int tindex)
 {
   struct cm_tile_type *type;
   int i;
@@ -970,7 +977,7 @@ static void tile_type_lattice_add(struct tile_type_vector *lattice,
     struct cm_tile tile;
 
     tile.type = type;
-    tile.index = index;
+    tile.index = tindex;
 
     tile_vector_append(&type->tiles, tile);
   }
@@ -1200,12 +1207,12 @@ static void init_tile_lattice(struct city *pcity,
   tile_type_init(&type); /* init just once */
 
   city_tile_iterate_index(city_map_radius_sq_get(pcity), pcenter, ptile,
-                          index) {
+                          ctindex) {
     if (is_free_worked(pcity, ptile)) {
       continue;
     } else if (city_can_work_tile(pcity, ptile)) {
       compute_tile_production(pcity, ptile, &type); /* clobbers type */
-      tile_type_lattice_add(lattice, &type, index); /* copy type if needed */
+      tile_type_lattice_add(lattice, &type, ctindex); /* copy type if needed */
     }
   } city_tile_iterate_index_end;
 
@@ -1303,10 +1310,9 @@ static void add_workers(struct partial_solution *soln,
   }
 
   /* update production */
-  output_type_iterate(stat) {
-    newcount = soln->production[stat] + number * ptype->production[stat];
-    fc_assert_ret(newcount >= 0);
-    soln->production[stat] = newcount;
+  output_type_iterate(stat_index) {
+    newcount = soln->production[stat_index] + number * ptype->production[stat_index];
+    soln->production[stat_index] = newcount;
   } output_type_iterate_end;
 }
 
@@ -1360,7 +1366,7 @@ static bool prereqs_filled(const struct partial_solution *soln, int type,
     solution so far.
   If oldchoice == -1 then we return the first possible choice.
 ****************************************************************************/
-static int next_choice(struct cm_state *state, int oldchoice)
+static int next_choice(struct cm_state *state, int oldchoice, bool negative_ok)
 {
   int newchoice;
 
@@ -1377,7 +1383,7 @@ static int next_choice(struct cm_state *state, int oldchoice)
       /* we could use a strictly better tile instead */
       continue;
     }
-    if (!choice_is_promising(state, newchoice)) {
+    if (!choice_is_promising(state, newchoice, negative_ok)) {
       /* heuristic says we can't beat the best going this way */
       log_base(LOG_PRUNE_BRANCH, "--- pruning branch ---");
       print_partial_solution(LOG_PRUNE_BRANCH, &state->current, state);
@@ -1398,14 +1404,14 @@ static int next_choice(struct cm_state *state, int oldchoice)
   Pick a sibling choice to the last choice.  This works down the branch to
   see if a choice that actually looks worse may actually be better.
 ****************************************************************************/
-static bool take_sibling_choice(struct cm_state *state)
+static bool take_sibling_choice(struct cm_state *state, bool negative_ok)
 {
   int oldchoice = last_choice(state);
   int newchoice;
 
   /* need to remove first, to run the heuristic */
   remove_worker(&state->current, oldchoice, state);
-  newchoice = next_choice(state, oldchoice);
+  newchoice = next_choice(state, oldchoice, negative_ok);
 
   if (newchoice == num_types(state)) {
     /* add back in so the caller can then remove it again. */
@@ -1423,10 +1429,10 @@ static bool take_sibling_choice(struct cm_state *state)
   Go down from the current branch, if we can.
   Thanks to the fact that the lattice is sorted by depth, we can keep the
   choice stack sorted -- that is, we can start our next choice as
-  last_choice-1.  This keeps us from trying out all permutations of the
+  last_choice - 1.  This keeps us from trying out all permutations of the
   same combination.
 ****************************************************************************/
-static bool take_child_choice(struct cm_state *state)
+static bool take_child_choice(struct cm_state *state, bool negative_ok)
 {
   int oldchoice, newchoice;
 
@@ -1441,7 +1447,7 @@ static bool take_child_choice(struct cm_state *state)
   }
 
   /* oldchoice-1 because we can use oldchoice again */
-  newchoice = next_choice(state, oldchoice - 1);
+  newchoice = next_choice(state, oldchoice - 1, negative_ok);
 
   /* did we fail? */
   if (newchoice == num_types(state)) {
@@ -1461,10 +1467,10 @@ static bool take_child_choice(struct cm_state *state)
   tile lattice.
 ****************************************************************************/
 static void complete_solution(struct partial_solution *soln,
-			      const struct cm_state *state,
-			      const struct tile_type_vector *lattice)
+                              const struct cm_state *state,
+                              const struct tile_type_vector *lattice)
 {
-  int last_choice = -1;
+  int last_worker_choice = -1;
   int i;
 
   if (soln->idle == 0) {
@@ -1474,7 +1480,7 @@ static void complete_solution(struct partial_solution *soln,
   /* find the last worker type added (-1 if none) */
   for (i = 0; i < num_types(state); i++) {
     if (soln->worker_counts[i] != 0) {
-      last_choice = i;
+      last_worker_choice = i;
     }
   }
 
@@ -1486,7 +1492,7 @@ static void complete_solution(struct partial_solution *soln,
     int total = tile_type_num_tiles(ptype);
     int touse;
 
-    if (ptype->lattice_index < last_choice) {
+    if (ptype->lattice_index < last_worker_choice) {
       /* lex-order: we can't use ptype (some other branch
          will check this combination, or already did) */
 	continue;
@@ -1540,7 +1546,7 @@ static int specialists_in_solution(const struct cm_state *state,
 static void compute_max_stats_heuristic(const struct cm_state *state,
 					const struct partial_solution *soln,
 					int production[],
-					int check_choice)
+					int check_choice, bool negative_ok)
 {
   struct partial_solution solnplus; /* will be soln, plus some tiles */
 
@@ -1554,24 +1560,25 @@ static void compute_max_stats_heuristic(const struct cm_state *state,
     const struct cm_tile_type *ptype = tile_type_get(state, check_choice);
 
     memcpy(production, soln->production, sizeof(soln->production));
-    output_type_iterate(stat) {
-      production[stat] += ptype->production[stat];
+    output_type_iterate(stat_index) {
+      production[stat_index] += ptype->production[stat_index];
     } output_type_iterate_end;
 
   } else {
 
     /* initialize solnplus here, after the shortcut check */
     init_partial_solution(&solnplus, num_types(state),
-                          city_size_get(state->pcity));
+                          city_size_get(state->pcity),
+                          negative_ok);
 
-    output_type_iterate(stat) {
+    output_type_iterate(stat_index) {
       /* compute the solution that has soln, then the check_choice,
          then complete it with the best available tiles for the stat. */
       copy_partial_solution(&solnplus, soln, state);
       add_worker(&solnplus, check_choice, state);
-      complete_solution(&solnplus, state, &state->lattice_by_prod[stat]);
+      complete_solution(&solnplus, state, &state->lattice_by_prod[stat_index]);
 
-      production[stat] = solnplus.production[stat];
+      production[stat_index] = solnplus.production[stat_index];
     } output_type_iterate_end;
 
     destroy_partial_solution(&solnplus);
@@ -1586,15 +1593,15 @@ static void compute_max_stats_heuristic(const struct cm_state *state,
   struct tile *pcenter = city_tile(pcity);
   bool is_celebrating = base_city_celebrating(pcity);
 
-  output_type_iterate(stat) {
-    int base = production[stat];
+  output_type_iterate(stat_index) {
+    int base = production[stat_index];
 
     city_tile_iterate(city_map_radius_sq_get(pcity), pcenter, ptile) {
       if (is_free_worked(pcity, ptile)) {
-	base += city_tile_output(pcity, ptile, is_celebrating, stat);
+	base += city_tile_output(pcity, ptile, is_celebrating, stat_index);
       }
     } city_tile_iterate_end;
-    pcity->citizen_base[stat] = base;
+    pcity->citizen_base[stat_index] = base;
   } output_type_iterate_end;
 
   set_city_production(pcity);
@@ -1607,7 +1614,8 @@ static void compute_max_stats_heuristic(const struct cm_state *state,
   A choice is also unpromising if any of the stats is less than the
   absolute minimum (in practice, this matters a lot more).
 ****************************************************************************/
-static bool choice_is_promising(struct cm_state *state, int newchoice)
+static bool choice_is_promising(struct cm_state *state, int newchoice,
+                                bool negative_ok)
 {
   int production[O_LAST];
   bool beats_best = FALSE;
@@ -1615,16 +1623,18 @@ static bool choice_is_promising(struct cm_state *state, int newchoice)
   /* this computes an upper bound (componentwise) for the current branch,
      if it is worse in every component than the best, or still unsufficient,
      then we can prune the whole branch */
-  compute_max_stats_heuristic(state, &state->current, production, newchoice);
+  compute_max_stats_heuristic(state, &state->current, production, newchoice,
+                              negative_ok);
 
-  output_type_iterate(stat) {
-    if (production[stat] < state->min_production[stat]) {
+  output_type_iterate(stat_index) {
+    if (production[stat_index] < state->min_production[stat_index]) {
       log_base(LOG_PRUNE_BRANCH, "--- pruning: insufficient %s (%d < %d)",
-               get_output_name(stat), production[stat],
-               state->min_production[stat]);
+               get_output_name(stat_index), production[stat_index],
+               state->min_production[stat_index]);
       return FALSE;
     }
-    if (production[stat] > state->best.production[stat] && state->parameter.factor[stat] > 0 ) {
+    if (production[stat_index] > state->best.production[stat_index]
+        && state->parameter.factor[stat_index] > 0 ) {
       beats_best = TRUE;
       /* may still fail to meet min at another production type, so
        * don't short-circuit */
@@ -1642,10 +1652,10 @@ static bool choice_is_promising(struct cm_state *state, int newchoice)
      FIXME: this heuristic will break in rulesets where specialists can
      influence happiness other than by direct production of luxury. */
   {
-    int specialist_count = specialists_in_solution(state, &state->current);
+    int specialists_amount = specialists_in_solution(state, &state->current);
     int max_content = player_content_citizens(city_owner(state->pcity));
     int specialists_suppress_unhappy
-      = MAX(specialist_count + state->current.idle - max_content, 0);
+      = MAX(specialists_amount + state->current.idle - max_content, 0);
     int max_luxury = production[O_LUXURY]
           + game.info.happy_cost * specialists_suppress_unhappy;
  
@@ -1721,16 +1731,17 @@ static double estimate_fitness(const struct cm_state *state,
   int rates[3];
   double estimates[O_LAST];
   double sum = 0;
+  int trade;
 
-  output_type_iterate(stat) {
-    estimates[stat] = production[stat];
+  output_type_iterate(stat_index) {
+    estimates[stat_index] = production[stat_index];
   } output_type_iterate_end;
 
   /* bonus to trade is applied before calculating taxes, see city.c */
-  int trade = estimates[O_TRADE] * pcity->bonus[O_TRADE] / 100.0;
-  
+  trade = estimates[O_TRADE] * pcity->bonus[O_TRADE] / 100.0;
+
   get_tax_rates(pplayer, rates);
-  
+
   /* sci/lux/gold get benefit from the tax rates (in percentage) */
   estimates[O_SCIENCE]
     += rates[SCIENCE] * trade / 100.0;
@@ -1740,14 +1751,14 @@ static double estimate_fitness(const struct cm_state *state,
     += rates[TAX] * trade / 100.0;
 
   /* now add in the bonuses from building effects (in percentage) */
-  output_type_iterate(stat) {
-    estimates[stat] *= pcity->bonus[stat] / 100.0;
+  output_type_iterate(stat_index) {
+    estimates[stat_index] *= pcity->bonus[stat_index] / 100.0;
   } output_type_iterate_end;
 
   /* finally, sum it all up, weighted by the parameter, but give additional
    * weight to luxuries to take account of disorder/happy constraints */
-  output_type_iterate(stat) {
-    sum += estimates[stat] * state->parameter.factor[stat];
+  output_type_iterate(stat_index) {
+    sum += estimates[stat_index] * state->parameter.factor[stat_index];
   } output_type_iterate_end;
   sum += estimates[O_LUXURY];
   return sum;
@@ -1767,7 +1778,7 @@ static double estimate_fitness(const struct cm_state *state,
   in the lattice.  If there are no idle workers left, then we pop out
   until we can make another choice.
 ****************************************************************************/
-static bool bb_next(struct cm_state *state)
+static bool bb_next(struct cm_state *state, bool negative_ok)
 {
   /* if no idle workers, then look at our solution. */
   if (state->current.idle == 0) {
@@ -1783,10 +1794,11 @@ static bool bb_next(struct cm_state *state)
 
   /* try to move to a child branch, if we can.  If not (including if we're
      at a leaf), then move to a sibling. */
-  if (!take_child_choice(state)) {
+  if (!take_child_choice(state, negative_ok)) {
     /* keep trying to move to a sibling branch, or popping out a level if
        we're stuck (fully examined the current branch) */
-    while ((!choice_stack_empty(state)) && !take_sibling_choice(state)) {
+    while ((!choice_stack_empty(state))
+           && !take_sibling_choice(state, negative_ok)) {
       pop_choice(state);
     }
 
@@ -1803,7 +1815,7 @@ static bool bb_next(struct cm_state *state)
 /****************************************************************************
   Initialize the state for the branch-and-bound algorithm.
 ****************************************************************************/
-static struct cm_state *cm_state_init(struct city *pcity)
+static struct cm_state *cm_state_init(struct city *pcity, bool negative_ok)
 {
   const int SCIENCE = 0, TAX = 1, LUXURY = 2;
   const struct player *pplayer = city_owner(pcity);
@@ -1812,7 +1824,7 @@ static struct cm_state *cm_state_init(struct city *pcity)
   int rates[3];
 
   log_base(LOG_CM_STATE, "creating cm_state for %s (size %d)",
-           city_name(pcity), city_size_get(pcity));
+           city_name_get(pcity), city_size_get(pcity));
 
   /* copy the arguments */
   state->pcity = pcity;
@@ -1825,13 +1837,13 @@ static struct cm_state *cm_state_init(struct city *pcity)
   get_tax_rates(pplayer, rates);
 
   /* For the heuristic, make sorted copies of the lattice */
-  output_type_iterate(stat) {
-    tile_type_vector_init(&state->lattice_by_prod[stat]);
-    tile_type_vector_copy(&state->lattice_by_prod[stat], &state->lattice);
-    compare_key = stat;
+  output_type_iterate(stat_index) {
+    tile_type_vector_init(&state->lattice_by_prod[stat_index]);
+    tile_type_vector_copy(&state->lattice_by_prod[stat_index], &state->lattice);
+    compare_key = stat_index;
     /* calculate effect of 1 trade production on interesting production */
-    switch(stat){
-      case O_SCIENCE: 
+    switch (stat_index) {
+      case O_SCIENCE:
         compare_key_trade_bonus = rates[SCIENCE] * pcity->bonus[O_TRADE] / 100.0;
 	break;
       case O_LUXURY:
@@ -1844,19 +1856,21 @@ static struct cm_state *cm_state_init(struct city *pcity)
         compare_key_trade_bonus = 0.0;
 	break;
     }
-    qsort(state->lattice_by_prod[stat].p, state->lattice_by_prod[stat].size,
-	  sizeof(*state->lattice_by_prod[stat].p),
-	  compare_tile_type_by_stat);
+    qsort(state->lattice_by_prod[stat_index].p, state->lattice_by_prod[stat_index].size,
+          sizeof(*state->lattice_by_prod[stat_index].p),
+          compare_tile_type_by_stat);
   } output_type_iterate_end;
 
   state->min_luxury = - FC_INFINITY;
 
   /* We have no best solution yet, so its value is the worst possible. */
-  init_partial_solution(&state->best, numtypes, city_size_get(pcity));
+  init_partial_solution(&state->best, numtypes, city_size_get(pcity),
+                        negative_ok);
   state->best_value = worst_fitness();
 
   /* Initialize the current solution and choice stack to empty */
-  init_partial_solution(&state->current, numtypes, city_size_get(pcity));
+  init_partial_solution(&state->current, numtypes, city_size_get(pcity),
+                        negative_ok);
   state->choice.stack = fc_malloc(city_size_get(pcity)
 				  * sizeof(*state->choice.stack));
   state->choice.size = 0;
@@ -1873,7 +1887,8 @@ static struct cm_state *cm_state_init(struct city *pcity)
   solving anything.
 ****************************************************************************/
 static void begin_search(struct cm_state *state,
-			 const struct cm_parameter *parameter)
+			 const struct cm_parameter *parameter,
+                         bool negative_ok)
 {
 #ifdef GATHER_TIME_STATS
   timer_start(performance.current->wall_timer);
@@ -1889,7 +1904,8 @@ static void begin_search(struct cm_state *state,
   state->best_value = worst_fitness();
   destroy_partial_solution(&state->current);
   init_partial_solution(&state->current, num_types(state),
-			city_size_get(state->pcity));
+			city_size_get(state->pcity),
+                        negative_ok);
   state->choice.size = 0;
 }
 
@@ -1917,8 +1933,8 @@ static void end_search(struct cm_state *state)
 static void cm_state_free(struct cm_state *state)
 {
   tile_type_vector_free_all(&state->lattice);
-  output_type_iterate(stat) {
-    tile_type_vector_free(&state->lattice_by_prod[stat]);
+  output_type_iterate(stat_index) {
+    tile_type_vector_free(&state->lattice_by_prod[stat_index]);
   } output_type_iterate_end;
   destroy_partial_solution(&state->best);
   destroy_partial_solution(&state->current);
@@ -1934,7 +1950,7 @@ static void cm_state_free(struct cm_state *state)
 ****************************************************************************/
 static void cm_find_best_solution(struct cm_state *state,
                                   const struct cm_parameter *const parameter,
-                                  struct cm_result *result)
+                                  struct cm_result *result, bool negative_ok)
 {
   int loop_count = 0;
   int max_count;
@@ -1944,7 +1960,7 @@ static void cm_find_best_solution(struct cm_state *state,
   performance.current = &performance.opt;
 #endif
 
-  begin_search(state, parameter);
+  begin_search(state, parameter, negative_ok);
   
   /* make a backup of the city to restore at the very end */
   memcpy(&backup, state->pcity, sizeof(backup));
@@ -1956,13 +1972,13 @@ static void cm_find_best_solution(struct cm_state *state,
   }
 
   /* search until we find a feasible solution */
-  while (!bb_next(state)) {
+  while (!bb_next(state, negative_ok)) {
     /* Limit the number of loops. */
     loop_count++;
 
     if (loop_count > max_count) {
       log_error("Did not find a cm solution in %d iterations for %s.",
-                max_count, city_name(state->pcity));
+                max_count, city_name_get(state->pcity));
       break;
     }
   }
@@ -1981,16 +1997,16 @@ static void cm_find_best_solution(struct cm_state *state,
  ***************************************************************************/
 void cm_query_result(struct city *pcity,
 		     const struct cm_parameter *param,
-		     struct cm_result *result)
+		     struct cm_result *result, bool negative_ok)
 {
-  struct cm_state *state = cm_state_init(pcity);
+  struct cm_state *state = cm_state_init(pcity, negative_ok);
 
   /* Refresh the city.  Otherwise the CM can give wrong results or just be
    * slower than necessary.  Note that cities are often passed in in an
    * unrefreshed state (which should probably be fixed). */
   city_refresh_from_main_map(pcity, NULL);
 
-  cm_find_best_solution(state, param, result);
+  cm_find_best_solution(state, param, result, negative_ok);
   cm_state_free(state);
 }
 
@@ -2038,9 +2054,9 @@ void cm_copy_parameter(struct cm_parameter *dest,
 **************************************************************************/
 void cm_init_parameter(struct cm_parameter *dest)
 {
-  output_type_iterate(stat) {
-    dest->minimal_surplus[stat] = 0;
-    dest->factor[stat] = 1;
+  output_type_iterate(stat_index) {
+    dest->minimal_surplus[stat_index] = 0;
+    dest->factor[stat_index] = 1;
   } output_type_iterate_end;
 
   dest->happy_factor = 1;
@@ -2055,9 +2071,9 @@ void cm_init_parameter(struct cm_parameter *dest)
 ***************************************************************************/
 void cm_init_emergency_parameter(struct cm_parameter *dest)
 {
-  output_type_iterate(stat) {
-    dest->minimal_surplus[stat] = -FC_INFINITY;
-    dest->factor[stat] = 1;
+  output_type_iterate(stat_index) {
+    dest->minimal_surplus[stat_index] = -FC_INFINITY;
+    dest->factor[stat_index] = 1;
   } output_type_iterate_end;
 
   dest->happy_factor = 1;
@@ -2133,14 +2149,14 @@ static void cm_result_copy(struct cm_result *result,
          sizeof(*result->worker_positions)
          * city_map_tiles(result->city_radius_sq));
 
-  city_tile_iterate_index(result->city_radius_sq, pcenter, ptile, index) {
+  city_tile_iterate_index(result->city_radius_sq, pcenter, ptile, ctindex) {
     if (workers_map == NULL) {
       /* use the main map */
       struct city *pwork = tile_worked(ptile);
 
-      result->worker_positions[index] = (NULL != pwork && pwork == pcity);
+      result->worker_positions[ctindex] = (NULL != pwork && pwork == pcity);
     } else {
-      result->worker_positions[index] = workers_map[index];
+      result->worker_positions[ctindex] = workers_map[ctindex];
     }
   } city_tile_iterate_index_end;
 
@@ -2286,7 +2302,7 @@ void cm_print_city(const struct city *pcity)
 {
   struct tile *pcenter = city_tile(pcity);
 
-  log_test("cm_print_city(city %d=\"%s\")", pcity->id, city_name(pcity));
+  log_test("cm_print_city(city %d=\"%s\")", pcity->id, city_name_get(pcity));
   log_test("  size=%d, specialists=%s",
            city_size_get(pcity), specialists_string(pcity->specialists));
 
