@@ -29,7 +29,6 @@
 
 static struct extra_type extras[MAX_EXTRA_TYPES];
 
-static struct extra_type_list *category_extra[ECAT_COUNT];
 static struct extra_type_list *caused_by[EC_LAST];
 static struct extra_type_list *removed_by[ERM_COUNT];
 
@@ -46,9 +45,6 @@ void extras_init(void)
   for (i = 0; i < ERM_COUNT; i++) {
     removed_by[i] = extra_type_list_new();
   }
-  for (i = 0; i < ECAT_COUNT; i++) {
-    category_extra[i] = extra_type_list_new();
-  }
 
   for (i = 0; i < MAX_EXTRA_TYPES; i++) {
     requirement_vector_init(&(extras[i].reqs));
@@ -95,11 +91,6 @@ void extras_free(void)
     removed_by[i] = NULL;
   }
 
-  for (i = 0; i < ECAT_COUNT; i++) {
-    extra_type_list_destroy(category_extra[i]);
-    category_extra[i] = NULL;
-  }
-
   for (i = 0; i < MAX_EXTRA_TYPES; i++) {
     requirement_vector_free(&(extras[i].reqs));
     requirement_vector_free(&(extras[i].rmreqs));
@@ -238,16 +229,6 @@ struct extra_type_list *extra_type_list_by_cause(enum extra_cause cause)
   return caused_by[cause];
 }
 
-/**************************************************************************
-  Returns extra types of the category.
-**************************************************************************/
-struct extra_type_list *extra_type_list_for_category(enum extra_category cat)
-{
-  fc_assert(cat < ECAT_LAST);
-
-  return category_extra[cat];
-}
-
 /**************************************************************************
   Return random extra type for given cause that is native to the tile.
 **************************************************************************/
@@ -285,16 +266,6 @@ void extra_to_caused_by_list(struct extra_type *pextra, enum extra_cause cause)
   extra_type_list_append(caused_by[cause], pextra);
 }
 
-/**************************************************************************
-  Add extra type to list of extras of a category
-**************************************************************************/
-void extra_to_category_list(struct extra_type *pextra, enum extra_category cat)
-{
-  fc_assert(cat < ECAT_LAST);
-
-  extra_type_list_append(category_extra[cat], pextra);
-}
-
 /**************************************************************************
   Returns extra type for given rmcause.
 **************************************************************************/
