@@ -37,9 +37,8 @@ bool api_methods_building_type_is_improvement(lua_State *L,
                                               Building_Type *pbuilding);
 const char *api_methods_building_type_rule_name(lua_State *L,
                                                 Building_Type *pbuilding);
-const char
-  *api_methods_building_type_name_translation(lua_State *L,
-                                              Building_Type *pbuilding);
+const char *api_methods_building_type_name_translation(lua_State *L,
+                                                       Building_Type *pbuilding);
 
 /* City */
 bool api_methods_city_has_building(lua_State *L, City *pcity,
@@ -49,6 +48,14 @@ int api_methods_city_size_get(lua_State *L, City *pcity);
 Tile *api_methods_city_tile_get(lua_State *L, City *pcity);
 int api_methods_city_inspire_partisans(lua_State *L, City *self, Player *inspirer);
 
+int api_methods_city_culture_get(lua_State *L, City *pcity);
+
+bool api_methods_is_city_happy(lua_State *L, City *pcity);
+bool api_methods_is_city_unhappy(lua_State *L, City *pcity);
+bool api_methods_is_city_celebrating(lua_State *L, City *pcity);
+bool api_methods_is_gov_center(lua_State *L, City *pcity);
+bool api_methods_is_capital(lua_State *L, City *pcity);
+
 /* Government */
 const char *api_methods_government_rule_name(lua_State *L,
                                              Government *pgovernment);
@@ -60,9 +67,8 @@ const char *api_methods_nation_type_rule_name(lua_State *L,
                                               Nation_Type *pnation);
 const char *api_methods_nation_type_name_translation(lua_State *L,
                                                      Nation_Type *pnation);
-const char
-  *api_methods_nation_type_plural_translation(lua_State *L,
-                                              Nation_Type *pnation);
+const char *api_methods_nation_type_plural_translation(lua_State *L,
+                                                       Nation_Type *pnation);
 
 /* Player */
 bool api_methods_player_has_wonder(lua_State *L, Player *pplayer,
@@ -75,26 +81,38 @@ bool api_methods_player_knows_tech(lua_State *L, Player *pplayer,
                                    Tech_Type *ptech);
 bool api_methods_player_shares_research(lua_State *L, Player *pplayer,
                                         Player *aplayer);
+const char *api_methods_research_rule_name(lua_State *L, Player *pplayer);
+const char *api_methods_research_name_translation(lua_State *L, Player *pplayer);
 Unit_List_Link *api_methods_private_player_unit_list_head(lua_State *L,
                                                           Player *pplayer);
 City_List_Link *api_methods_private_player_city_list_head(lua_State *L,
                                                           Player *pplayer);
+int api_methods_player_culture_get(lua_State *L, Player *pplayer);
 
 /* Tech Type */
 const char *api_methods_tech_type_rule_name(lua_State *L, Tech_Type *ptech);
-const char *api_methods_tech_type_name_translation(lua_State *L,
-                                                   Tech_Type *ptech);
+const char *api_methods_tech_type_name_translation(lua_State *L, Tech_Type *ptech);
 
 /* Terrain */
 const char *api_methods_terrain_rule_name(lua_State *L, Terrain *pterrain);
-const char *api_methods_terrain_name_translation(lua_State *L,
-                                                 Terrain *pterrain);
+const char *api_methods_terrain_name_translation(lua_State *L, Terrain *pterrain);
+const char *api_methods_terrain_class_name(lua_State *L, Terrain *pterrain);
 
 /* Disaster */
 const char *api_methods_disaster_rule_name(lua_State *L, Disaster *pdis);
 const char *api_methods_disaster_name_translation(lua_State *L,
                                                   Disaster *pdis);
 
+/* Achievement */
+const char *api_methods_achievement_rule_name(lua_State *L, Achievement *pach);
+const char *api_methods_achievement_name_translation(lua_State *L,
+                                                     Achievement *pach);
+
+/* Action */
+const char *api_methods_action_rule_name(lua_State *L, Action *pact);
+const char *api_methods_action_name_translation(lua_State *L,
+                                                Action *pact);
+
 /* Tile */
 int api_methods_tile_nat_x(lua_State *L, Tile *ptile);
 int api_methods_tile_nat_y(lua_State *L, Tile *ptile);
@@ -104,14 +122,15 @@ City *api_methods_tile_city(lua_State *L, Tile *ptile);
 bool api_methods_tile_city_exists_within_max_city_map(lua_State *L,
                                                       Tile *ptile,
                                                       bool may_be_on_center);
+bool api_methods_tile_has_extra(lua_State *L, Tile *ptile, const char *name);
 bool api_methods_tile_has_base(lua_State *L, Tile *ptile, const char *name);
 bool api_methods_tile_has_road(lua_State *L, Tile *ptile, const char *name);
 int api_methods_tile_num_units(lua_State *L, Tile *ptile);
 int api_methods_tile_sq_distance(lua_State *L, Tile *ptile1, Tile *ptile2);
 int api_methods_private_tile_next_outward_index(lua_State *L, Tile *pstart,
-                                                int index, int max_dist);
+                                                int tindex, int max_dist);
 Tile *api_methods_private_tile_for_outward_index(lua_State *L, Tile *pstart,
-                                                 int index);
+                                                 int tindex);
 Unit_List_Link *api_methods_private_tile_unit_list_head(lua_State *L,
                                                         Tile *ptile);
 
@@ -119,6 +138,9 @@ Unit_List_Link *api_methods_private_tile_unit_list_head(lua_State *L,
 bool api_methods_unit_city_can_be_built_here(lua_State *L, Unit *punit);
 Tile *api_methods_unit_tile_get(lua_State *L, Unit * punit);
 Direction api_methods_unit_orientation_get(lua_State *L, Unit *punit);
+Unit *api_methods_unit_transporter(lua_State *L, Unit *punit);
+Unit_List_Link *api_methods_private_unit_cargo_list_head(lua_State *L,
+                                                         Unit *punit);
 
 /* Unit Type */
 bool api_methods_unit_type_has_flag(lua_State *L, Unit_Type *punit_type,
