@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 2003 - The Freeciv Project
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "support.h"
 
 /* common */
+#include "extras.h"
 #include "game.h"
 #include "map.h"
 #include "rgbcolor.h"
@@ -34,14 +35,6 @@
 
 static struct terrain civ_terrains[MAX_NUM_TERRAINS];
 static struct resource civ_resources[MAX_NUM_RESOURCES];
-
-enum tile_special_type infrastructure_specials[] = {
-  S_IRRIGATION,
-  S_FARMLAND,
-  S_MINE,
-  S_LAST
-};
-
 static struct user_flag user_terrain_flags[MAX_NUM_USER_TER_FLAGS];
 
 /****************************************************************************
@@ -55,6 +48,7 @@ void terrains_init(void)
     /* Can't use terrain_by_number here because it does a bounds check. */
     civ_terrains[i].item_number = i;
     civ_terrains[i].rgb = NULL;
+    civ_terrains[i].animal = NULL;
   }
   for (i = 0; i < ARRAY_SIZE(civ_resources); i++) {
     civ_resources[i].item_number = i;
@@ -226,33 +220,13 @@ struct terrain *rand_terrain_by_flag(enum terrain_flag_id flag)
   return terr;
 }
 
-/****************************************************************************
-  Fill terrain with flag to buffer. Returns number of terrains found.
-  Return value can be greater than size of buffer.
-****************************************************************************/
-int terrains_by_flag(enum terrain_flag_id flag, struct terrain **buffer, int bufsize)
-{
-  int num = 0;
-
-  terrain_type_iterate(pterr) {
-    if (terrain_has_flag(pterr, flag)) {
-      if (num < bufsize) {
-        buffer[num] = pterr;
-      }
-      num++;
-    }
-  } terrain_type_iterate_end;
-
-  return num;
-}
-
 /****************************************************************************
   Return the (translated) name of the terrain.
   You don't have to free the return pointer.
 ****************************************************************************/
 const char *terrain_name_translation(const struct terrain *pterrain)
 {
-  return name_translation(&pterrain->name);
+  return name_translation_get(&pterrain->name);
 }
 
 /**************************************************************************
@@ -261,7 +235,7 @@ const char *terrain_name_translation(const struct terrain *pterrain)
 **************************************************************************/
 const char *terrain_rule_name(const struct terrain *pterrain)
 {
-  return rule_name(&pterrain->name);
+  return rule_name_get(&pterrain->name);
 }
 
 /****************************************************************************
@@ -380,7 +354,7 @@ struct resource *resource_by_rule_name(const char *name)
 ****************************************************************************/
 const char *resource_name_translation(const struct resource *presource)
 {
-  return name_translation(&presource->name);
+  return name_translation_get(&presource->name);
 }
 
 /**************************************************************************
@@ -389,10 +363,9 @@ const char *resource_name_translation(const struct resource *presource)
 **************************************************************************/
 const char *resource_rule_name(const struct resource *presource)
 {
-  return rule_name(&presource->name);
+  return rule_name_get(&presource->name);
 }
 
-
 /****************************************************************************
   This iterator behaves like adjc_iterate or cardinal_adjc_iterate depending
   on the value of card_only.
@@ -403,14 +376,14 @@ const char *resource_rule_name(const struct resource *presource)
   int _tile##_count;							\
 									\
   if (card_only) {							\
-    _tile##_list = map.cardinal_dirs;					\
-    _tile##_count = map.num_cardinal_dirs;				\
+    _tile##_list = game.map.cardinal_dirs;				\
+    _tile##_count = game.map.num_cardinal_dirs;				\
   } else {								\
-    _tile##_list = map.valid_dirs;					\
-    _tile##_count = map.num_valid_dirs;					\
+    _tile##_list = game.map.valid_dirs;					\
+    _tile##_count = game.map.num_valid_dirs;				\
   }									\
   adjc_dirlist_iterate(center_tile, _tile, _tile##_dir,			\
-		       _tile##_list, _tile##_count) {
+                       _tile##_list, _tile##_count) {
 
 #define variable_adjc_iterate_end					\
   } adjc_dirlist_iterate_end;						\
@@ -541,198 +514,6 @@ bool is_resource_near_tile(const struct tile *ptile,
   return check_self && tile_resource(ptile) == pres;
 }
 
-/* Names of specials.
- * (These must correspond to enum tile_special_type.)
- */
-static const char *tile_special_type_names[] =
-{
-  N_("Irrigation"),
-  N_("Mine"),
-  N_("Pollution"),
-  N_("Hut"),
-  N_("Farmland"),
-  N_("Fallout")
-};
-
-/****************************************************************************
-  Return the special with the given name, or S_LAST.
-****************************************************************************/
-enum tile_special_type special_by_rule_name(const char *name)
-{
-  fc_assert_ret_val(ARRAY_SIZE(tile_special_type_names) == S_LAST, S_LAST);
-
-  tile_special_type_iterate(i) {
-    if (tile_special_type_names[i] != NULL
-        && 0 == strcmp(tile_special_type_names[i], name)) {
-      return i;
-    }
-  } tile_special_type_iterate_end;
-
-  return S_LAST;
-}
-
-/****************************************************************************
-  Return the translated name of the given special.
-****************************************************************************/
-const char *special_name_translation(enum tile_special_type type)
-{
-  fc_assert_ret_val(ARRAY_SIZE(tile_special_type_names) == S_LAST, NULL);
-  fc_assert_ret_val(type >= 0 && type < S_LAST, NULL);
-
-  return _(tile_special_type_names[type]);
-}
-
-/****************************************************************************
-  Return the untranslated name of the given special.
-****************************************************************************/
-const char *special_rule_name(enum tile_special_type type)
-{
-  fc_assert_ret_val(ARRAY_SIZE(tile_special_type_names) == S_LAST, NULL);
-  fc_assert_ret_val(type >= 0 && type < S_LAST, NULL);
-
-  return tile_special_type_names[type];
-}
-
-/****************************************************************************
-  Add the given special to the set.
-****************************************************************************/
-void set_special(bv_special *set, enum tile_special_type to_set)
-{
-  fc_assert_ret(to_set >= 0 && to_set < S_LAST);
-  BV_SET(*set, to_set);
-}
-
-/****************************************************************************
-  Remove the given special from the set.
-****************************************************************************/
-void clear_special(bv_special *set, enum tile_special_type to_clear)
-{
-  fc_assert_ret(to_clear >= 0 && to_clear < S_LAST);
-  BV_CLR(*set, to_clear);
-}
-
-/****************************************************************************
-  Clear all specials from the set.
-****************************************************************************/
-void clear_all_specials(bv_special *set)
-{
-  BV_CLR_ALL(*set);
-}
-
-/****************************************************************************
- Returns TRUE iff the given special is found in the given set.
-****************************************************************************/
-bool contains_special(bv_special set,
-		      enum tile_special_type to_test_for)
-{
-  fc_assert_ret_val(to_test_for >= 0 && to_test_for < S_LAST, FALSE);
-  return BV_ISSET(set, to_test_for);
-}
-
-/****************************************************************************
- Returns TRUE iff any specials are set on the tile.
-****************************************************************************/
-bool contains_any_specials(bv_special set)
-{
-  return BV_ISSET_ANY(set);
-}
-
-/****************************************************************************
-  Returns TRUE iff the special can be supported by the terrain type.
-****************************************************************************/
-bool is_native_terrain_to_special(enum tile_special_type special,
-                                  const struct terrain *pterrain)
-{
-  /* FIXME: The special definition should be moved into the ruleset. */
-  switch (special) {
-  case S_IRRIGATION:
-    return (pterrain == pterrain->irrigation_result);
-  case S_MINE:
-    return (pterrain == pterrain->mining_result);
-  case S_POLLUTION:
-    return !terrain_has_flag(pterrain, TER_NO_POLLUTION);
-  case S_HUT:
-    return TRUE;
-  case S_FARMLAND:
-    return (pterrain == pterrain->irrigation_result);
-  case S_FALLOUT:
-    return !terrain_has_flag(pterrain, TER_NO_POLLUTION);
-  case S_OLD_ROAD:
-  case S_OLD_RAILROAD:
-  case S_OLD_RIVER:
-  case S_OLD_FORTRESS:
-  case S_OLD_AIRBASE:
-    fc_assert(FALSE);
-  case S_LAST:
-    break;
-  }
-
-  return FALSE;
-}
-
-/****************************************************************************
-  Returns TRUE iff the special can be supported by the terrain type of the
-  tile.
-****************************************************************************/
-bool is_native_tile_to_special(enum tile_special_type special,
-                               const struct tile *ptile)
-{
-  return is_native_terrain_to_special(special, tile_terrain(ptile));
-}
-
-/****************************************************************************
-  Returns TRUE iff any cardinally tile adjacent to (map_x,map_y) has the
-  given special.
-****************************************************************************/
-bool is_special_card_near(const struct tile *ptile, enum tile_special_type spe,
-                          bool check_self)
-{
-  cardinal_adjc_iterate(ptile, adjc_tile) {
-    if (tile_has_special(adjc_tile, spe)) {
-      return TRUE;
-    }
-  } cardinal_adjc_iterate_end;
-
-  return check_self && tile_has_special(ptile, spe);
-}
-
-/****************************************************************************
-  Returns TRUE iff any tile adjacent to (map_x,map_y) has the given special.
-****************************************************************************/
-bool is_special_near_tile(const struct tile *ptile, enum tile_special_type spe,
-                          bool check_self)
-{
-  adjc_iterate(ptile, adjc_tile) {
-    if (tile_has_special(adjc_tile, spe)) {
-      return TRUE;
-    }
-  } adjc_iterate_end;
-
-  return check_self && tile_has_special(ptile, spe);
-}
-
-/****************************************************************************
-  Returns the number of adjacent tiles that have the given map special.
-****************************************************************************/
-int count_special_near_tile(const struct tile *ptile,
-			    bool cardinal_only, bool percentage,
-			    enum tile_special_type spe)
-{
-  int count = 0, total = 0;
-
-  variable_adjc_iterate(ptile, adjc_tile, cardinal_only) {
-    if (tile_has_special(adjc_tile, spe)) {
-      count++;
-    }
-    total++;
-  } variable_adjc_iterate_end;
-
-  if (percentage) {
-    count = count * 100 / total;
-  }
-  return count;
-}
-
 /****************************************************************************
   Returns TRUE iff any cardinally adjacent tile contains terrain with the
   given flag (does not check ptile itself).
@@ -795,12 +576,12 @@ int count_terrain_flag_near_tile(const struct tile *ptile,
 }
 
 /****************************************************************************
-  Return a (static) string with special(s) name(s):
+  Return a (static) string with extra(s) name(s):
     eg: "Mine"
     eg: "Road/Farmland"
-  This only includes "infrastructure", i.e., man-made specials.
+  This only includes "infrastructure", i.e., man-made extras.
 ****************************************************************************/
-const char *get_infrastructure_text(bv_special spe, bv_bases bases, bv_roads roads)
+const char *get_infrastructure_text(bv_extras extras)
 {
   static char s[256];
   char *p;
@@ -808,43 +589,26 @@ const char *get_infrastructure_text(bv_special spe, bv_bases bases, bv_roads roa
 
   s[0] = '\0';
 
-  road_type_iterate(proad) {
-    if (BV_ISSET(roads, road_index(proad))
-        && !road_has_flag(proad, RF_NATURAL)) {
+  extra_type_iterate(pextra) {
+    if (pextra->category == ECAT_INFRA
+        && BV_ISSET(extras, extra_index(pextra))) {
       bool hidden = FALSE;
 
-      road_type_iterate(top) {
-        int topi = road_index(top);
+      extra_type_iterate(top) {
+        int topi = extra_index(top);
 
-        if (BV_ISSET(proad->hidden_by, topi)
-            && BV_ISSET(roads, topi)) {
+        if (BV_ISSET(pextra->hidden_by, topi)
+            && BV_ISSET(extras, topi)) {
           hidden = TRUE;
           break;
         }
-      } road_type_iterate_end;
+      } extra_type_iterate_end;
 
       if (!hidden) {
-        cat_snprintf(s, sizeof(s), "%s/", road_name_translation(proad));
+        cat_snprintf(s, sizeof(s), "%s/", extra_name_translation(pextra));
       }
     }
-  } road_type_iterate_end;
-
-  /* Likewise for farmland on irrigation */
-  if (contains_special(spe, S_FARMLAND)) {
-    cat_snprintf(s, sizeof(s), "%s/", _("Farmland"));
-  } else if (contains_special(spe, S_IRRIGATION)) {
-    cat_snprintf(s, sizeof(s), "%s/", _("Irrigation"));
-  }
-
-  if (contains_special(spe, S_MINE)) {
-    cat_snprintf(s, sizeof(s), "%s/", _("Mine"));
-  }
-
-  base_type_iterate(pbase) {
-    if (BV_ISSET(bases, base_index(pbase))) {
-      cat_snprintf(s, sizeof(s), "%s/", base_name_translation(pbase));
-    }
-  } base_type_iterate_end;
+  } extra_type_iterate_end;
 
   len = strlen(s);
   p = s + len - 1;
@@ -856,57 +620,43 @@ const char *get_infrastructure_text(bv_special spe, bv_bases bases, bv_roads roa
 }
 
 /****************************************************************************
-  Return the prerequesites needed before building the given infrastructure.
+  Returns the highest-priority (best) infrastructure (man-made extra) to
+  be pillaged from the terrain set.  May return NULL if nothing
+  better is available.
 ****************************************************************************/
-enum tile_special_type get_infrastructure_prereq(enum tile_special_type spe)
+struct extra_type *get_preferred_pillage(bv_extras extras)
 {
-  if (spe == S_FARMLAND) {
-    return S_IRRIGATION;
-  } else {
-    return S_LAST;
-  }
-}
-
-/****************************************************************************
-  Determine the highest-priority (best) infrastructure (man-made special) to
-  be pillaged from the terrain set, which is returned in tgt.
-  Returns FALSE if there is nothing to be pillaged.
-****************************************************************************/
-bool get_preferred_pillage(struct act_tgt *tgt,
-                           bv_special pset,
-                           bv_bases bases,
-                           bv_roads roads)
-{
-  tgt->type = ATT_SPECIAL;
-  if (contains_special(pset, S_FARMLAND)) {
-    tgt->obj.spe = S_FARMLAND;
-    return TRUE;
-  }
-  if (contains_special(pset, S_IRRIGATION)) {
-    tgt->obj.spe = S_IRRIGATION;
-    return TRUE;
-  }
-  if (contains_special(pset, S_MINE)) {
-    tgt->obj.spe = S_MINE;
-    return TRUE;
-  }
-  base_type_iterate(pbase) {
-    if (BV_ISSET(bases, base_index(pbase))) {
-      tgt->type = ATT_BASE;
-      tgt->obj.base = base_index(pbase);
-      return TRUE;
+  extra_type_by_cause_iterate_rev(EC_IRRIGATION, pextra) {
+    if (is_extra_removed_by(pextra, ERM_PILLAGE) && BV_ISSET(extras, extra_index(pextra))) {
+      return pextra;
     }
-  } base_type_iterate_end;
+  } extra_type_by_cause_iterate_rev_end;
 
-  road_type_iterate(proad) {
-    if (BV_ISSET(roads, road_index(proad))) {
-      tgt->type = ATT_ROAD;
-      tgt->obj.road = road_index(proad);
-      return TRUE;
+  extra_type_by_cause_iterate_rev(EC_MINE, pextra) {
+    if (is_extra_removed_by(pextra, ERM_PILLAGE) && BV_ISSET(extras, extra_index(pextra))) {
+      return pextra;
     }
-  } road_type_iterate_end;
+  } extra_type_by_cause_iterate_rev_end;
 
-  return FALSE;
+  extra_type_by_cause_iterate_rev(EC_BASE, pextra) {
+    if (is_extra_removed_by(pextra, ERM_PILLAGE) && BV_ISSET(extras, extra_index(pextra))) {
+      return pextra;
+    }
+  } extra_type_by_cause_iterate_rev_end;
+
+  extra_type_by_cause_iterate_rev(EC_ROAD, pextra) {
+    if (is_extra_removed_by(pextra, ERM_PILLAGE) && BV_ISSET(extras, extra_index(pextra))) {
+      return pextra;
+    }
+  } extra_type_by_cause_iterate_rev_end;
+
+  extra_type_by_cause_iterate_rev(EC_NONE, pextra) {
+    if (is_extra_removed_by(pextra, ERM_PILLAGE) && BV_ISSET(extras, extra_index(pextra))) {
+      return pextra;
+    }
+  } extra_type_by_cause_iterate_rev_end;
+
+  return NULL;
 }
 
 /****************************************************************************
@@ -1018,54 +768,72 @@ bool terrain_can_support_alteration(const struct terrain *pterrain,
 }
 
 /****************************************************************************
-  Return the (translated) name of the infrastructure (e.g., "Irrigation").
-  You don't have to free the return pointer.
+   Time to complete the extra building activity on the given terrain.
 ****************************************************************************/
-const char *terrain_alteration_name_translation(enum terrain_alteration talter)
+int terrain_extra_build_time(const struct terrain *pterrain,
+                             enum unit_activity activity,
+                             const struct extra_type *tgt)
 {
-  switch(talter) {
-   case TA_CAN_IRRIGATE:
-     return special_name_translation(S_IRRIGATION);
-   case TA_CAN_MINE:
-     return special_name_translation(S_MINE);
-   case TA_CAN_ROAD:
-     return _("Road");
-   default:
-     return NULL;
+  int factor;
+
+  if (tgt != NULL && tgt->build_time != 0) {
+    /* Extra specific build time */
+    return tgt->build_time;
+  }
+
+  if (tgt == NULL) {
+    factor = 1;
+  } else {
+    factor = tgt->build_time_factor;
+  }
+
+  /* Terrain and activity specific build time */
+  switch (activity) {
+  case ACTIVITY_BASE:
+    return pterrain->base_time * factor;
+  case ACTIVITY_GEN_ROAD:
+    return pterrain->road_time * factor;
+  case ACTIVITY_IRRIGATE:
+    return pterrain->irrigation_time * factor;
+  case ACTIVITY_MINE:
+    return pterrain->mining_time * factor;
+  default:
+    fc_assert(FALSE);
+    return 0;
   }
 }
 
 /****************************************************************************
-   Time to complete the base building activity on the given terrain.
+   Time to complete the extra removal activity on the given terrain.
 ****************************************************************************/
-int terrain_base_time(const struct terrain *pterrain,
-                      Base_type_id base)
+int terrain_extra_removal_time(const struct terrain *pterrain,
+                               enum unit_activity activity,
+                               const struct extra_type *tgt)
 {
-  struct base_type *pbase = base_by_number(base);
+  int factor;
 
-  if (pbase->build_time == 0) {
-    /* Terrain specific build time */
-    return pterrain->base_time;
-  } else {
-    /* Road specific build time */
-    return pbase->build_time;
+  if (tgt != NULL && tgt->removal_time != 0) {
+    /* Extra specific removal time */
+    return tgt->removal_time;
   }
-}
 
-/****************************************************************************
-  Time to complete the road building activity on the given terrain.
-****************************************************************************/
-int terrain_road_time(const struct terrain *pterrain,
-                            Road_type_id road)
-{
-  struct road_type *proad = road_by_number(road);
-
-  if (proad->build_time == 0) {
-    /* Terrain specific build time */
-    return pterrain->road_time;
+  if (tgt == NULL) {
+    factor = 1;
   } else {
-    /* Road specific build time */
-    return proad->build_time;
+    factor = tgt->removal_time_factor;
+  }
+
+  /* Terrain and activity specific removal time */
+  switch (activity) {
+  case ACTIVITY_POLLUTION:
+    return pterrain->clean_pollution_time * factor;
+  case ACTIVITY_FALLOUT:
+    return pterrain->clean_fallout_time * factor;
+  case ACTIVITY_PILLAGE:
+    return pterrain->pillage_time * factor;
+  default:
+    fc_assert(FALSE);
+    return 0;
   }
 }
 
@@ -1125,7 +893,7 @@ void set_user_terrain_flag_name(enum terrain_flag_id id, const char *name,
 /**************************************************************************
   Terrain flag name callback, called from specenum code.
 **************************************************************************/
-char *terrain_flag_id_name_cb(enum terrain_flag_id flag)
+const char *terrain_flag_id_name_cb(enum terrain_flag_id flag)
 {
   if (flag < TER_USER_1 || flag > TER_USER_LAST) {
     return NULL;
