@@ -13,6 +13,22 @@
 #ifndef FC__BUILDINGADV_H
 #define FC__BUILDINGADV_H
 
+/* server/advisors */
+#include "advchoice.h"
+
+#define FOOD_WEIGHTING 30
+#define SHIELD_WEIGHTING 17
+#define TRADE_WEIGHTING 18
+/* The Trade Weighting has to about as large as the Shield Weighting,
+   otherwise the AI will build Barracks to create veterans in cities 
+   with only 1 shields production.
+    8 is too low
+   18 is too high
+ */
+#define POLLUTION_WEIGHTING 20 /* tentative */
+#define WARMING_FACTOR 50
+#define COOLING_FACTOR WARMING_FACTOR
+
 struct player;
 
 void building_advisor(struct player *pplayer);
