@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -149,7 +149,7 @@ void handle_city_make_specialist(struct player *pplayer, int city_id,
   city_radius_sq = city_map_radius_sq_get(pcity);
   if (!is_valid_city_coords(city_radius_sq, worker_x, worker_y)) {
     log_error("handle_city_make_specialist() invalid city map {%d,%d} "
-              "\"%s\".", worker_x, worker_y, city_name(pcity));
+              "\"%s\".", worker_x, worker_y, city_name_get(pcity));
     return;
   }
   pcenter = city_tile(pcity);
@@ -157,7 +157,7 @@ void handle_city_make_specialist(struct player *pplayer, int city_id,
   if (NULL == (ptile = city_map_to_tile(pcenter, city_radius_sq, worker_x,
                                         worker_y))) {
     log_error("handle_city_make_specialist() unavailable city map {%d,%d} "
-              "\"%s\".", worker_x, worker_y, city_name(pcity));
+              "\"%s\".", worker_x, worker_y, city_name_get(pcity));
     return;
   }
 
@@ -168,7 +168,7 @@ void handle_city_make_specialist(struct player *pplayer, int city_id,
     pcity->specialists[DEFAULT_SPECIALIST]++;
   } else {
     log_verbose("handle_city_make_specialist() not working {%d,%d} \"%s\".",
-                worker_x, worker_y, city_name(pcity));
+                worker_x, worker_y, city_name_get(pcity));
   }
 
   city_refresh(pcity);
@@ -197,7 +197,7 @@ void handle_city_make_worker(struct player *pplayer, int city_id,
 
   if (!is_valid_city_coords(city_radius_sq, worker_x, worker_y)) {
     log_error("handle_city_make_worker() invalid city map {%d,%d} "
-              "\"%s\".", worker_x, worker_y, city_name(pcity));
+              "\"%s\".", worker_x, worker_y, city_name_get(pcity));
     return;
   }
   pcenter = city_tile(pcity);
@@ -205,7 +205,7 @@ void handle_city_make_worker(struct player *pplayer, int city_id,
   if (NULL == (ptile = city_map_to_tile(pcenter, city_radius_sq, worker_x,
                                         worker_y))) {
     log_error("handle_city_make_worker() unavailable city map {%d,%d} "
-              "\"%s\".", worker_x, worker_y, city_name(pcity));
+              "\"%s\".", worker_x, worker_y, city_name_get(pcity));
     return;
   }
 
@@ -217,19 +217,19 @@ void handle_city_make_worker(struct player *pplayer, int city_id,
 
   if (tile_worked(ptile) == pcity) {
     log_verbose("handle_city_make_worker() already working {%d,%d} \"%s\".",
-                worker_x, worker_y, city_name(pcity));
+                worker_x, worker_y, city_name_get(pcity));
     return;
   }
 
   if (0 == city_specialists(pcity)) {
     log_verbose("handle_city_make_worker() no specialists {%d,%d} \"%s\".",
-                worker_x, worker_y, city_name(pcity));
+                worker_x, worker_y, city_name_get(pcity));
     return;
   }
 
   if (!city_can_work_tile(pcity, ptile)) {
     log_verbose("handle_city_make_worker() cannot work here {%d,%d} \"%s\".",
-                worker_x, worker_y, city_name(pcity));
+                worker_x, worker_y, city_name_get(pcity));
     return;
   }
 
@@ -376,13 +376,13 @@ void really_handle_city_buy(struct player *pplayer, struct city *pcity)
                   /* TRANS: bought an unit. */
                   Q_("?unit:You bought %s in %s."),
                   utype_name_translation(pcity->production.value.utype),
-                  city_name(pcity));
+                  city_name_get(pcity));
   } else if (VUT_IMPROVEMENT == pcity->production.kind) {
     notify_player(pplayer, pcity->tile, E_IMP_BUY, ftc_server,
                   /* TRANS: bought an improvement .*/
                   Q_("?improvement:You bought %s in %s."),
                   improvement_name_translation(pcity->production.value.building),
-                  city_name(pcity));
+                  city_name_get(pcity));
   }
 
   conn_list_do_buffer(pplayer->connections);
@@ -446,7 +446,7 @@ void handle_city_refresh(struct player *pplayer, int city_id)
   Handle request to change current production.
 **************************************************************************/
 void handle_city_change(struct player *pplayer, int city_id,
-			int production_kind, int production_value)
+                        int production_kind, int production_value)
 {
   struct universal prod;
   struct city *pcity = player_city_by_number(pplayer, city_id);
@@ -475,7 +475,7 @@ void handle_city_change(struct player *pplayer, int city_id,
     return;
   }
 
-  if (!can_city_build_now(pcity, prod)) {
+  if (!can_city_build_now(pcity, &prod)) {
     return;
   }
   if (!city_can_change_build(pcity)) {
@@ -484,7 +484,7 @@ void handle_city_change(struct player *pplayer, int city_id,
     return;
   }
 
-  change_build_target(pplayer, pcity, prod, E_CITY_PRODUCTION_CHANGED);
+  change_build_target(pplayer, pcity, &prod, E_CITY_PRODUCTION_CHANGED);
 
   city_refresh(pcity);
   sanity_check_city(pcity);
