@@ -15,6 +15,8 @@
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -32,22 +34,16 @@
 #include <Dialogs.h>
 #endif
 
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
 #ifdef WIN32_NATIVE
 #include <windows.h>
 #endif
 
 /* utility */
+#include "deprecations.h"
+#include "fc_cmdline.h"
 #include "fciconv.h"
 #include "fcintl.h"
 #include "log.h"
-#include "shared.h"
 #include "support.h"
 #include "timing.h"
 
@@ -60,13 +56,10 @@
 /* server */
 #include "aiiface.h"
 #include "console.h"
-#include "ggzserver.h"
 #include "meta.h"
 #include "sernet.h"
 #include "srv_main.h"
 
-#include "civserver.h"
-
 #ifdef GENERATING_MAC
 static void Mac_options(int argc);  /* don't need argv */
 #endif
@@ -92,9 +85,6 @@ static void signal_handler(int sig)
 
   switch (sig) {
   case SIGINT:
-    if (with_ggz) {
-      save_and_exit(SIGINT);
-    }
     if (timer && timer_read_seconds(timer) <= 1.0) {
       save_and_exit(SIGINT);
     } else {
@@ -152,14 +142,14 @@ int main(int argc, char *argv[])
 
   /* Load win32 post-crash debugger */
 #ifdef WIN32_NATIVE
-# ifndef NDEBUG
+# ifndef FREECIV_NDEBUG
   if (LoadLibrary("exchndl.dll") == NULL) {
-#  ifdef DEBUG
+#  ifdef FREECIV_DEBUG
     fprintf(stderr, "exchndl.dll could not be loaded, no crash debugger\n");
-#  endif
+#  endif /* FREECIV_DEBUG */
   }
-# endif
-#endif
+# endif /* FREECIV_NDEBUG */
+#endif /* WIN32_NATIVE */
 
 #ifdef USE_INTERRUPT_HANDLERS
   if (SIG_ERR == signal(SIGINT, signal_handler)) {
@@ -203,20 +193,23 @@ int main(int argc, char *argv[])
 #endif
   srvarg.announce = ANNOUNCE_DEFAULT;
 
+  game.server.meta_info.type[0] = '\0';
+
   /* no  we don't use GNU's getopt or even the "standard" getopt */
   /* yes we do have reasons ;)                                   */
   /* FIXME: and that are? */
   inx = 1;
   while (inx < argc) {
-    if ((option = get_option_malloc("--file", argv, &inx, argc))) {
+    if ((option = get_option_malloc("--file", argv, &inx, argc,
+                                    FALSE))) {
       sz_strlcpy(srvarg.load_filename, option);
       free(option);
     } else if (is_option("--help", argv[inx])) {
       showhelp = TRUE;
       break;
-    } else if ((option = get_option_malloc("--log", argv, &inx, argc))) {
-      srvarg.log_filename = option; /* Never freed. */
-#ifndef NDEBUG
+    } else if ((option = get_option_malloc("--log", argv, &inx, argc, TRUE))) {
+      srvarg.log_filename = option;
+#ifndef FREECIV_NDEBUG
     } else if (is_option("--Fatal", argv[inx])) {
       if (inx + 1 >= argc || '-' == argv[inx + 1][0]) {
         srvarg.fatal_assertions = SIGABRT;
@@ -228,9 +221,9 @@ int main(int argc, char *argv[])
         inx++;
         showhelp = TRUE;
       }
-#endif /* NDEBUG */
-    } else if ((option = get_option_malloc("--Ranklog", argv, &inx, argc))) {
-      srvarg.ranklog_filename = option; /* Never freed. */
+#endif /* FREECIV_NDEBUG */
+    } else if ((option = get_option_malloc("--Ranklog", argv, &inx, argc, TRUE))) {
+      srvarg.ranklog_filename = option;
     } else if (is_option("--keep", argv[inx])) {
       srvarg.metaconnection_persistent = TRUE;
       /* Implies --meta */
@@ -242,27 +235,32 @@ int main(int argc, char *argv[])
     } else if (is_option("--meta", argv[inx])) {
       srvarg.metaserver_no_send = FALSE;
     } else if ((option = get_option_malloc("--Metaserver",
-                                           argv, &inx, argc))) {
+                                           argv, &inx, argc, FALSE))) {
       sz_strlcpy(srvarg.metaserver_addr, option);
       free(option);
       srvarg.metaserver_no_send = FALSE;      /* --Metaserver implies --meta */
     } else if ((option = get_option_malloc("--identity",
-					   argv, &inx, argc))) {
+                                           argv, &inx, argc, FALSE))) {
       sz_strlcpy(srvarg.identity_name, option);
       free(option);
-    } else if ((option = get_option_malloc("--port", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--port", argv, &inx, argc, FALSE))) {
       if (!str_to_int(option, &srvarg.port)) {
         showhelp = TRUE;
         break;
       }
       free(option);
-    } else if ((option = get_option_malloc("--bind", argv, &inx, argc))) {
-      srvarg.bind_addr = option; /* Never freed. */
-    } else if ((option = get_option_malloc("--Bind-meta", argv, &inx, argc))) {
-      srvarg.bind_meta_addr = option; /* Never freed. */
-    } else if ((option = get_option_malloc("--read", argv, &inx, argc)))
-      srvarg.script_filename = option; /* Never freed. */
-    else if ((option = get_option_malloc("--quitidle", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--bind", argv, &inx, argc, TRUE))) {
+      srvarg.bind_addr = option;
+    } else if ((option = get_option_malloc("--Bind-meta", argv, &inx, argc, TRUE))) {
+      srvarg.bind_meta_addr = option;
+#ifdef FREECIV_WEB
+    } else if ((option = get_option_malloc("--type", argv, &inx, argc, FALSE))) {
+      sz_strlcpy(game.server.meta_info.type, option);
+      free(option);
+#endif /* FREECIV_WEB */
+    } else if ((option = get_option_malloc("--read", argv, &inx, argc, TRUE)))
+      srvarg.script_filename = option;
+    else if ((option = get_option_malloc("--quitidle", argv, &inx, argc, FALSE))) {
       if (!str_to_int(option, &srvarg.quitidle)) {
         showhelp = TRUE;
         break;
@@ -270,16 +268,17 @@ int main(int argc, char *argv[])
       free(option);
     } else if (is_option("--exit-on-end", argv[inx])) {
       srvarg.exit_on_end = TRUE;
-    } else if ((option = get_option_malloc("--debug", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--debug", argv, &inx, argc, FALSE))) {
       if (!log_parse_level_str(option, &srvarg.loglevel)) {
         showhelp = TRUE;
         break;
       }
       free(option);
 #ifdef HAVE_FCDB
-    } else if ((option = get_option_malloc("--Database", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--Database", argv, &inx, argc, FALSE))) {
+      /* Freed after file has been loaded - not here nor in server quit */
       srvarg.fcdb_enabled = TRUE;
-      srvarg.fcdb_conf = option; /* Never freed */
+      srvarg.fcdb_conf = option;
     } else if (is_option("--auth", argv[inx])) {
       srvarg.auth_enabled = TRUE;
     } else if (is_option("--Guests", argv[inx])) {
@@ -287,21 +286,21 @@ int main(int argc, char *argv[])
     } else if (is_option("--Newusers", argv[inx])) {
       srvarg.auth_allow_newusers = TRUE;
 #endif /* HAVE_FCDB */
-    } else if ((option = get_option_malloc("--Serverid", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--Serverid", argv, &inx, argc, FALSE))) {
       sz_strlcpy(srvarg.serverid, option);
       free(option);
-    } else if ((option = get_option_malloc("--saves", argv, &inx, argc))) {
-      srvarg.saves_pathname = option; /* Never freed. */
-    } else if ((option = get_option_malloc("--scenarios", argv, &inx, argc))) {
-      srvarg.scenarios_pathname = option; /* Never freed */
+    } else if ((option = get_option_malloc("--saves", argv, &inx, argc, TRUE))) {
+      srvarg.saves_pathname = option;
+    } else if ((option = get_option_malloc("--scenarios", argv, &inx, argc, TRUE))) {
+      srvarg.scenarios_pathname = option;
     } else if (is_option("--version", argv[inx])) {
       showvers = TRUE;
-    } else if ((option = get_option_malloc("--Announce", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--Announce", argv, &inx, argc, FALSE))) {
       if (!strcasecmp(option, "ipv4")) {
         srvarg.announce = ANNOUNCE_IPV4;
       } else if(!strcasecmp(option, "none")) {
         srvarg.announce= ANNOUNCE_NONE;
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
       } else if (!strcasecmp(option, "ipv6")) {
         srvarg.announce = ANNOUNCE_IPV6;
 #endif /* IPv6 support */
@@ -309,8 +308,10 @@ int main(int argc, char *argv[])
         log_error(_("Illegal value \"%s\" for --Announce"), option);
       }
       free(option);
+    } else if (is_option("--warnings", argv[inx])) {
+      deprecation_warnings_enable();
 #ifdef AI_MODULES
-    } else if ((option = get_option_malloc("--LoadAI", argv, &inx, argc))) {
+    } else if ((option = get_option_malloc("--LoadAI", argv, &inx, argc, FALSE))) {
       if (!load_ai_module(option)) {
         fc_fprintf(stderr, _("Failed to load AI module \"%s\"\n"), option);
         exit(EXIT_FAILURE);
@@ -361,24 +362,24 @@ int main(int argc, char *argv[])
                 _("Listen for clients on ADDR"));
     cmdhelp_add(help, "B", "Bind-meta ADDR",
                 _("Connect to metaserver from this address"));
-#ifdef DEBUG
+#ifdef FREECIV_DEBUG
     cmdhelp_add(help, "d",
                 /* TRANS: "debug" is exactly what user must type, do not translate. */
                 _("debug NUM"),
                 _("Set debug log level (%d to %d, or %d:file1,min,max:...)"),
                 LOG_FATAL, LOG_DEBUG, LOG_DEBUG);
-#else  /* DEBUG */
+#else  /* FREECIV_DEBUG */
     cmdhelp_add(help, "d",
                 /* TRANS: "debug" is exactly what user must type, do not translate. */
                 _("debug NUM"),
                 _("Set debug log level (%d to %d)"), LOG_FATAL, LOG_VERBOSE);
-#endif /* DEBUG */
-#ifndef NDEBUG
+#endif /* FREECIV_DEBUG */
+#ifndef FREECIV_NDEBUG
     cmdhelp_add(help, "F",
                 /* TRANS: "Fatal" is exactly what user must type, do not translate. */
                 _("Fatal [SIGNAL]"),
                 _("Raise a signal on failed assertion"));
-#endif
+#endif /* FREECIV_NDEBUG */
     cmdhelp_add(help, "f",
                 /* TRANS: "file" is exactly what user must type, do not translate. */
                 _("file FILE"),
@@ -399,6 +400,12 @@ int main(int argc, char *argv[])
                 /* TRANS: "Metaserver" is exactly what user must type, do not translate. */
                 _("Metaserver ADDR"),
                 _("Set ADDR as metaserver address"));
+#ifdef FREECIV_WEB
+    cmdhelp_add(help, "t",
+                /* TRANS: "type" is exactly what user must type, do not translate. */
+                _("type TYPE"),
+                _("Set TYPE as server type in metaserver"));
+#endif /* FREECIV_WEB */
     cmdhelp_add(help, "k", "keep",
                 _("Keep updating game information on metaserver even after "
                   "failure")),
@@ -440,6 +447,8 @@ int main(int argc, char *argv[])
 #endif /* AI_MODULES */
     cmdhelp_add(help, "v", "version",
                 _("Print the version number"));
+    cmdhelp_add(help, "w", "warnings",
+                _("Warn about deprecated modpack constructs"));
 
     /* The function below prints a header and footer for the options.
      * Furthermore, the options are sorted. */
@@ -461,7 +470,6 @@ int main(int argc, char *argv[])
   /* disallow running as root -- too dangerous */
   dont_run_as_root(argv[0], "freeciv_server");
 
-  ggz_initialize();
   init_our_capability();
 
   /* have arguments, call the main server loop... */
@@ -482,11 +490,10 @@ static void Mac_options(int argc)
 #define HARDCODED_OPT
   /*temporary hack since GetNewDialog() doesn't want to work*/
 #ifdef HARDCODED_OPT
-  srvarg.log_filename="log.out";
-  srvarg.loglevel=LOG_DEBUG;
+  srvarg.log_filename = "log.out";
+  srvarg.loglevel = LOG_DEBUG;
 #else  /* HARDCODED_OPT */
-  if (argc == 0)
-  {
+  if (argc == 0) {
     OSErr err;
     DialogPtr  optptr;
     Ptr storage;
@@ -498,51 +505,45 @@ static void Mac_options(int argc)
     short the_item, old_item=16;
     int done = false;
     Str255 the_string;
-    /*load/init the stuff for the dialog*/
-    storage =NewPtr(sizeof(DialogRecord));
-    if (storage == 0)
-    {
+
+    /* load/init the stuff for the dialog */
+    storage = NewPtr(sizeof(DialogRecord));
+    if (storage == 0) {
       exit(EXIT_FAILURE);
     }
-    ditl=Get1Resource('DITL',200);
-    if ((ditl == 0)||(ResError()))
-    {
+    ditl = Get1Resource('DITL',200);
+    if ((ditl == 0) || (ResError())) {
       exit(EXIT_FAILURE);
     }
-    dlog=Get1Resource('DLOG',200);
-    if ((dlog == 0)||(ResError()))
-    {
+    dlog = Get1Resource('DLOG',200);
+    if ((dlog == 0) || (ResError())) {
       exit(EXIT_FAILURE);
     }
-    /*make the dialog*/
-    optptr=GetNewDialog(200, storage, (WindowPtr)-1L);
-    /*setup the dialog*/
-    err=SetDialogDefaultItem(optptr, 1);
-    if (err != 0)
-    {
+    /* make the dialog */
+    optptr = GetNewDialog(200, storage, (WindowPtr)-1L);
+    /* setup the dialog */
+    err = SetDialogDefaultItem(optptr, 1);
+    if (err != 0) {
       exit(EXIT_FAILURE);
     }
-    /*insert default highlight draw code?*/
+    /* insert default highlight draw code? */
     err=SetDialogCancelItem(optptr, 2);
-    if (err != 0)
-    {
+    if (err != 0) {
       exit(EXIT_FAILURE);
     }
     err=SetDialogTracksCursor(optptr, true);
-    if (err != 0)
-    {
+    if (err != 0) {
       exit(EXIT_FAILURE);
     }
     GetDItem(optptr, 16/*normal radio button*/, &the_type, &the_handle, &the_rect);
     SetCtlValue((ControlHandle)the_handle, true);
 
-    while(!done)/*loop*/
+    while (!done) /* loop */
     {
       ModalDialog(0L, &the_item);/* don't feed 0 where a upp is expected? */
       	/* old book suggests using OL(NIL) as the first argument, but
            It doesn't include anything about UPPs either, so... */
-      switch (the_item)
-      {
+      switch (the_item) {
         case 1:
           done = true;
         break;
@@ -576,19 +577,16 @@ static void Mac_options(int argc)
     GetDItem( optptr, 10, &the_type, &the_handle, &the_rect);
     GetIText( the_handle, (unsigned char *)srvarg.script_filename);
     GetDItem(optptr, 15, &the_type, &the_handle, &the_rect);
-    if(GetControlValue((ControlHandle)the_handle))
-    {
-      srvarg.loglevel=LOG_FATAL;
+    if (GetControlValue((ControlHandle)the_handle)) {
+      srvarg.loglevel = LOG_FATAL;
     }
     GetDItem(optptr, 16, &the_type, &the_handle, &the_rect);
-    if(GetControlValue((ControlHandle)the_handle))
-    {
-      srvarg.loglevel=LOG_NORMAL;
+    if (GetControlValue((ControlHandle)the_handle)) {
+      srvarg.loglevel = LOG_NORMAL;
     }
     GetDItem(optptr, 17, &the_type, &the_handle, &the_rect);
-    if(GetControlValue((ControlHandle)the_handle))
-    {
-      srvarg.loglevel=LOG_VERBOSE;
+    if (GetControlValue((ControlHandle)the_handle)) {
+      srvarg.loglevel = LOG_VERBOSE;
     }
     DisposeDialog(optptr);/*get rid of the dialog after sorting out the options*/
     DisposePtr(storage);/*clean up the allocated memory*/
