@@ -19,11 +19,12 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
 #include <readline/readline.h>
 #endif
 
 /* utility */
+#include "deprecations.h"
 #include "fcbacktrace.h"
 #include "fciconv.h"
 #include "fcintl.h"
@@ -42,7 +43,7 @@
 static bool console_show_prompt = FALSE;
 static bool console_prompt_is_showing = FALSE;
 static bool console_rfcstyle = FALSE;
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
 static bool readline_received_enter = TRUE;
 #else
 static int con_dump(enum rfc_status rfc_status, const char *message, ...);
@@ -87,19 +88,20 @@ Print the prompt if it is not the last thing printed.
 ************************************************************************/
 static void con_update_prompt(void)
 {
-  if (console_prompt_is_showing || !console_show_prompt)
+  if (console_prompt_is_showing || !console_show_prompt) {
     return;
+  }
 
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
   if (readline_received_enter) {
     readline_received_enter = FALSE;
   } else {
     rl_forced_update_display();
   }
-#else  /* HAVE_LIBREADLINE */
+#else  /* FREECIV_HAVE_LIBREADLINE */
   con_dump(C_READY,"> ");
   con_flush();
-#endif /* HAVE_LIBREADLINE */
+#endif /* FREECIV_HAVE_LIBREADLINE */
 
   console_prompt_is_showing = TRUE;
 }
@@ -131,6 +133,14 @@ static const char *log_prefix(void)
 }
 #endif /* DEBUG */
 
+/************************************************************************
+  Deprecation warning callback to send event to clients.
+************************************************************************/
+static void depr_warn_callback(const char *msg)
+{
+  notify_conn(NULL, NULL, E_DEPRECATION_WARNING, ftc_warning, "%s", msg);
+}
+
 /************************************************************************
   Initialize logging via console.
 ************************************************************************/
@@ -145,6 +155,7 @@ void con_log_init(const char *log_filename, enum log_level level,
            fatal_assertions);
 #endif /* DEBUG */
   backtrace_init();
+  deprecation_warn_cb_set(depr_warn_callback);
 }
 
 /************************************************************************
@@ -157,7 +168,7 @@ void con_log_close(void)
   log_close();
 }
 
-#ifndef HAVE_LIBREADLINE
+#ifndef FREECIV_HAVE_LIBREADLINE
 /************************************************************************
 Write to console without line-break, don't print prompt.
 ************************************************************************/
@@ -181,7 +192,7 @@ static int con_dump(enum rfc_status rfc_status, const char *message, ...)
   console_prompt_is_showing = FALSE;
   return (int) strlen(buf);
 }
-#endif /* HAVE_LIBREADLINE */
+#endif /* FREECIV_HAVE_LIBREADLINE */
 
 /************************************************************************
 Write to console and add line-break, and show prompt if required.
@@ -288,7 +299,7 @@ User pressed enter: will need a new prompt
 void con_prompt_enter(void)
 {
   console_prompt_is_showing = FALSE;
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
   readline_received_enter = TRUE;
 #endif
 }
@@ -299,7 +310,7 @@ Clear "user pressed enter" state (used in special cases).
 void con_prompt_enter_clear(void)
 {
   console_prompt_is_showing = TRUE;
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
   readline_received_enter = FALSE;
 #endif
 }
