@@ -23,9 +23,11 @@ struct unit_list;
 
 enum plr_info_level { INFO_MINIMUM, INFO_MEETING, INFO_EMBASSY, INFO_FULL };
 
-struct player *server_create_player(int player_id, const char *ai_type,
-                                    struct rgbcolor *prgbcolor);
+struct player *server_create_player(int player_id, const char *ai_tname,
+                                    struct rgbcolor *prgbcolor,
+                                    bool allow_ai_type_fallbacking);
 const struct rgbcolor *player_preferred_color(struct player *pplayer);
+bool player_color_changeable(const struct player *pplayer, const char **reason);
 void assign_player_colors(void);
 void server_player_set_color(struct player *pplayer,
                              const struct rgbcolor *prgbcolor);
@@ -36,6 +38,9 @@ void give_midgame_initial_units(struct player *pplayer, struct tile *ptile);
 void server_remove_player(struct player *pplayer);
 void kill_player(struct player *pplayer);
 void update_revolution(struct player *pplayer);
+void government_change(struct player *pplayer, struct government *gov,
+                       bool revolution_finished);
+int revolution_length(struct government *gov, struct player *plr);
 
 struct player_economic player_limit_to_max_rates(struct player *pplayer);
 
@@ -71,6 +76,7 @@ void make_contact(struct player *pplayer1, struct player *pplayer2,
 		  struct tile *ptile);
 void maybe_make_contact(struct tile *ptile, struct player *pplayer);
 void enter_war(struct player *pplayer, struct player *pplayer2);
+void player_update_last_war_action(struct player *pplayer);
 
 void player_info_freeze(void);
 void player_info_thaw(void);
@@ -84,7 +90,7 @@ struct conn_list *player_reply_dest(struct player *pplayer);
 void shuffle_players(void);
 void set_shuffled_players(int *shuffled_players);
 struct player *shuffled_player(int i);
-void reset_all_start_commands(void);
+void reset_all_start_commands(bool plrchange);
 
 #define shuffled_players_iterate(NAME_pplayer)\
 do {\
