@@ -39,20 +39,26 @@ bool api_edit_unit_teleport(lua_State *L, Unit *punit, Tile *dest);
 
 void api_edit_unit_turn(lua_State *L, Unit *punit, Direction dir);
 
+void api_edit_unit_kill(lua_State *L, Unit *punit, const char *reason,
+                        Player *killer);
+
 void api_edit_create_city(lua_State *L, Player *pplayer, Tile *ptile,
                           const char *name);
 Player *api_edit_create_player(lua_State *L, const char *username,
                                Nation_Type *pnation, const char *ai);
 void api_edit_change_gold(lua_State *L, Player *pplayer, int amount);
 Tech_Type *api_edit_give_technology(lua_State *L, Player *pplayer,
-                                    Tech_Type *ptech, const char *reason);
-bool api_edit_trait_mod(lua_State *L, Player *pplayer, const char *trait_name,
-                        const int mod);
+                                    Tech_Type *ptech, int cost, bool notify,
+                                    const char *reason);
+bool api_edit_trait_mod_set(lua_State *L, Player *pplayer,
+                            const char *tname, const int mod);
 
+void api_edit_create_extra(lua_State *L, Tile *ptile, const char *name);
 void api_edit_create_base(lua_State *L, Tile *ptile, const char *name,
                           struct player *pplayer);
-
 void api_edit_create_road(lua_State *L, Tile *ptile, const char *name);
+void api_edit_remove_extra(lua_State *L, Tile *ptile, const char *name);
+
 void api_edit_tile_set_label(lua_State *L, Tile *ptile, const char *label);
 
 void api_edit_climate_change(lua_State *L, enum climate_change_type type,
@@ -64,4 +70,7 @@ void api_edit_player_victory(lua_State *L, Player *pplayer);
 bool api_edit_unit_move(lua_State *L, Unit *punit, Tile *ptile,
                         int movecost);
 
+void api_edit_city_add_history(lua_State *L, City *pcity, int amount);
+void api_edit_player_add_history(lua_State *L, Player *pplayer, int amount);
+
 #endif /* API_SERVER_EDIT_H */
