@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +15,15 @@
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
-#ifdef HAVE_SYS_TYPES_H
+#ifdef FREECIV_HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_SOCKET_H
@@ -39,7 +41,7 @@
 #ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
 #include <readline/history.h>
 #include <readline/readline.h>
 #endif
@@ -55,16 +57,6 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
-#ifdef HAVE_WS2TCPIP_H
-#include <ws2tcpip.h>
-#endif
 
 /* utility */
 #include "capability.h"
@@ -83,12 +75,14 @@
 #include "game.h"
 #include "packets.h"
 
+/* server/scripting */
+#include "script_server.h"
+
 /* server */
 #include "aiiface.h"
 #include "auth.h"
 #include "connecthand.h"
 #include "console.h"
-#include "ggzserver.h"
 #include "meta.h"
 #include "plrhand.h"
 #include "srv_main.h"
@@ -130,7 +124,7 @@ static int socklan;
 
 static int server_accept_connection(int sockfd);
 static void start_processing_request(struct connection *pconn,
-				     int request_id);
+                                     int request_id);
 static void finish_processing_request(struct connection *pconn);
 static void connection_ping(struct connection *pconn);
 static void send_ping_times_to_all(void);
@@ -142,28 +136,28 @@ static bool no_input = FALSE;
 
 /* Avoid compiler warning about defined, but unused function
  * by defining it only when needed */
-#if defined(HAVE_LIBREADLINE) || \
-    (!defined(SOCKET_ZERO_ISNT_STDIN) && !defined(HAVE_LIBREADLINE))  
+#if defined(FREECIV_HAVE_LIBREADLINE) || \
+    (!defined(FREECIV_SOCKET_ZERO_NOT_STDIN) && !defined(FREECIV_HAVE_LIBREADLINE))
 /*****************************************************************************
   This happens if you type an EOF character with nothing on the current line.
 *****************************************************************************/
 static void handle_stdin_close(void)
 {
-  /* Note this function may be called even if SOCKET_ZERO_ISNT_STDIN, so
+  /* Note this function may be called even if FREECIV_SOCKET_ZERO_NOT_STDIN, so
    * the preprocessor check has to come inside the function body.  But
-   * perhaps we want to do this even when SOCKET_ZERO_ISNT_STDIN? */
-#ifndef SOCKET_ZERO_ISNT_STDIN
+   * perhaps we want to do this even when FREECIV_SOCKET_ZERO_NOT_STDIN? */
+#ifndef FREECIV_SOCKET_ZERO_NOT_STDIN
   log_normal(_("Server cannot read standard input. Ignoring input."));
   no_input = TRUE;
-#endif /* SOCKET_ZERO_ISNT_STDIN */
+#endif /* FREECIV_SOCKET_ZERO_NOT_STDIN */
 }
 
-#endif /* HAVE_LIBREADLINE || (!SOCKET_ZERO_ISNT_STDIN && !HAVE_LIBREADLINE) */
+#endif /* FREECIV_HAVE_LIBREADLINE || (!FREECIV_SOCKET_ZERO_NOT_STDIN && !FREECIV_HAVE_LIBREADLINE) */
 
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
 /****************************************************************************/
 
-#define HISTORY_FILENAME  ".freeciv-server_history"
+#define HISTORY_FILENAME  "freeciv-server_history"
 #define HISTORY_LENGTH    100
 
 static char *history_file = NULL;
@@ -198,7 +192,7 @@ static void handle_readline_input_callback(char *line)
 
   readline_handled_input = TRUE;
 }
-#endif /* HAVE_LIBREADLINE */
+#endif /* FREECIV_HAVE_LIBREADLINE */
 
 /****************************************************************************
   Close the connection (very low-level). See also
@@ -219,6 +213,7 @@ static void close_connection(struct connection *pconn)
   pconn->server.ignore_list = NULL;
 
   /* safe to do these even if not in lists: */
+  conn_list_remove(game.glob_observers, pconn);
   conn_list_remove(game.all_connections, pconn);
   conn_list_remove(game.est_connections, pconn);
 
@@ -236,16 +231,18 @@ static void close_connection(struct connection *pconn)
 void close_connections_and_socket(void)
 {
   int i;
+
   lsend_packet_server_shutdown(game.all_connections);
 
-  for(i=0; i<MAX_NUM_CONNECTIONS; i++) {
-    if(connections[i].used) {
+  for (i = 0; i < MAX_NUM_CONNECTIONS; i++) {
+    if (connections[i].used) {
       close_connection(&connections[i]);
     }
     conn_list_destroy(connections[i].self);
   }
 
   /* Remove the game connection lists and make sure they are empty. */
+  conn_list_destroy(game.glob_observers);
   conn_list_destroy(game.all_connections);
   conn_list_destroy(game.est_connections);
 
@@ -258,7 +255,7 @@ void close_connections_and_socket(void)
     fc_closesocket(socklan);
   }
 
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
   if (history_file) {
     write_history(history_file);
     history_truncate_file(history_file, HISTORY_LENGTH);
@@ -266,11 +263,12 @@ void close_connections_and_socket(void)
     history_file = NULL;
     clear_history();
   }
-#endif
+#endif /* FREECIV_HAVE_LIBREADLINE */
 
   send_server_info_to_metaserver(META_GOODBYE);
   server_close_meta();
 
+  packets_deinit();
   fc_shutdown_network();
 }
 
@@ -293,6 +291,7 @@ static void really_close_connections(void)
         closing[num++] = pconn;
         /* Remove closing connections from the lists (hard detach)
          * to avoid sending to closing connections. */
+        conn_list_remove(game.glob_observers, pconn);
         conn_list_remove(game.est_connections, pconn);
         conn_list_remove(game.all_connections, pconn);
         if (NULL != conn_get_player(pconn)) {
@@ -499,27 +498,37 @@ enum server_events server_sniff_all_input(void)
   bool excepting;
   fd_set readfs, writefs, exceptfs;
   fc_timeval tv;
-#ifdef SOCKET_ZERO_ISNT_STDIN
-  char *bufptr;    
+#ifdef FREECIV_SOCKET_ZERO_NOT_STDIN
+  char *bufptr;
 #endif
 
   con_prompt_init();
 
-#ifdef HAVE_LIBREADLINE
+#ifdef FREECIV_HAVE_LIBREADLINE
   {
     if (!no_input && !readline_initialized) {
       char *home_dir = user_home_dir();
 
       if (home_dir) {
-	history_file
-	  = fc_malloc(strlen(home_dir) + 1 + strlen(HISTORY_FILENAME) + 1);
-	if (history_file) {
-	  strcpy(history_file, home_dir);
-	  strcat(history_file, "/");
-	  strcat(history_file, HISTORY_FILENAME);
-	  using_history();
-	  read_history(history_file);
-	}
+        int fcdl = strlen(home_dir) + 1 + strlen(".freeciv") + 1;
+        char *fc_dir = fc_malloc(fcdl);
+
+        if (fc_dir != NULL) {
+          fc_snprintf(fc_dir, fcdl, "%s/.freeciv", home_dir);
+
+          if (make_dir(fc_dir)) {
+            history_file
+              = fc_malloc(strlen(fc_dir) + 1 + strlen(HISTORY_FILENAME) + 1);
+            if (history_file) {
+              strcpy(history_file, fc_dir);
+              strcat(history_file, "/");
+              strcat(history_file, HISTORY_FILENAME);
+              using_history();
+              read_history(history_file);
+            }
+          }
+          FC_FREE(fc_dir);
+        }
       }
 
       rl_initialize();
@@ -531,11 +540,11 @@ enum server_events server_sniff_all_input(void)
       atexit(rl_callback_handler_remove);
     }
   }
-#endif /* HAVE_LIBREADLINE */
+#endif /* FREECIV_HAVE_LIBREADLINE */
 
   while (TRUE) {
     con_prompt_on();		/* accepting new input */
-    
+
     if (force_end_of_sniff) {
       force_end_of_sniff = FALSE;
       con_prompt_off();
@@ -548,12 +557,12 @@ enum server_events server_sniff_all_input(void)
      * but only if at least one player has previously connected. */
     if (srvarg.quitidle != 0) {
       static time_t last_noplayers;
-      static bool connections;
+      static bool conns;
 
       if (conn_list_size(game.est_connections) > 0) {
-	connections = TRUE;
+	conns = TRUE;
       }
-      if (connections && conn_list_size(game.est_connections) == 0) {
+      if (conns && conn_list_size(game.est_connections) == 0) {
 	if (last_noplayers != 0) {
 	  if (time(NULL) > last_noplayers + srvarg.quitidle) {
 	    save_game_auto("Lost all connections", AS_QUITIDLE);
@@ -576,7 +585,7 @@ enum server_events server_sniff_all_input(void)
 	    }
 
             /* Do not restart before someone has connected and left again */
-            connections = FALSE;
+            conns = FALSE;
 	  }
 	} else {
 	  last_noplayers = time(NULL);
@@ -642,6 +651,7 @@ enum server_events server_sniff_all_input(void)
     /* Don't wait if timeout == -1 (i.e. on auto games) */
     if (S_S_RUNNING == server_state() && game.info.timeout == -1) {
       call_ai_refresh();
+      script_server_signal_emit("pulse", 0);
       (void) send_server_info_to_metaserver(META_REFRESH);
       return S_E_END_OF_TURN_TIMEOUT;
     }
@@ -654,13 +664,13 @@ enum server_events server_sniff_all_input(void)
     FC_FD_ZERO(&exceptfs);
 
     if (!no_input) {
-#ifdef SOCKET_ZERO_ISNT_STDIN
+#ifdef FREECIV_SOCKET_ZERO_NOT_STDIN
       fc_init_console();
-#else /* SOCKET_ZERO_ISNT_STDIN */
+#else /* FREECIV_SOCKET_ZERO_NOT_STDIN */
 #   if !defined(__VMS)
       FD_SET(0, &readfs);
-#   endif /* VMS */	
-#endif /* SOCKET_ZERO_ISNT_STDIN */
+#   endif /* VMS */
+#endif /* FREECIV_SOCKET_ZERO_NOT_STDIN */
     }
 
     max_desc = 0;
@@ -670,17 +680,9 @@ enum server_events server_sniff_all_input(void)
       max_desc = MAX(max_desc, listen_socks[i]);
     }
 
-    if (with_ggz) {
-#ifdef GGZ_SERVER
-      int ggz_sock = get_ggz_socket();
-
-      FD_SET(ggz_sock, &readfs);
-      max_desc = MAX(max_desc, ggz_sock);
-#endif /* GGZ_SERVER */
-    }
-
     for (i = 0; i < MAX_NUM_CONNECTIONS; i++) {
       struct connection *pconn = connections + i;
+
       if (pconn->used && !pconn->server.is_closing) {
         FD_SET(pconn->sock, &readfs);
         if (0 < pconn->send_buffer->ndata) {
@@ -695,15 +697,25 @@ enum server_events server_sniff_all_input(void)
     if (fc_select(max_desc + 1, &readfs, &writefs, &exceptfs, &tv) == 0) {
       /* timeout */
       call_ai_refresh();
+      script_server_signal_emit("pulse", 0);
       (void) send_server_info_to_metaserver(META_REFRESH);
       if (current_turn_timeout() > 0
 	  && S_S_RUNNING == server_state()
 	  && game.server.phase_timer
 	  && (timer_read_seconds(game.server.phase_timer)
-	      > game.info.seconds_to_phasedone)) {
+	      > game.tinfo.seconds_to_phasedone)) {
 	con_prompt_off();
 	return S_E_END_OF_TURN_TIMEOUT;
       }
+      if ((game.server.autosaves & (1 << AS_TIMER))
+          && S_S_RUNNING == server_state()
+          && (timer_read_seconds(game.server.save_timer)
+              >= game.server.save_frequency * 60)) {
+        save_game_auto("Timer", AS_TIMER);
+        game.server.save_timer = timer_renew(game.server.save_timer,
+                                             TIMER_USER, TIMER_ACTIVE);
+        timer_start(game.server.save_timer);
+      }
 
       if (!no_input) {
 #if defined(__VMS)
@@ -729,36 +741,34 @@ enum server_events server_sniff_all_input(void)
 	  }
 	}
 #else  /* !__VMS */
-#ifndef SOCKET_ZERO_ISNT_STDIN
+#ifndef FREECIV_SOCKET_ZERO_NOT_STDIN
         really_close_connections();
         continue;
-#endif /* SOCKET_ZERO_ISNT_STDIN */
+#endif /* FREECIV_SOCKET_ZERO_NOT_STDIN */
 #endif /* !__VMS */
       }
     }
 
-    if (!with_ggz) { /* No listening socket when using GGZ. */
-      excepting = FALSE;
-      for (i = 0; i < listen_count; i++) {
-        if (FD_ISSET(listen_socks[i], &exceptfs)) {
-          excepting = TRUE;
-          break;
-        }
+    excepting = FALSE;
+    for (i = 0; i < listen_count; i++) {
+      if (FD_ISSET(listen_socks[i], &exceptfs)) {
+        excepting = TRUE;
+        break;
       }
-      if (excepting) {                  /* handle Ctrl-Z suspend/resume */
-	continue;
-      }
-      for (i = 0; i < listen_count; i++) {
-        s = listen_socks[i];
-        if (FD_ISSET(s, &readfs)) {     /* new players connects */
-          log_verbose("got new connection");
-          if (-1 == server_accept_connection(s)) {
-            /* There will be a log_error() message from
-             * server_accept_connection() if something
-             * goes wrong, so no need to make another
-             * error-level message here. */
-            log_verbose("failed accepting connection");
-          }
+    }
+    if (excepting) {                  /* handle Ctrl-Z suspend/resume */
+      continue;
+    }
+    for (i = 0; i < listen_count; i++) {
+      s = listen_socks[i];
+      if (FD_ISSET(s, &readfs)) {     /* new players connects */
+        log_verbose("got new connection");
+        if (-1 == server_accept_connection(s)) {
+          /* There will be a log_error() message from
+           * server_accept_connection() if something
+           * goes wrong, so no need to make another
+           * error-level message here. */
+          log_verbose("failed accepting connection");
         }
       }
     }
@@ -774,19 +784,7 @@ enum server_events server_sniff_all_input(void)
         connection_close_server(pconn, _("network exception"));
       }
     }
-#ifdef GGZ_SERVER
-    if (with_ggz) {
-      /* This is intentionally after all the player socket handling because
-       * it may cut a client. */
-      int ggz_sock = get_ggz_socket();
-
-      if (FD_ISSET(ggz_sock, &readfs)) {
-	input_from_ggz(ggz_sock);
-      }
-    }
-#endif /* GGZ_SERVER */
-    
-#ifdef SOCKET_ZERO_ISNT_STDIN
+#ifdef FREECIV_SOCKET_ZERO_NOT_STDIN
     if (!no_input && (bufptr = fc_read_console())) {
       char *bufptr_internal = local_to_internal_string_malloc(bufptr);
 
@@ -794,16 +792,16 @@ enum server_events server_sniff_all_input(void)
       handle_stdin_input(NULL, bufptr_internal);
       free(bufptr_internal);
     }
-#else  /* !SOCKET_ZERO_ISNT_STDIN */
-    if(!no_input && FD_ISSET(0, &readfs)) {    /* input from server operator */
-#ifdef HAVE_LIBREADLINE
+#else  /* !FREECIV_SOCKET_ZERO_NOT_STDIN */
+    if (!no_input && FD_ISSET(0, &readfs)) {    /* input from server operator */
+#ifdef FREECIV_HAVE_LIBREADLINE
       rl_callback_read_char();
       if (readline_handled_input) {
-	readline_handled_input = FALSE;
-	con_prompt_enter_clear();
+        readline_handled_input = FALSE;
+        con_prompt_enter_clear();
       }
       continue;
-#else  /* !HAVE_LIBREADLINE */
+#else  /* !FREECIV_HAVE_LIBREADLINE */
       ssize_t didget;
       char *buffer = NULL; /* Must be NULL when calling getline() */
       char *buf_internal;
@@ -840,12 +838,12 @@ enum server_events server_sniff_all_input(void)
         free(buf_internal);
       }
       free(buffer);
-#endif /* !HAVE_LIBREADLINE */
+#endif /* !FREECIV_HAVE_LIBREADLINE */
     } else
-#endif /* !SOCKET_ZERO_ISNT_STDIN */
-     
+#endif /* !FREECIV_SOCKET_ZERO_NOT_STDIN */
+
     {                             /* input from a player */
-      for(i = 0; i < MAX_NUM_CONNECTIONS; i++) {
+      for (i = 0; i < MAX_NUM_CONNECTIONS; i++) {
         struct connection *pconn = connections + i;
         int nb;
 
@@ -853,7 +851,7 @@ enum server_events server_sniff_all_input(void)
             || pconn->server.is_closing
             || !FD_ISSET(pconn->sock, &readfs)) {
           continue;
-	}
+        }
 
         nb = read_socket_data(pconn->sock, pconn->buffer);
         if (0 <= nb) {
@@ -873,29 +871,40 @@ enum server_events server_sniff_all_input(void)
         if (pconn->used
             && !pconn->server.is_closing
             && pconn->send_buffer
-	    && pconn->send_buffer->ndata > 0) {
-	  if (FD_ISSET(pconn->sock, &writefs)) {
-	    flush_connection_send_buffer_all(pconn);
-	  } else {
-	    cut_lagging_connection(pconn);
-	  }
+            && pconn->send_buffer->ndata > 0) {
+          if (FD_ISSET(pconn->sock, &writefs)) {
+            flush_connection_send_buffer_all(pconn);
+          } else {
+            cut_lagging_connection(pconn);
+          }
         }
       }
+      really_close_connections();
+      break;
     }
-    really_close_connections();
-    break;
   }
   con_prompt_off();
 
   call_ai_refresh();
+  script_server_signal_emit("pulse", 0);
 
   if (current_turn_timeout() > 0
       && S_S_RUNNING == server_state()
       && game.server.phase_timer
       && (timer_read_seconds(game.server.phase_timer)
-          > game.info.seconds_to_phasedone)) {
+          > game.tinfo.seconds_to_phasedone)) {
     return S_E_END_OF_TURN_TIMEOUT;
   }
+  if ((game.server.autosaves & (1 << AS_TIMER))
+      && S_S_RUNNING == server_state()
+      && (timer_read_seconds(game.server.save_timer)
+          >= game.server.save_frequency * 60)) {
+    save_game_auto("Timer", AS_TIMER);
+    game.server.save_timer = timer_renew(game.server.save_timer,
+                                         TIMER_USER, TIMER_ACTIVE);
+    timer_start(game.server.save_timer);
+  }
+
   return S_E_OTHERWISE;
 }
 
@@ -940,7 +949,7 @@ static int server_accept_connection(int sockfd)
   int new_sock;
   union fc_sockaddr fromend;
   bool nameinfo = FALSE;
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   char host[NI_MAXHOST], service[NI_MAXSERV];
   char dst[INET6_ADDRSTRLEN];
 #else  /* IPv6 support */
@@ -956,7 +965,7 @@ static int server_accept_connection(int sockfd)
     return -1;
   }
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (fromend.saddr.sa_family == AF_INET6) {
     inet_ntop(AF_INET6, &fromend.saddr_in6.sin6_addr,
               dst, sizeof(dst));
@@ -993,7 +1002,7 @@ static int server_accept_connection(int sockfd)
     } conn_list_iterate_end;
   }
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   nameinfo = (0 == getnameinfo(&fromend.saddr, fromlen, host, NI_MAXHOST,
                                service, NI_MAXSERV, NI_NUMERICSERV)
               && '\0' != host[0]);
@@ -1091,7 +1100,7 @@ int server_open_socket(void)
   fc_errno eno = 0;
   union fc_sockaddr *problematic = NULL;
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   struct ipv6_mreq mreq6;
 #endif
 
@@ -1130,19 +1139,19 @@ int server_open_socket(void)
       continue;
     }
 
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
     /* SO_REUSEADDR considered harmful on Win, necessary otherwise */
     if (setsockopt(s, SOL_SOCKET, SO_REUSEADDR, 
                    (char *)&on, sizeof(on)) == -1) {
       log_error("setsockopt SO_REUSEADDR failed: %s",
                 fc_strerror(fc_get_errno()));
-      sockaddr_debug(paddr, LOG_DEBUG);
+      sockaddr_debug(paddr, LOG_NORMAL);
     }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
     /* AF_INET6 sockets should use IPv6 only,
      * without stealing IPv4 from AF_INET sockets. */
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
     if (paddr->saddr.sa_family == AF_INET6) {
 #ifdef IPV6_V6ONLY
       if (setsockopt(s, IPPROTO_IPV6, IPV6_V6ONLY,
@@ -1198,7 +1207,10 @@ int server_open_socket(void)
       sockaddr_debug(problematic, LOG_NORMAL);
     }
     fc_sockaddr_list_iterate(list, paddr) {
-      sockaddr_debug(paddr, LOG_DEBUG);
+      /* Do not list already logged 'problematic' again */
+      if (paddr != problematic) {
+        sockaddr_debug(paddr, LOG_DEBUG);
+      }
     } fc_sockaddr_list_iterate_end;
     exit(EXIT_FAILURE);
   }
@@ -1211,7 +1223,7 @@ int server_open_socket(void)
     return 0;
   }
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (srvarg.announce == ANNOUNCE_IPV6) {
     lan_family = AF_INET6;
   } else
@@ -1240,7 +1252,7 @@ int server_open_socket(void)
 
   addr.saddr.sa_family = lan_family;
 
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (addr.saddr.sa_family == AF_INET6) {
     addr.saddr_in6.sin6_family = AF_INET6;
     addr.saddr_in6.sin6_port = htons(SERVER_LAN_PORT);
@@ -1261,7 +1273,7 @@ int server_open_socket(void)
     log_error("Announcement socket binding failed: %s", fc_strerror(fc_get_errno()));
   }
 
-#ifndef IPV6_SUPPORT
+#ifndef FREECIV_IPV6_SUPPORT
   if (addr.saddr.sa_family == AF_INET) {
 #ifdef HAVE_INET_ATON
     inet_aton(group, &mreq4.imr_multiaddr);
@@ -1312,6 +1324,7 @@ void init_connections(void)
 
   game.all_connections = conn_list_new();
   game.est_connections = conn_list_new();
+  game.glob_observers = conn_list_new();
 
   for(i=0; i<MAX_NUM_CONNECTIONS; i++) { 
     struct connection *pconn = &connections[i];
@@ -1394,6 +1407,14 @@ void handle_conn_pong(struct connection *pconn)
             timer_list_size(pconn->server.ping_timers), pconn->ping_time);
 }
 
+/**************************************************************************
+  Handle client's regular hearbeat
+**************************************************************************/
+void handle_client_heartbeat(struct connection *pconn)
+{
+  log_debug("Received heartbeat");
+}
+
 /**************************************************************************
   Send ping time info about all connections to all connections.
 **************************************************************************/
@@ -1429,10 +1450,6 @@ static void get_lanserver_announcement(void)
   fd_set readfs, exceptfs;
   fc_timeval tv;
 
-  if (with_ggz) {
-    return;
-  }
-
   if (srvarg.announce == ANNOUNCE_NONE) {
     return;
   }
@@ -1474,11 +1491,11 @@ static void get_lanserver_announcement(void)
 ********************************************************************/
 static void send_lanserver_response(void)
 {
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
   unsigned char buffer[MAX_LEN_PACKET];
-#else  /* HAVE_WINSOCK */
+#else  /* FREECIV_HAVE_WINSOCK */
   char buffer[MAX_LEN_PACKET];
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
   char hostname[512];
   char port[256];
   char version[256];
@@ -1491,7 +1508,7 @@ static void send_lanserver_response(void)
   int socksend, setting = 1;
   const char *group;
   size_t size;
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
   unsigned char ttl;
 #endif
 
@@ -1510,7 +1527,7 @@ static void send_lanserver_response(void)
 
 /* this setsockopt call fails on Windows 98, so we stick with the default
  * value of 1 on Windows, which should be fine in most cases */
-#ifndef HAVE_WINSOCK
+#ifndef FREECIV_HAVE_WINSOCK
   /* Set the Time-to-Live field for the packet.  */
   ttl = SERVER_LAN_TTL;
   if (setsockopt(socksend, IPPROTO_IP, IP_MULTICAST_TTL, 
@@ -1518,7 +1535,7 @@ static void send_lanserver_response(void)
     log_error("setsockopt failed: %s", fc_strerror(fc_get_errno()));
     return;
   }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   if (setsockopt(socksend, SOL_SOCKET, SO_BROADCAST, 
                  (const char*)&setting, sizeof(setting))) {
