@@ -15,7 +15,7 @@
 
 /* utility */
 #include "log.h"        /* enum log_level */
-#include "netintf.h"
+#include "net_types.h"  /* announce_type */
 
 /* common */
 #include "fc_types.h"
@@ -120,6 +120,4 @@ extern bool force_end_of_sniff;
 
 void update_nations_with_startpos(void);
 
-int current_turn_timeout(void);
-
 #endif /* FC__SRV_MAIN_H */
