@@ -139,14 +139,13 @@ void do_tech_parasite_effect(struct player *pplayer)
 {
   struct effect_list *plist = effect_list_new();
   struct astring effects;
-  struct research *presearch;
+  struct research *plr_research;
   char research_name[MAX_LEN_NAME * 2];
   const char *advance_name;
   Tech_type_id tech;
   /* Note that two EFT_TECH_PARASITE effects will combine into a single,
    * much worse effect. */
   int mod = get_player_bonus_effects(plist, pplayer, EFT_TECH_PARASITE);
-  int num_players;
   int num_techs;
 
   if (mod <= 0) {
@@ -158,25 +157,27 @@ void do_tech_parasite_effect(struct player *pplayer)
   /* Pick a random technology. */
   tech = A_UNSET;
   num_techs = 0;
-  presearch = research_get(pplayer);
+  plr_research = research_get(pplayer);
   advance_index_iterate(A_FIRST, i) {
-    if (!research_invention_gettable(presearch, i,
+    int num_teams;
+
+    if (!research_invention_gettable(plr_research, i,
                                      game.info.tech_parasite_allow_holes)
-        || TECH_KNOWN == research_invention_state(presearch, i)) {
+        || TECH_KNOWN == research_invention_state(plr_research, i)) {
       continue;
     }
 
-    num_players = 0;
-    players_iterate(aplayer) {
-      if (TECH_KNOWN == research_invention_state(research_get(aplayer), i)) {
-        if (mod <= ++num_players) {
+    num_teams = 0;
+    researches_iterate(other_research) {
+      if (TECH_KNOWN == research_invention_state(other_research, i)) {
+        if (mod <= ++num_teams) {
           if (0 == fc_rand(++num_techs)) {
             tech = i;
           }
           break;
         }
       }
-    } players_iterate_end;
+    } researches_iterate_end;
   } advance_index_iterate_end;
 
   if (A_UNSET == tech) {
@@ -186,8 +187,8 @@ void do_tech_parasite_effect(struct player *pplayer)
   }
 
   /* Notify. */
-  research_pretty_name(presearch, research_name, sizeof(research_name));
-  advance_name = research_advance_name_translation(presearch, tech);
+  research_pretty_name(plr_research, research_name, sizeof(research_name));
+  advance_name = research_advance_name_translation(plr_research, tech);
   astr_init(&effects);
   get_effect_list_req_text(plist, &effects);
 
@@ -197,14 +198,14 @@ void do_tech_parasite_effect(struct player *pplayer)
                 Q_("?fromeffect:%s acquired from %s!"),
                 advance_name,
                 astr_str(&effects));
-  notify_research(presearch, pplayer, E_TECH_GAIN, ftc_server,
+  notify_research(plr_research, pplayer, E_TECH_GAIN, ftc_server,
                   /* TRANS: Tech from source of an effect
                    * (Great Library) */
                   Q_("?fromeffect:%s acquired from %s's %s!"),
                   advance_name,
                   player_name(pplayer),
                   astr_str(&effects));
-  notify_research_embassies(presearch, NULL, E_TECH_EMBASSY, ftc_server,
+  notify_research_embassies(plr_research, NULL, E_TECH_EMBASSY, ftc_server,
                             /* TRANS: Tech from source of an effect
                              * (Great Library) */
                             Q_("?fromeffect:The %s have acquired %s from %s."),
@@ -216,10 +217,10 @@ void do_tech_parasite_effect(struct player *pplayer)
   astr_free(&effects);
 
   /* Really get tech. */
-  research_apply_penalty(presearch, tech, game.server.freecost);
-  found_new_tech(presearch, tech, FALSE, TRUE);
+  research_apply_penalty(plr_research, tech, game.server.freecost);
+  found_new_tech(plr_research, tech, FALSE, TRUE);
 
-  research_players_iterate(presearch, member) {
+  research_players_iterate(plr_research, member) {
     script_server_signal_emit("tech_researched", 3,
                               API_TYPE_TECH_TYPE, advance_by_number(tech),
                               API_TYPE_PLAYER, member,
