@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,9 +16,9 @@
 #endif
 
 /* utility */
+#include "fc_cmdline.h"
 #include "fciconv.h"
 #include "fcintl.h"
-#include "shared.h"
 #include "support.h"
 
 /* common */
@@ -93,13 +93,13 @@ int fcmp_parse_cmdline(int argc, char *argv[])
       cmdhelp_destroy(help);
 
       exit(EXIT_SUCCESS);
-    } else if ((option = get_option_malloc("--List", argv, &i, argc))) {
+    } else if ((option = get_option_malloc("--List", argv, &i, argc, TRUE))) {
       fcmp.list_url = option;
-    } else if ((option = get_option_malloc("--prefix", argv, &i, argc))) {
+    } else if ((option = get_option_malloc("--prefix", argv, &i, argc, TRUE))) {
       fcmp.inst_prefix = option;
-    } else if ((option = get_option_malloc("--install", argv, &i, argc))) {
+    } else if ((option = get_option_malloc("--install", argv, &i, argc, TRUE))) {
       fcmp.autoinstall = option;
-    } else if ((option = get_option_malloc("--debug", argv, &i, argc))) {
+    } else if ((option = get_option_malloc("--debug", argv, &i, argc, FALSE))) {
       if (!log_parse_level_str(option, &loglevel)) {
         fc_fprintf(stderr,
                    _("Invalid debug level \"%s\" specified with --debug "
@@ -132,7 +132,7 @@ int fcmp_parse_cmdline(int argc, char *argv[])
     } else {
       static char pfx_buf[500];
 
-      snprintf(pfx_buf, sizeof(pfx_buf), "%s/.freeciv", home);
+      snprintf(pfx_buf, sizeof(pfx_buf), "%s" DIR_SEPARATOR ".freeciv", home);
       fcmp.inst_prefix = pfx_buf;
     }
   }
