@@ -224,7 +224,7 @@ void mpgui::setup(QWidget *central, struct fcmp_params *params)
 
   connect(mplist_table, SIGNAL(cellClicked(int, int)), this, SLOT(row_selected(int, int)));
   connect(mplist_table, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(row_download(QModelIndex)));
-  connect(this, SIGNAL(display_msg_thr_signal(const char *)), this, SLOT(display_msg(const char *)));
+  connect(this, SIGNAL(display_msg_thr_signal(QString)), this, SLOT(display_msg(QString)));
   connect(this, SIGNAL(progress_thr_signal(int, int)), this, SLOT(progress(int, int)));
   connect(this, SIGNAL(refresh_list_versions_thr_signal()), this, SLOT(refresh_list_versions()));
 
@@ -265,10 +265,11 @@ void mpgui::setup(QWidget *central, struct fcmp_params *params)
 /**************************************************************************
   Display status message
 **************************************************************************/
-void mpgui::display_msg(const char *msg)
+void mpgui::display_msg(QString msg)
 {
-  log_verbose("%s", msg);
-  msg_dspl->setText(QString::fromUtf8(msg));
+  QByteArray msg_bytes = msg.toLocal8Bit();
+  log_verbose("%s", msg_bytes.data());
+  msg_dspl->setText(msg);
 }
 
 /**************************************************************************
@@ -276,7 +277,7 @@ void mpgui::display_msg(const char *msg)
 **************************************************************************/
 void mpgui::display_msg_thr(const char *msg)
 {
-  emit display_msg_thr_signal(msg);
+  emit display_msg_thr_signal(QString::fromUtf8(msg));
 }
 
 /**************************************************************************
