@@ -14,10 +14,15 @@
 #ifndef FC__MEM_H
 #define FC__MEM_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #include <stdlib.h>             /* size_t; actually stddef.h, but stdlib.h
                                  * might be more reliable? --dwp */
 
 /* utility */
+#include "log.h"
 #include "support.h"            /* fc__warn_unused_result */
 
 /* fc_malloc, fc_realloc, fc_calloc:
@@ -27,17 +32,16 @@
  */
    
 #define fc_malloc(sz)      fc_real_malloc((sz), "malloc", \
-					  __LINE__, __FILE__)
+					  __FC_LINE__, __FILE__)
 #define fc_realloc(ptr,sz) fc_real_realloc((ptr), (sz), "realloc", \
-					   __LINE__, __FILE__)
+					   __FC_LINE__, __FILE__)
 #define fc_calloc(n,esz)   fc_real_calloc((n), (esz), "calloc", \
-					   __LINE__, __FILE__)
+					   __FC_LINE__, __FILE__)
                                            
 #define FC_FREE(ptr)       do { free(ptr); (ptr) = NULL; } while(0)
 
-#define mystrdup(str)      real_mystrdup((str), "strdup", \
-					 __LINE__, __FILE__)
-     
+#define fc_strdup(str) real_fc_strdup((str), "strdup", __FC_LINE__, __FILE__)
+
 /***********************************************************************/
 
 /* You shouldn't call these functions directly;
@@ -53,8 +57,12 @@ void *fc_real_calloc(size_t nelem, size_t elsize,
                      const char *called_as, int line, const char *file)
                      fc__warn_unused_result;
 
-char *real_mystrdup(const char *str, 
-                    const char *called_as, int line, const char *file)
-                    fc__warn_unused_result;
+char *real_fc_strdup(const char *str,
+                     const char *called_as, int line, const char *file)
+                     fc__warn_unused_result;
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif /* FC__MEM_H */
