@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,14 +11,16 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-/********************************************************************** 
+/***********************************************************************
   Common network interface.
-**********************************************************************/
+***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
 #include <fc_config.h>
 #endif
 
+#include "fc_prehdrs.h"
+
 #include <errno.h>
 #include <signal.h>
 #include <stdio.h>
@@ -43,13 +45,6 @@
 #ifdef HAVE_SYS_SIGNAL_H
 #include <sys/signal.h>
 #endif
-#ifdef HAVE_WINSOCK
-#ifdef HAVE_WINSOCK2
-#include <winsock2.h>
-#else  /* HAVE_WINSOCK2 */
-#include <winsock.h>
-#endif /* HAVE_WINSOCK2 */
-#endif /* HAVE_WINSOCK */
 #ifdef WIN32_NATIVE
 #include <windows.h>	/* GetTempPath */
 #endif
@@ -74,7 +69,7 @@
 #endif /* AI_NUMERICSERV */
 #endif /* HAVE_GETADDRINFO */
 
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
 /***************************************************************
   Set errno variable on Winsock error
 ***************************************************************/
@@ -89,6 +84,7 @@ static void set_socket_errno(void)
     case WSAECONNRESET:
     case WSAECONNREFUSED:
     case WSAETIMEDOUT:
+    case WSAECONNABORTED:
       errno = err;
       return;
     default:
@@ -99,7 +95,7 @@ static void set_socket_errno(void)
       errno = 0;
   }
 }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
 /***************************************************************
   Connect a socket to an address
@@ -110,11 +106,11 @@ int fc_connect(int sockfd, const struct sockaddr *serv_addr, socklen_t addrlen)
   
   result = connect(sockfd, serv_addr, addrlen);
   
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   if (result == -1) {
     set_socket_errno();
   }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   return result;
 }
@@ -129,11 +125,11 @@ int fc_select(int n, fd_set *readfds, fd_set *writefds, fd_set *exceptfds,
 
   result = select(n, readfds, writefds, exceptfds, timeout);
 
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   if (result == -1) {
     set_socket_errno();
   }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   return result;
 }
@@ -145,14 +141,14 @@ int fc_readsocket(int sock, void *buf, size_t size)
 {
   int result;
   
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   result = recv(sock, buf, size, 0);
   if (result == -1) {
     set_socket_errno();
   }
-#else  /* HAVE_WINSOCK */
+#else  /* FREECIV_HAVE_WINSOCK */
   result = read(sock, buf, size);
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   return result;
 }
@@ -164,18 +160,18 @@ int fc_writesocket(int sock, const void *buf, size_t size)
 {
   int result;
         
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   result = send(sock, buf, size, 0);
   if (result == -1) {
     set_socket_errno();
   }
-#else  /* HAVE_WINSOCK */
+#else  /* FREECIV_HAVE_WINSOCK */
 #  ifdef MSG_NOSIGNAL
   result = send(sock, buf, size, MSG_NOSIGNAL);
 #  else  /* MSG_NOSIGNAL */
   result = write(sock, buf, size);
 #  endif /* MSG_NOSIGNAL */
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   return result;
 }
@@ -185,7 +181,7 @@ int fc_writesocket(int sock, const void *buf, size_t size)
 ***************************************************************/
 void fc_closesocket(int sock)
 {
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   closesocket(sock);
 #else
   close(sock);
@@ -197,13 +193,13 @@ void fc_closesocket(int sock)
 ***************************************************************/
 void fc_init_network(void)
 {
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   WSADATA wsa;
 
   if (WSAStartup(MAKEWORD(1, 1), &wsa) != 0) {
     log_error("no usable WINSOCK.DLL: %s", fc_strerror(fc_get_errno()));
   }
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 
   /* broken pipes are ignored. */
 #ifdef HAVE_SIGPIPE
@@ -216,7 +212,7 @@ void fc_init_network(void)
 ***************************************************************/
 void fc_shutdown_network(void)
 {
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
   WSACleanup();
 #endif
 }
@@ -227,7 +223,7 @@ void fc_shutdown_network(void)
 void fc_nonblock(int sockfd)
 {
 #ifdef NONBLOCKING_SOCKETS
-#ifdef HAVE_WINSOCK
+#ifdef FREECIV_HAVE_WINSOCK
 #ifdef __LP64__
   unsigned b = 1;
 #else  /* __LP64__ */
@@ -235,7 +231,7 @@ void fc_nonblock(int sockfd)
 #endif /* __LP64__ */
 
   ioctlsocket(sockfd, FIONBIO, &b);
-#else  /* HAVE_WINSOCK */
+#else  /* FREECIV_HAVE_WINSOCK */
 #ifdef HAVE_FCNTL
   int f_set;
 
@@ -257,7 +253,7 @@ void fc_nonblock(int sockfd)
   }
 #endif /* HAVE_IOCTL */
 #endif /* HAVE_FCNTL */
-#endif /* HAVE_WINSOCK */
+#endif /* FREECIV_HAVE_WINSOCK */
 #else  /* NONBLOCKING_SOCKETS */
   log_debug("NONBLOCKING_SOCKETS not available");
 #endif /* NONBLOCKING_SOCKETS */
@@ -268,7 +264,7 @@ void fc_nonblock(int sockfd)
 ***************************************************************************/
 void sockaddr_debug(union fc_sockaddr *addr, enum log_level lvl)
 {
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   char buf[INET6_ADDRSTRLEN] = "Unknown";
 
   if (addr->saddr.sa_family == AF_INET6) { 
@@ -307,11 +303,11 @@ int sockaddr_size(union fc_sockaddr *addr)
 #ifdef WIN32_NATIVE
   return sizeof(*addr);
 #else
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (addr->saddr.sa_family == AF_INET6) {
     return sizeof(addr->saddr_in6);
   } else
-#endif /* IPV6_SUPPORT */
+#endif /* FREECIV_IPV6_SUPPORT */
   if (addr->saddr.sa_family == AF_INET) {
     return sizeof(addr->saddr_in4);
   } else {
@@ -329,7 +325,7 @@ int sockaddr_size(union fc_sockaddr *addr)
 ***************************************************************************/
 bool sockaddr_ipv6(union fc_sockaddr *addr)
 {
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
   if (addr->saddr.sa_family == AF_INET6) {
     return TRUE;
   }
@@ -362,7 +358,7 @@ static struct fc_sockaddr_list *net_lookup_getaddrinfo(const char *name,
       gafam = AF_INET6;
       break;
     case FC_ADDR_ANY:
-#ifndef IPV6_SUPPORT
+#ifndef FREECIV_IPV6_SUPPORT
       gafam = AF_INET;
 #else
       gafam = AF_UNSPEC;
@@ -538,7 +534,7 @@ int find_next_free_port(int starting_port, int highest_port,
   int gafamily;
   bool found = FALSE;
 
-#ifndef IPV6_SUPPORT
+#ifndef FREECIV_IPV6_SUPPORT
   fc_assert(family == FC_ADDR_IPV4 || family == FC_ADDR_ANY);
 #endif
 
@@ -546,11 +542,11 @@ int find_next_free_port(int starting_port, int highest_port,
    case FC_ADDR_IPV4:
      gafamily = AF_INET;
      break;
-#ifdef IPV6_SUPPORT
+#ifdef FREECIV_IPV6_SUPPORT
    case FC_ADDR_IPV6:
      gafamily = AF_INET6;
      break;
-#endif /* IPV6_SUPPORT */
+#endif /* FREECIV_IPV6_SUPPORT */
    case FC_ADDR_ANY:
      gafamily = AF_UNSPEC;
      break;
