@@ -586,6 +586,39 @@ bool str_to_int(const char *str, int *pint)
   return ('\0' == *str && (NULL == pint || 1 == sscanf(start, "%d", pint)));
 }
 
+/****************************************************************************
+  Convert 'str' to it's unsigned int reprentation if possible. 'pint' can be NULL,
+  then it will only test 'str' only contains an unsigned integer number.
+****************************************************************************/
+bool str_to_uint(const char *str, unsigned int *pint)
+{
+  const char *start;
+
+  fc_assert_ret_val(NULL != str, FALSE);
+
+  while (fc_isspace(*str)) {
+    /* Skip leading spaces. */
+    str++;
+  }
+
+  start = str;
+  if ('+' == *str) {
+    /* Handle sign. */
+    str++;
+  }
+  while (fc_isdigit(*str)) {
+    /* Digits. */
+    str++;
+  }
+
+  while (fc_isspace(*str)) {
+    /* Ignore trailing spaces. */
+    str++;
+  }
+
+  return ('\0' == *str && (NULL == pint || 1 == sscanf(start, "%u", pint)));
+}
+
 /****************************************************************************
   Convert 'str' to it's float reprentation if possible. 'pfloat' can be NULL,
   then it will only test 'str' only contains a floating point number.
@@ -1782,7 +1815,7 @@ bool make_dir(const char *pathname)
     dir = strchr(dir, DIR_SEPARATOR_CHAR);
     /* We set the current / with 0, and restore it afterwards */
     if (dir) {
-      *dir = 0;
+      *dir = '\0';
     }
 
 #ifdef WIN32_NATIVE
@@ -2109,7 +2142,7 @@ bool wildcard_fit_string(const char *pattern, const char *test)
       break;
     case '\\':
       pattern++;
-      /* break; not missing. */
+      fc__fallthrough; /* No break */
     default:
       if (*pattern != *test) {
         return FALSE;
